/**
 * Helper for importing a legacy stylesheet into a component.
 *
 * Given a path to a stylesheet, it returns a CSSStyleSheet that can then be
 * adopted by your component.
 *
 * Pass `patchThemeSupport: true` to turn on the legacy dark mode theming and be
 * returned both the original stylesheet and the new patched rules for dark mode.
 */
export declare function getStyleSheets(path: string, { patchThemeSupport }?: {
    patchThemeSupport?: boolean | undefined;
}): CSSStyleSheet[];
/**
 * The combination of these gives components a way to toggle styling for dark
 * mode. It's not enough to just just the media query because the user may have
 * their OS level set to light mode but have turned on the dark theme via
 * settings.
 *
 * See ElementsBreadcrumbs.ts for an example of how this is used.
 */
export declare const DARK_MODE_CLASS = ".component-in-dark-mode";
export declare function isInDarkMode(): boolean;
export declare function applyDarkModeClassIfNeeded(): string;
export declare const CSS_RESOURCES_TO_LOAD_INTO_RUNTIME: string[];
