/**
 * @unrestricted
 */
export class HTMLFormatter {
    /**
     * @param {!FormattedContentBuilder} builder
     */
    constructor(builder: FormattedContentBuilder);
    _builder: FormattedContentBuilder;
    _jsFormatter: JavaScriptFormatter;
    _cssFormatter: CSSFormatter;
    /**
     * @param {string} text
     * @param {!Array<number>} lineEndings
     */
    format(text: string, lineEndings: Array<number>): void;
    _text: string | undefined;
    _lineEndings: number[] | undefined;
    _model: HTMLModel | undefined;
    /**
     * @param {!FormatterElement} element
     * @param {number} offset
     */
    _formatTokensTill(element: {
        name: string;
        /**
         * @type {!Array<FormatterElement>}
         */
        children: Array<any>;
        /**
         * @type {?FormatterElement}
         */
        parent: any | null;
        /**
         * @type {?Tag}
         */
        openTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
        /**
         * @type {?Tag}
         */
        closeTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
    }, offset: number): void;
    /**
     * @param {!FormatterElement} element
     */
    _walk(element: {
        name: string;
        /**
         * @type {!Array<FormatterElement>}
         */
        children: Array<any>;
        /**
         * @type {?FormatterElement}
         */
        parent: any | null;
        /**
         * @type {?Tag}
         */
        openTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
        /**
         * @type {?Tag}
         */
        closeTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
    }): void;
    /**
     * @param {!FormatterElement} element
     */
    _beforeOpenTag(element: {
        name: string;
        /**
         * @type {!Array<FormatterElement>}
         */
        children: Array<any>;
        /**
         * @type {?FormatterElement}
         */
        parent: any | null;
        /**
         * @type {?Tag}
         */
        openTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
        /**
         * @type {?Tag}
         */
        closeTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
    }): void;
    /**
     * @param {!FormatterElement} element
     */
    _afterOpenTag(element: {
        name: string;
        /**
         * @type {!Array<FormatterElement>}
         */
        children: Array<any>;
        /**
         * @type {?FormatterElement}
         */
        parent: any | null;
        /**
         * @type {?Tag}
         */
        openTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
        /**
         * @type {?Tag}
         */
        closeTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
    }): void;
    /**
     * @param {!FormatterElement} element
     */
    _beforeCloseTag(element: {
        name: string;
        /**
         * @type {!Array<FormatterElement>}
         */
        children: Array<any>;
        /**
         * @type {?FormatterElement}
         */
        parent: any | null;
        /**
         * @type {?Tag}
         */
        openTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
        /**
         * @type {?Tag}
         */
        closeTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
    }): void;
    /**
     * @param {!FormatterElement} element
     */
    _afterCloseTag(element: {
        name: string;
        /**
         * @type {!Array<FormatterElement>}
         */
        children: Array<any>;
        /**
         * @type {?FormatterElement}
         */
        parent: any | null;
        /**
         * @type {?Tag}
         */
        openTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
        /**
         * @type {?Tag}
         */
        closeTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
    }): void;
    /**
     * @param {!FormatterElement} element
     * @param {!Token} token
     */
    _formatToken(element: {
        name: string;
        /**
         * @type {!Array<FormatterElement>}
         */
        children: Array<any>;
        /**
         * @type {?FormatterElement}
         */
        parent: any | null;
        /**
         * @type {?Tag}
         */
        openTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
        /**
         * @type {?Tag}
         */
        closeTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
    }, token: {
        value: string;
        type: Set<string>;
        startOffset: number;
        endOffset: number;
    }): void;
    /**
     * @param {!FormatterElement} element
     * @return {boolean}
     */
    _scriptTagIsJavaScript(element: {
        name: string;
        /**
         * @type {!Array<FormatterElement>}
         */
        children: Array<any>;
        /**
         * @type {?FormatterElement}
         */
        parent: any | null;
        /**
         * @type {?Tag}
         */
        openTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
        /**
         * @type {?Tag}
         */
        closeTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
    }): boolean;
}
export namespace HTMLFormatter {
    const SupportedJavaScriptMimeTypes: Set<string>;
}
/**
 * @unrestricted
 */
export class HTMLModel {
    /**
     * @param {string} text
     */
    constructor(text: string);
    _state: string;
    _document: {
        name: string;
        /**
         * @type {!Array<FormatterElement>}
         */
        children: Array<any>;
        /**
         * @type {?FormatterElement}
         */
        parent: any | null;
        /**
         * @type {?Tag}
         */
        openTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
        /**
         * @type {?Tag}
         */
        closeTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
    };
    _stack: {
        name: string;
        /**
         * @type {!Array<FormatterElement>}
         */
        children: Array<any>;
        /**
         * @type {?FormatterElement}
         */
        parent: any | null;
        /**
         * @type {?Tag}
         */
        openTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
        /**
         * @type {?Tag}
         */
        closeTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
    }[];
    /** @type {!Array<Token>} */
    _tokens: Array<{
        value: string;
        type: Set<string>;
        startOffset: number;
        endOffset: number;
    }>;
    _tokenIndex: number;
    /** @type {!Map<string, string>} */
    _attributes: Map<string, string>;
    _attributeName: string;
    _tagName: string;
    _isOpenTag: boolean;
    /**
     * @param {string} text
     */
    _build(text: string): void;
    /**
     * @param {!Token} token
     */
    _updateDOM(token: {
        value: string;
        type: Set<string>;
        startOffset: number;
        endOffset: number;
    }): void;
    /**
     * @param {!Token} token
     */
    _onStartTag(token: {
        value: string;
        type: Set<string>;
        startOffset: number;
        endOffset: number;
    }): void;
    _tagStartOffset: number | undefined;
    _tagEndOffset: number | null | undefined;
    /**
     * @param {!Token} token
     */
    _onEndTag(token: {
        value: string;
        type: Set<string>;
        startOffset: number;
        endOffset: number;
    }): void;
    /**
     * @param {!Tag} tag
     */
    _onTagComplete(tag: {
        name: string;
        startOffset: number;
        endOffset: number;
        attributes: Map<string, string>;
        isOpenTag: boolean;
        selfClosingTag: boolean;
    }): void;
    /**
     * @param {!Tag} closeTag
     */
    _popElement(closeTag: {
        name: string;
        startOffset: number;
        endOffset: number;
        attributes: Map<string, string>;
        isOpenTag: boolean;
        selfClosingTag: boolean;
    }): void;
    /**
     * @param {!Tag} openTag
     */
    _pushElement(openTag: {
        name: string;
        startOffset: number;
        endOffset: number;
        attributes: Map<string, string>;
        isOpenTag: boolean;
        selfClosingTag: boolean;
    }): void;
    /**
     * @return {?Token}
     */
    peekToken(): {
        value: string;
        type: Set<string>;
        startOffset: number;
        endOffset: number;
    } | null;
    /**
     * @return {?Token}
     */
    nextToken(): {
        value: string;
        type: Set<string>;
        startOffset: number;
        endOffset: number;
    } | null;
    /**
     * @return {!FormatterElement}
     */
    document(): {
        name: string;
        /**
         * @type {!Array<FormatterElement>}
         */
        children: Array<any>;
        /**
         * @type {?FormatterElement}
         */
        parent: any | null;
        /**
         * @type {?Tag}
         */
        openTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
        /**
         * @type {?Tag}
         */
        closeTag: {
            name: string;
            startOffset: number;
            endOffset: number;
            attributes: Map<string, string>;
            isOpenTag: boolean;
            selfClosingTag: boolean;
        } | null;
    };
}
import { FormattedContentBuilder } from "./FormattedContentBuilder.js";
import { JavaScriptFormatter } from "./JavaScriptFormatter.js";
import { CSSFormatter } from "./CSSFormatter.js";
