export class HARRoot extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    log: HARLog;
}
export class HARLog extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    version: string;
    creator: HARCreator;
    browser: HARCreator | undefined;
    pages: HARPage[];
    entries: HAREntry[];
    comment: string | undefined;
}
export class HARPage extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    startedDateTime: Date;
    id: string;
    title: string;
    pageTimings: HARPageTimings;
    comment: string | undefined;
}
export class HAREntry extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    pageref: string | undefined;
    startedDateTime: Date;
    time: number;
    request: HARRequest;
    response: HARResponse;
    cache: {};
    timings: HARTimings;
    serverIPAddress: string | undefined;
    connection: string | undefined;
    comment: string | undefined;
    _fromCache: string | undefined;
    _initiator: HARInitiator | undefined;
    _priority: string | undefined;
    _resourceType: string | undefined;
    _webSocketMessages: HARInitiator[] | undefined;
    /**
     * @param {*} initiator
     * @return {!HARInitiator|undefined}
     */
    _importInitiator(initiator: any): HARInitiator | undefined;
    /**
     * @param {*} inputMessages
     * @return {!Array<!HARInitiator>|undefined}
     */
    _importWebSocketMessages(inputMessages: any): Array<HARInitiator> | undefined;
}
export class HARParam extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    name: string;
    value: string | undefined;
    fileName: string | undefined;
    contentType: string | undefined;
    comment: string | undefined;
}
export class HARTimings extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    blocked: number | undefined;
    dns: number | undefined;
    connect: number | undefined;
    send: number;
    wait: number;
    receive: number;
    ssl: number | undefined;
    comment: string | undefined;
    _blocked_queueing: number | undefined;
    _blocked_proxy: number | undefined;
}
export class HARInitiator extends HARBase {
    /**
     * Based on Initiator defined in browser_protocol.pdl
     *
     * @param {*} data
     */
    constructor(data: any);
    type: string | undefined;
    url: string | undefined;
    lineNumber: number | undefined;
}
declare class HARBase {
    /**
     * @param {*} data
     * @return {!Date}
     */
    static _safeDate(data: any): Date;
    /**
     * @param {*} data
     * @return {number}
     */
    static _safeNumber(data: any): number;
    /**
     * @param {*} data
     * @return {number|undefined}
     */
    static _optionalNumber(data: any): number | undefined;
    /**
     * @param {*} data
     * @return {string|undefined}
     */
    static _optionalString(data: any): string | undefined;
    /**
     * @param {*} data
     */
    constructor(data: any);
    /**
     * @param {string} name
     * @return {string|undefined}
     */
    customAsString(name: string): string | undefined;
    /**
     * @param {string} name
     * @return {number|undefined}
     */
    customAsNumber(name: string): number | undefined;
    /**
     * @param {string} name
     * @return {!Array|undefined}
     */
    customAsArray(name: string): any[] | undefined;
}
declare class HARCreator extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    name: string;
    version: string;
    comment: string | undefined;
}
declare class HARPageTimings extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    onContentLoad: number | undefined;
    onLoad: number | undefined;
    comment: string | undefined;
}
declare class HARRequest extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    method: string;
    url: string;
    httpVersion: string;
    cookies: HARCookie[];
    headers: HARHeader[];
    queryString: HARQueryString[];
    postData: HARPostData | undefined;
    headersSize: number;
    bodySize: number;
    comment: string | undefined;
}
declare class HARResponse extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    status: number;
    statusText: string;
    httpVersion: string;
    cookies: HARCookie[];
    headers: HARHeader[];
    content: HARContent;
    redirectURL: string;
    headersSize: number;
    bodySize: number;
    comment: string | undefined;
    _transferSize: number | undefined;
    _error: string | undefined;
}
declare class HARCookie extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    name: string;
    value: string;
    path: string | undefined;
    domain: string | undefined;
    expires: Date | undefined;
    httpOnly: boolean | undefined;
    secure: boolean | undefined;
    comment: string | undefined;
}
declare class HARHeader extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    name: string;
    value: string;
    comment: string | undefined;
}
declare class HARQueryString extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    name: string;
    value: string;
    comment: string | undefined;
}
declare class HARPostData extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    mimeType: string;
    params: HARParam[];
    text: string;
    comment: string | undefined;
}
declare class HARContent extends HARBase {
    /**
     * @param {*} data
     */
    constructor(data: any);
    size: number;
    compression: number | undefined;
    mimeType: string;
    text: string | undefined;
    encoding: string | undefined;
    comment: string | undefined;
}
export {};
