export namespace HeapSnapshotProgressEvent {
    const Update: string;
    const BrokenSnapshot: string;
}
export const baseSystemDistance: 100000000;
/**
 * @unrestricted
 */
export class AllocationNodeCallers {
    /**
     * @param {!Array.<!SerializedAllocationNode>} nodesWithSingleCaller
     * @param {!Array.<!SerializedAllocationNode>} branchingCallers
     */
    constructor(nodesWithSingleCaller: Array<SerializedAllocationNode>, branchingCallers: Array<SerializedAllocationNode>);
    /** @type {!Array.<!SerializedAllocationNode>} */
    nodesWithSingleCaller: Array<SerializedAllocationNode>;
    /** @type {!Array.<!SerializedAllocationNode>} */
    branchingCallers: Array<SerializedAllocationNode>;
}
/**
 * @unrestricted
 */
export class SerializedAllocationNode {
    /**
     * @param {number} nodeId
     * @param {string} functionName
     * @param {string} scriptName
     * @param {number} scriptId
     * @param {number} line
     * @param {number} column
     * @param {number} count
     * @param {number} size
     * @param {number} liveCount
     * @param {number} liveSize
     * @param {boolean} hasChildren
     */
    constructor(nodeId: number, functionName: string, scriptName: string, scriptId: number, line: number, column: number, count: number, size: number, liveCount: number, liveSize: number, hasChildren: boolean);
    /** @type {number} */
    id: number;
    /** @type {string} */
    name: string;
    /** @type {string} */
    scriptName: string;
    /** @type {number} */
    scriptId: number;
    /** @type {number} */
    line: number;
    /** @type {number} */
    column: number;
    /** @type {number} */
    count: number;
    /** @type {number} */
    size: number;
    /** @type {number} */
    liveCount: number;
    /** @type {number} */
    liveSize: number;
    /** @type {boolean} */
    hasChildren: boolean;
}
/**
 * @unrestricted
 */
export class AllocationStackFrame {
    /**
     * @param {string} functionName
     * @param {string} scriptName
     * @param {number} scriptId
     * @param {number} line
     * @param {number} column
     */
    constructor(functionName: string, scriptName: string, scriptId: number, line: number, column: number);
    /** @type {string} */
    functionName: string;
    /** @type {string} */
    scriptName: string;
    /** @type {number} */
    scriptId: number;
    /** @type {number} */
    line: number;
    /** @type {number} */
    column: number;
}
/**
 * @unrestricted
 */
export class Node {
    /**
     * @param {number} id
     * @param {string} name
     * @param {number} distance
     * @param {number} nodeIndex
     * @param {number} retainedSize
     * @param {number} selfSize
     * @param {string} type
     */
    constructor(id: number, name: string, distance: number, nodeIndex: number, retainedSize: number, selfSize: number, type: string);
    id: number;
    name: string;
    distance: number;
    nodeIndex: number;
    retainedSize: number;
    selfSize: number;
    type: string;
    canBeQueried: boolean;
    detachedDOMTreeNode: boolean;
}
/**
 * @unrestricted
 */
export class Edge {
    /**
     * @param {string} name
     * @param {!Node} node
     * @param {string} type
     * @param {number} edgeIndex
     */
    constructor(name: string, node: Node, type: string, edgeIndex: number);
    name: string;
    node: Node;
    type: string;
    edgeIndex: number;
}
/**
 * @unrestricted
 */
export class Aggregate {
    /** @type {number} */
    count: number;
    /** @type {number} */
    distance: number;
    /** @type {number} */
    self: number;
    /** @type {number} */
    maxRet: number;
    /** @type {number} */
    type: number;
    /** @type {string} */
    name: string;
    /** @type {!Array.<number>} */
    idxs: Array<number>;
}
/**
 * @unrestricted
 */
export class AggregateForDiff {
    /** @type {!Array.<number>} */
    indexes: Array<number>;
    /** @type {!Array.<number>} */
    ids: Array<number>;
    /** @type {!Array.<number>} */
    selfSizes: Array<number>;
}
/**
 * @unrestricted
 */
export class Diff {
    /** @type {number} */
    addedCount: number;
    /** @type {number} */
    removedCount: number;
    /** @type {number} */
    addedSize: number;
    /** @type {number} */
    removedSize: number;
    /** @type {!Array.<number>} */
    deletedIndexes: Array<number>;
    /** @type {!Array.<number>} */
    addedIndexes: Array<number>;
    /** @type {number} */
    countDelta: number;
    /** @type {number} */
    sizeDelta: number;
}
/**
 * @unrestricted
 */
export class DiffForClass {
    /** @type {number} */
    addedCount: number;
    /** @type {number} */
    removedCount: number;
    /** @type {number} */
    addedSize: number;
    /** @type {number} */
    removedSize: number;
    /** @type {!Array.<number>} */
    deletedIndexes: Array<number>;
    /** @type {!Array.<number>} */
    addedIndexes: Array<number>;
    /** @type {number} */
    countDelta: number;
    /** @type {number} */
    sizeDelta: number;
}
/**
 * @unrestricted
 */
export class ComparatorConfig {
    /** @type {string} */
    fieldName1: string;
    /** @type {boolean} */
    ascending1: boolean;
    /** @type {string} */
    fieldName2: string;
    /** @type {boolean} */
    ascending2: boolean;
}
/**
 * @unrestricted
 */
export class WorkerCommand {
    /** @type {number} */
    callId: number;
    /** @type {string} */
    disposition: string;
    /** @type {number} */
    objectId: number;
    /** @type {number} */
    newObjectId: number;
    /** @type {string} */
    methodName: string;
    /** @type {!Array.<*>} */
    methodArguments: Array<any>;
    /** @type {string} */
    source: string;
}
/**
 * @unrestricted
 */
export class ItemsRange {
    /**
     * @param {number} startPosition
     * @param {number} endPosition
     * @param {number} totalLength
     * @param {!Array.<*>} items
     */
    constructor(startPosition: number, endPosition: number, totalLength: number, items: Array<any>);
    /** @type {number} */
    startPosition: number;
    /** @type {number} */
    endPosition: number;
    /** @type {number} */
    totalLength: number;
    /** @type {!Array.<*>} */
    items: Array<any>;
}
/**
 * @unrestricted
 */
export class StaticData {
    /**
     * @param {number} nodeCount
     * @param {number} rootNodeIndex
     * @param {number} totalSize
     * @param {number} maxJSObjectId
     */
    constructor(nodeCount: number, rootNodeIndex: number, totalSize: number, maxJSObjectId: number);
    /** @type {number} */
    nodeCount: number;
    /** @type {number} */
    rootNodeIndex: number;
    /** @type {number} */
    totalSize: number;
    /** @type {number} */
    maxJSObjectId: number;
}
/**
 * @unrestricted
 */
export class Statistics {
    /** @type {number} */
    total: number;
    /** @type {number} */
    v8heap: number;
    /** @type {number} */
    native: number;
    /** @type {number} */
    code: number;
    /** @type {number} */
    jsArrays: number;
    /** @type {number} */
    strings: number;
    /** @type {number} */
    system: number;
}
/**
 * @unrestricted
 */
export class NodeFilter {
    /**
     * @param {number=} minNodeId
     * @param {number=} maxNodeId
     */
    constructor(minNodeId?: number | undefined, maxNodeId?: number | undefined);
    /** @type {number|undefined} */
    minNodeId: number | undefined;
    /** @type {number|undefined} */
    maxNodeId: number | undefined;
    /** @type {number|undefined} */
    allocationNodeId: number | undefined;
    /**
     * @param {!NodeFilter} o
     * @return {boolean}
     */
    equals(o: NodeFilter): boolean;
}
/**
 * @unrestricted
 */
export class SearchConfig {
    /**
     * @param {string} query
     * @param {boolean} caseSensitive
     * @param {boolean} isRegex
     * @param {boolean} shouldJump
     * @param {boolean} jumpBackward
     */
    constructor(query: string, caseSensitive: boolean, isRegex: boolean, shouldJump: boolean, jumpBackward: boolean);
    query: string;
    caseSensitive: boolean;
    isRegex: boolean;
    shouldJump: boolean;
    jumpBackward: boolean;
}
/**
 * @unrestricted
 */
export class Samples {
    /**
     * @param {!Array.<number>} timestamps
     * @param {!Array.<number>} lastAssignedIds
     * @param {!Array.<number>} sizes
     */
    constructor(timestamps: Array<number>, lastAssignedIds: Array<number>, sizes: Array<number>);
    timestamps: number[];
    lastAssignedIds: number[];
    sizes: number[];
}
/**
 * @unrestricted
 */
export class Location {
    /**
     * @param {number} scriptId
     * @param {number} lineNumber
     * @param {number} columnNumber
     */
    constructor(scriptId: number, lineNumber: number, columnNumber: number);
    scriptId: number;
    lineNumber: number;
    columnNumber: number;
}
