/**
 * @unrestricted
 */
export class AllocationProfile {
    /**
     *
     * @param {*} profile
     * @param {*} liveObjectStats
     */
    constructor(profile: any, liveObjectStats: any);
    _strings: any;
    _liveObjectStats: any;
    _nextNodeId: number;
    /**
     * @type {!Array<!FunctionAllocationInfo>}
     */
    _functionInfos: Array<FunctionAllocationInfo>;
    /**
     * @type {!Object.<number, ?BottomUpAllocationNode>}}
     */
    _idToNode: {
        [x: number]: BottomUpAllocationNode | null;
    };
    /**
     * @type {!Object.<number, !TopDownAllocationNode>}}
     */
    _idToTopDownNode: {
        [x: number]: TopDownAllocationNode;
    };
    /**
     * @type {!Object.<number, !FunctionAllocationInfo>}}
     */
    _collapsedTopNodeIdToFunctionInfo: {
        [x: number]: FunctionAllocationInfo;
    };
    /**
     * @type {!Array<!HeapSnapshotModel.HeapSnapshotModel.SerializedAllocationNode>}
     */
    _traceTops: Array<HeapSnapshotModel.HeapSnapshotModel.SerializedAllocationNode>;
    _traceTree: TopDownAllocationNode;
    /**
     *
     * @param {*} profile
     */
    _buildFunctionAllocationInfos(profile: any): void;
    /**
     *
     * @param {*} profile
     * @param {*} liveObjectStats
     */
    _buildAllocationTree(profile: any, liveObjectStats: any): TopDownAllocationNode;
    /**
     * @return {!Array.<!HeapSnapshotModel.HeapSnapshotModel.SerializedAllocationNode>}
     */
    serializeTraceTops(): Array<HeapSnapshotModel.HeapSnapshotModel.SerializedAllocationNode>;
    /**
     * @param {number} nodeId
     * @return {!HeapSnapshotModel.HeapSnapshotModel.AllocationNodeCallers}
     */
    serializeCallers(nodeId: number): HeapSnapshotModel.HeapSnapshotModel.AllocationNodeCallers;
    /**
     * @param {number} traceNodeId
     * @return {!Array.<!HeapSnapshotModel.HeapSnapshotModel.AllocationStackFrame>}
     */
    serializeAllocationStack(traceNodeId: number): Array<HeapSnapshotModel.HeapSnapshotModel.AllocationStackFrame>;
    /**
     * @param {number} allocationNodeId
     * @return {!Array.<number>}
     */
    traceIds(allocationNodeId: number): Array<number>;
    /**
     * @param {number} nodeId
     * @return {!BottomUpAllocationNode}
     */
    _ensureBottomUpNode(nodeId: number): BottomUpAllocationNode;
    /**
     * @param {!BottomUpAllocationNode} node
     * @return {!HeapSnapshotModel.HeapSnapshotModel.SerializedAllocationNode}
     */
    _serializeCaller(node: BottomUpAllocationNode): HeapSnapshotModel.HeapSnapshotModel.SerializedAllocationNode;
    /**
     * @param {number} nodeId
     * @param {!FunctionAllocationInfo} functionInfo
     * @param {number} count
     * @param {number} size
     * @param {number} liveCount
     * @param {number} liveSize
     * @param {boolean} hasChildren
     * @return {!HeapSnapshotModel.HeapSnapshotModel.SerializedAllocationNode}
     */
    _serializeNode(nodeId: number, functionInfo: FunctionAllocationInfo, count: number, size: number, liveCount: number, liveSize: number, hasChildren: boolean): HeapSnapshotModel.HeapSnapshotModel.SerializedAllocationNode;
}
/**
 * @unrestricted
 */
export class TopDownAllocationNode {
    /**
     * @param {number} id
     * @param {!FunctionAllocationInfo} functionInfo
     * @param {number} count
     * @param {number} size
     * @param {number} liveCount
     * @param {number} liveSize
     * @param {?TopDownAllocationNode} parent
     */
    constructor(id: number, functionInfo: FunctionAllocationInfo, count: number, size: number, liveCount: number, liveSize: number, parent: TopDownAllocationNode | null);
    id: number;
    functionInfo: FunctionAllocationInfo;
    allocationCount: number;
    allocationSize: number;
    liveCount: number;
    liveSize: number;
    parent: TopDownAllocationNode | null;
    /**
     * @type {!Array<!TopDownAllocationNode>}
     */
    children: Array<TopDownAllocationNode>;
}
/**
 * @unrestricted
 */
export class BottomUpAllocationNode {
    /**
     * @param {!FunctionAllocationInfo} functionInfo
     */
    constructor(functionInfo: FunctionAllocationInfo);
    functionInfo: FunctionAllocationInfo;
    allocationCount: number;
    allocationSize: number;
    liveCount: number;
    liveSize: number;
    /**
     * @type {!Array<number>}
     */
    traceTopIds: Array<number>;
    /**
     * @type {!Array<!BottomUpAllocationNode>}
     */
    _callers: Array<BottomUpAllocationNode>;
    /**
     * @param {!TopDownAllocationNode} traceNode
     * @return {!BottomUpAllocationNode}
     */
    addCaller(traceNode: TopDownAllocationNode): BottomUpAllocationNode;
    /**
     * @return {!Array.<!BottomUpAllocationNode>}
     */
    callers(): Array<BottomUpAllocationNode>;
    /**
     * @return {boolean}
     */
    hasCallers(): boolean;
}
/**
 * @unrestricted
 */
export class FunctionAllocationInfo {
    /**
     * @param {string} functionName
     * @param {string} scriptName
     * @param {number} scriptId
     * @param {number} line
     * @param {number} column
     */
    constructor(functionName: string, scriptName: string, scriptId: number, line: number, column: number);
    functionName: string;
    scriptName: string;
    scriptId: number;
    line: number;
    column: number;
    totalCount: number;
    totalSize: number;
    totalLiveCount: number;
    totalLiveSize: number;
    /**
     * @type {!Array<!TopDownAllocationNode>}
     */
    _traceTops: Array<TopDownAllocationNode>;
    /**
     * @param {!TopDownAllocationNode} node
     */
    addTraceTopNode(node: TopDownAllocationNode): void;
    /**
     * @return {?BottomUpAllocationNode}
     */
    bottomUpRoot(): BottomUpAllocationNode | null;
    _buildAllocationTraceTree(): void;
    _bottomUpTree: BottomUpAllocationNode | undefined;
}
import * as HeapSnapshotModel from "../heap_snapshot_model/heap_snapshot_model.js";
