/**
 * @interface
 */
export class HeapSnapshotItem {
    /**
     * @return {number}
     */
    itemIndex(): number;
    /**
     * @return {!Object}
     */
    serialize(): Object;
}
/**
 * @implements {HeapSnapshotItem}
 * @unrestricted
 */
export class HeapSnapshotEdge implements HeapSnapshotItem {
    /**
     * @param {!HeapSnapshot} snapshot
     * @param {number=} edgeIndex
     */
    constructor(snapshot: HeapSnapshot, edgeIndex?: number | undefined);
    _snapshot: HeapSnapshot;
    _edges: Uint32Array;
    edgeIndex: number;
    /**
     * @return {!HeapSnapshotEdge}
     */
    clone(): HeapSnapshotEdge;
    /**
     * @return {boolean}
     */
    hasStringName(): boolean;
    /**
     * @return {string}
     */
    name(): string;
    /**
     * @return {!HeapSnapshotNode}
     */
    node(): HeapSnapshotNode;
    /**
     * @return {number}
     */
    nodeIndex(): number;
    /**
     * @override
     * @return {string}
     */
    toString(): string;
    /**
     * @return {string}
     */
    type(): string;
    /**
     * @override
     * @return {number}
     */
    itemIndex(): number;
    /**
     * @override
     * @return {!HeapSnapshotModel.HeapSnapshotModel.Edge}
     */
    serialize(): HeapSnapshotModel.HeapSnapshotModel.Edge;
    /**
     * @protected
     * @return {number}
     */
    protected rawType(): number;
    /**
     * @return {boolean}
     */
    isInvisible(): boolean;
    /**
     * @return {boolean}
     */
    isWeak(): boolean;
}
/**
 * @interface
 */
export class HeapSnapshotItemIterator {
    /**
     * @return {boolean}
     */
    hasNext(): boolean;
    /**
     * @return {!HeapSnapshotItem}
     */
    item(): HeapSnapshotItem;
    next(): void;
}
/**
 * @interface
 */
export class HeapSnapshotItemIndexProvider {
    /**
     * @param {number} newIndex
     * @return {!HeapSnapshotItem}
     */
    itemForIndex(newIndex: number): HeapSnapshotItem;
}
/**
 * @implements {HeapSnapshotItemIndexProvider}
 * @unrestricted
 */
export class HeapSnapshotNodeIndexProvider implements HeapSnapshotItemIndexProvider {
    /**
     * @param {!HeapSnapshot} snapshot
     */
    constructor(snapshot: HeapSnapshot);
    _node: HeapSnapshotNode;
    /**
     * @override
     * @param {number} index
     * @return {!HeapSnapshotNode}
     */
    itemForIndex(index: number): HeapSnapshotNode;
}
/**
 * @implements {HeapSnapshotItemIndexProvider}
 * @unrestricted
 */
export class HeapSnapshotEdgeIndexProvider implements HeapSnapshotItemIndexProvider {
    /**
     * @param {!HeapSnapshot} snapshot
     */
    constructor(snapshot: HeapSnapshot);
    _edge: JSHeapSnapshotEdge;
    /**
     * @override
     * @param {number} index
     * @return {!HeapSnapshotEdge}
     */
    itemForIndex(index: number): HeapSnapshotEdge;
}
/**
 * @implements {HeapSnapshotItemIndexProvider}
 * @unrestricted
 */
export class HeapSnapshotRetainerEdgeIndexProvider implements HeapSnapshotItemIndexProvider {
    /**
     * @param {!HeapSnapshot} snapshot
     */
    constructor(snapshot: HeapSnapshot);
    _retainerEdge: JSHeapSnapshotRetainerEdge;
    /**
     * @override
     * @param {number} index
     * @return {!HeapSnapshotRetainerEdge}
     */
    itemForIndex(index: number): HeapSnapshotRetainerEdge;
}
/**
 * @implements {HeapSnapshotItemIterator}
 * @unrestricted
 */
export class HeapSnapshotEdgeIterator implements HeapSnapshotItemIterator {
    /**
     * @param {!HeapSnapshotNode} node
     */
    constructor(node: HeapSnapshotNode);
    _sourceNode: HeapSnapshotNode;
    edge: JSHeapSnapshotEdge;
    /**
     * @override
     * @return {boolean}
     */
    hasNext(): boolean;
    /**
     * @override
     * @return {!HeapSnapshotEdge}
     */
    item(): HeapSnapshotEdge;
    /**
     * @override
     */
    next(): void;
}
/**
 * @implements {HeapSnapshotItem}
 * @unrestricted
 */
export class HeapSnapshotRetainerEdge implements HeapSnapshotItem {
    /**
     * @param {!HeapSnapshot} snapshot
     * @param {number} retainerIndex
     */
    constructor(snapshot: HeapSnapshot, retainerIndex: number);
    _snapshot: HeapSnapshot;
    /**
     * @type {number}
     */
    _retainerIndex: number;
    /**
     * @type {number};
     */
    _globalEdgeIndex: number;
    /**
     * @return {!HeapSnapshotRetainerEdge}
     */
    clone(): HeapSnapshotRetainerEdge;
    /**
     * @return {boolean}
     */
    hasStringName(): boolean;
    /**
     * @return {string}
     */
    name(): string;
    /**
     * @return {!HeapSnapshotNode}
     */
    node(): HeapSnapshotNode;
    /**
     * @return {number}
     */
    nodeIndex(): number;
    /**
     * @return {number}
     */
    retainerIndex(): number;
    /**
     * @param {number} retainerIndex
     */
    setRetainerIndex(retainerIndex: number): void;
    _retainingNodeIndex: number | undefined;
    _edgeInstance: JSHeapSnapshotEdge | null | undefined;
    _nodeInstance: HeapSnapshotNode | null | undefined;
    /**
     * @param {number} edgeIndex
     */
    set edgeIndex(arg: number);
    _node(): HeapSnapshotNode;
    _edge(): JSHeapSnapshotEdge;
    /**
     * @override
     * @return {string}
     */
    toString(): string;
    /**
     * @override
     * @return {number}
     */
    itemIndex(): number;
    /**
     * @override
     * @return {!HeapSnapshotModel.HeapSnapshotModel.Edge}
     */
    serialize(): HeapSnapshotModel.HeapSnapshotModel.Edge;
    /**
     * @return {string}
     */
    type(): string;
}
/**
 * @implements {HeapSnapshotItemIterator}
 * @unrestricted
 */
export class HeapSnapshotRetainerEdgeIterator implements HeapSnapshotItemIterator {
    /**
     * @param {!HeapSnapshotNode} retainedNode
     */
    constructor(retainedNode: HeapSnapshotNode);
    _retainersEnd: number;
    retainer: JSHeapSnapshotRetainerEdge;
    /**
     * @override
     * @return {boolean}
     */
    hasNext(): boolean;
    /**
     * @override
     * @return {!HeapSnapshotRetainerEdge}
     */
    item(): HeapSnapshotRetainerEdge;
    /**
     * @override
     */
    next(): void;
}
/**
 * @implements {HeapSnapshotItem}
 * @unrestricted
 */
export class HeapSnapshotNode implements HeapSnapshotItem {
    /**
     * @param {!HeapSnapshot} snapshot
     * @param {number=} nodeIndex
     */
    constructor(snapshot: HeapSnapshot, nodeIndex?: number | undefined);
    _snapshot: HeapSnapshot;
    nodeIndex: number;
    /**
     * @return {number}
     */
    distance(): number;
    /**
     * @return {string}
     */
    className(): string;
    /**
     * @return {number}
     */
    classIndex(): number;
    /**
     * @return {number}
     */
    dominatorIndex(): number;
    /**
     * @return {!HeapSnapshotEdgeIterator}
     */
    edges(): HeapSnapshotEdgeIterator;
    /**
     * @return {number}
     */
    edgesCount(): number;
    /**
     * @return {number}
     */
    id(): number;
    /**
     * @return {string}
     */
    rawName(): string;
    /**
     * @return {boolean}
     */
    isRoot(): boolean;
    /**
     * @return {boolean}
     */
    isUserRoot(): boolean;
    /**
     * @return {boolean}
     */
    isHidden(): boolean;
    /**
     * @return {boolean}
     */
    isArray(): boolean;
    /**
     * @return {boolean}
     */
    isDocumentDOMTreesRoot(): boolean;
    /**
     * @return {string}
     */
    name(): string;
    /**
     * @return {number}
     */
    retainedSize(): number;
    /**
     * @return {!HeapSnapshotRetainerEdgeIterator}
     */
    retainers(): HeapSnapshotRetainerEdgeIterator;
    /**
     * @return {number}
     */
    retainersCount(): number;
    /**
     * @return {number}
     */
    selfSize(): number;
    /**
     * @return {string}
     */
    type(): string;
    /**
     * @return {number}
     */
    traceNodeId(): number;
    /**
     * @override
     * @return {number}
     */
    itemIndex(): number;
    /**
     * @override
     * @return {!HeapSnapshotModel.HeapSnapshotModel.Node}
     */
    serialize(): HeapSnapshotModel.HeapSnapshotModel.Node;
    /**
     * @return {number}
     */
    _name(): number;
    /**
     * @return {number}
     */
    edgeIndexesStart(): number;
    /**
     * @return {number}
     */
    edgeIndexesEnd(): number;
    /**
     * @return {number}
     */
    ordinal(): number;
    /**
     * @return {number}
     */
    _nextNodeIndex(): number;
    /**
     * @protected
     * @return {number}
     */
    protected rawType(): number;
}
/**
 * @implements {HeapSnapshotItemIterator}
 * @unrestricted
 */
export class HeapSnapshotNodeIterator implements HeapSnapshotItemIterator {
    /**
     * @param {!HeapSnapshotNode} node
     */
    constructor(node: HeapSnapshotNode);
    node: HeapSnapshotNode;
    _nodesLength: number;
    /**
     * @override
     * @return {boolean}
     */
    hasNext(): boolean;
    /**
     * @override
     * @return {!HeapSnapshotNode}
     */
    item(): HeapSnapshotNode;
    /**
     * @override
     */
    next(): void;
}
/**
 * @implements {HeapSnapshotItemIterator}
 * @unrestricted
 */
export class HeapSnapshotIndexRangeIterator implements HeapSnapshotItemIterator {
    /**
     * @param {!HeapSnapshotItemIndexProvider} itemProvider
     * @param {!Array.<number>|!Uint32Array} indexes
     */
    constructor(itemProvider: HeapSnapshotItemIndexProvider, indexes: Array<number> | Uint32Array);
    _itemProvider: HeapSnapshotItemIndexProvider;
    _indexes: number[] | Uint32Array;
    _position: number;
    /**
     * @override
     * @return {boolean}
     */
    hasNext(): boolean;
    /**
     * @override
     * @return {!HeapSnapshotItem}
     */
    item(): HeapSnapshotItem;
    /**
     * @override
     */
    next(): void;
}
/**
 * @implements {HeapSnapshotItemIterator}
 * @unrestricted
 */
export class HeapSnapshotFilteredIterator implements HeapSnapshotItemIterator {
    /**
     * @param {!HeapSnapshotItemIterator} iterator
     * @param {function(!HeapSnapshotItem):boolean=} filter
     */
    constructor(iterator: HeapSnapshotItemIterator, filter?: ((arg0: HeapSnapshotItem) => boolean) | undefined);
    _iterator: HeapSnapshotItemIterator;
    _filter: ((arg0: HeapSnapshotItem) => boolean) | undefined;
    /**
     * @override
     * @return {boolean}
     */
    hasNext(): boolean;
    /**
     * @override
     * @return {!HeapSnapshotItem}
     */
    item(): HeapSnapshotItem;
    /**
     * @override
     */
    next(): void;
    _skipFilteredItems(): void;
}
/**
 * @unrestricted
 */
export class HeapSnapshotProgress {
    /**
     * @param {!HeapSnapshotWorkerDispatcher=} dispatcher
     */
    constructor(dispatcher?: HeapSnapshotWorkerDispatcher | undefined);
    _dispatcher: HeapSnapshotWorkerDispatcher | undefined;
    /**
     * @param {string} status
     */
    updateStatus(status: string): void;
    /**
     * @param {string} title
     * @param {number} value
     * @param {number} total
     */
    updateProgress(title: string, value: number, total: number): void;
    /**
     * @param {string} error
     */
    reportProblem(error: string): void;
    /**
     * @param {string} serializedText
     */
    _sendUpdateEvent(serializedText: string): void;
}
/**
 * @unrestricted
 */
export class HeapSnapshotProblemReport {
    /**
     * @param {string} title
     */
    constructor(title: string);
    _errors: string[];
    /**
     * @param {string} error
     */
    addError(error: string): void;
    /**
     * @override
     * @return {string}
     */
    toString(): string;
}
export type Profile = {
    root_index: number;
    nodes: Uint32Array;
    edges: Uint32Array;
    snapshot: HeapSnapshotHeader;
    samples: Array<number>;
    strings: Array<string>;
    locations: Array<number>;
    trace_function_infos: Uint32Array;
    trace_tree: Object;
};
/** @typedef {{
 * root_index: number,
 * nodes: !Uint32Array,
 * edges: !Uint32Array,
 * snapshot: !HeapSnapshotHeader,
 * samples: !Array<number>,
 * strings: !Array<string>,
 * locations: !Array<number>,
 * trace_function_infos: !Uint32Array,
 * trace_tree: Object
 * }} */
export let Profile: any;
/**
 * @unrestricted
 */
export class HeapSnapshot {
    /**
     * @param {!Profile} profile
     * @param {!HeapSnapshotProgress} progress
     */
    constructor(profile: Profile, progress: HeapSnapshotProgress);
    /** @type {!Uint32Array} */
    nodes: Uint32Array;
    /** @type {!Uint32Array} */
    containmentEdges: Uint32Array;
    /** @type {!HeapSnapshotMetainfo} */
    _metaNode: {
        /**
         * @type {!Array<string>}
         */
        location_fields: Array<string>;
        /**
         * @type {!Array<string>}
         */
        node_fields: Array<string>;
        /**
         * @type {!Array<!Array<string>>}
         */
        node_types: Array<Array<string>>;
        /**
         * @type {!Array<string>}
         */
        edge_fields: Array<string>;
        /**
         * @type {!Array<!Array<string>>}
         */
        edge_types: Array<Array<string>>;
        /**
         * @type {!Array<string>}
         */
        trace_function_info_fields: Array<string>;
        /**
         * @type {!Array<string>}
         */
        trace_node_fields: Array<string>;
        /**
         * @type {!Array<string>}
         */
        sample_fields: Array<string>;
        /**
         * @type {!Object<string, string>}
         */
        type_strings: {
            [x: string]: string;
        };
    };
    /** @type {!Array.<number>} */
    _rawSamples: Array<number>;
    /** @type {?HeapSnapshotModel.HeapSnapshotModel.Samples} */
    _samples: HeapSnapshotModel.HeapSnapshotModel.Samples | null;
    /** @type {!Array.<string>} */
    strings: Array<string>;
    /** @type {!Array.<number>} */
    _locations: Array<number>;
    _progress: HeapSnapshotProgress;
    _noDistance: number;
    _rootNodeIndex: number;
    /**
     * @type {!Object.<string, !Object.<string, !HeapSnapshotModel.HeapSnapshotModel.Diff>>}
     */
    _snapshotDiffs: {
        [x: string]: {
            [x: string]: HeapSnapshotModel.HeapSnapshotModel.Diff;
        };
    };
    /**
     * @type {!Object.<string, !HeapSnapshotModel.HeapSnapshotModel.AggregateForDiff>}
     */
    _aggregatesForDiff: {
        [x: string]: HeapSnapshotModel.HeapSnapshotModel.AggregateForDiff;
    };
    /**
     * @type {!Object.<string, !Object.<string, !AggregatedInfo>>}
     */
    _aggregates: {
        [x: string]: {
            [x: string]: AggregatedInfo;
        };
    };
    /**
     * @type {!Object.<string, boolean>}
     */
    _aggregatesSortedFlags: {
        [x: string]: boolean;
    };
    _profile: {
        root_index: number;
        nodes: Uint32Array;
        edges: Uint32Array;
        snapshot: HeapSnapshotHeader;
        samples: Array<number>;
        strings: Array<string>;
        locations: Array<number>;
        trace_function_infos: Uint32Array;
        trace_tree: Object;
    };
    /**
     * @type {number}
     */
    _nodeTypeOffset: number;
    /**
     * @type {number}
     */
    _nodeNameOffset: number;
    /**
     * @type {number}
     */
    _nodeIdOffset: number;
    /**
     * @type {number}
     */
    _nodeSelfSizeOffset: number;
    /**
     * @type {number}
     */
    _nodeEdgeCountOffset: number;
    /**
     * @type {number}
     */
    _nodeTraceNodeIdOffset: number;
    /**
     * @type {number}
     */
    _nodeFieldCount: number;
    /**
     * @type {!Array<string>}
     */
    _nodeTypes: Array<string>;
    /**
     * @type {number}
     */
    _nodeArrayType: number;
    /**
     * @type {number}
     */
    _nodeHiddenType: number;
    /**
     * @type {number}
     */
    _nodeObjectType: number;
    /**
     * @type {number}
     */
    _nodeNativeType: number;
    /**
     * @type {number}
     */
    _nodeConsStringType: number;
    /**
     * @type {number}
     */
    _nodeSlicedStringType: number;
    /**
     * @type {number}
     */
    _nodeCodeType: number;
    /**
     * @type {number}
     */
    _nodeSyntheticType: number;
    /**
     * @type {number}
     */
    _edgeFieldsCount: number;
    /**
     * @type {number}
     */
    _edgeTypeOffset: number;
    /**
     * @type {number}
     */
    _edgeNameOffset: number;
    /**
     * @type {number}
     */
    _edgeToNodeOffset: number;
    /**
     * @type {!Array<string>}
     */
    _edgeTypes: Array<string>;
    /**
     * @type {number}
     */
    _edgeElementType: number;
    /**
     * @type {number}
     */
    _edgeHiddenType: number;
    /**
     * @type {number}
     */
    _edgeInternalType: number;
    /**
     * @type {number}
     */
    _edgeShortcutType: number;
    /**
     * @type {number}
     */
    _edgeWeakType: number;
    /**
     * @type {number}
     */
    _edgeInvisibleType: number;
    /**
     * @type {number}
     */
    _locationIndexOffset: number;
    /**
     * @type {number}
     */
    _locationScriptIdOffset: number;
    /**
     * @type {number}
     */
    _locationLineOffset: number;
    /**
     * @type {number}
     */
    _locationColumnOffset: number;
    /**
     * @type {number}
     */
    _locationFieldCount: number;
    /**
     * @type {number}
     */
    nodeCount: number;
    /**
     * @type {number}
     */
    _edgeCount: number;
    /**
     * @type {!Float64Array}
     */
    _retainedSizes: Float64Array;
    /**
     * @type {!Uint32Array}
     */
    _firstEdgeIndexes: Uint32Array;
    /**
     * @type {!Uint32Array}
     */
    _retainingNodes: Uint32Array;
    /**
     * @type {!Uint32Array}
     */
    _retainingEdges: Uint32Array;
    /**
     * @type {!Uint32Array}
     */
    _firstRetainerIndex: Uint32Array;
    /**
     * @type {!Int32Array}
     */
    _nodeDistances: Int32Array;
    /**
     * @type {!Uint32Array}
     */
    _firstDominatedNodeIndex: Uint32Array;
    /**
     * @type {!Uint32Array}
     */
    _dominatedNodes: Uint32Array;
    /**
     * @type {!Uint32Array}
     */
    _dominatorsTree: Uint32Array;
    /**
     * @type {!AllocationProfile}
     */
    _allocationProfile: AllocationProfile;
    /**
     * @type {number}
     */
    _nodeDetachednessOffset: number;
    /**
     * @type {!Map<number, !HeapSnapshotModel.HeapSnapshotModel.Location>}
     */
    _locationMap: Map<number, HeapSnapshotModel.HeapSnapshotModel.Location>;
    /**
     * @type {!Object.<string, string>}
     */
    _lazyStringCache: {
        [x: string]: string;
    };
    /**
     * @protected
     */
    protected initialize(): void;
    _buildEdgeIndexes(): void;
    _buildRetainers(): void;
    /**
     * @param {number=} nodeIndex
     * @return {!HeapSnapshotNode}
     */
    createNode(nodeIndex?: number | undefined): HeapSnapshotNode;
    /**
     * @param {number} edgeIndex
     * @return {!JSHeapSnapshotEdge}
     */
    createEdge(edgeIndex: number): JSHeapSnapshotEdge;
    /**
     * @param {number} retainerIndex
     * @return {!JSHeapSnapshotRetainerEdge}
     */
    createRetainingEdge(retainerIndex: number): JSHeapSnapshotRetainerEdge;
    /**
     * @return {!HeapSnapshotNodeIterator}
     */
    _allNodes(): HeapSnapshotNodeIterator;
    /**
     * @return {!HeapSnapshotNode}
     */
    rootNode(): HeapSnapshotNode;
    /**
     * @return {number}
     */
    get rootNodeIndex(): number;
    /**
     * @return {number}
     */
    get totalSize(): number;
    /**
     * @param {number} nodeIndex
     * @return {number}
     */
    _getDominatedIndex(nodeIndex: number): number;
    /**
     * @param {!HeapSnapshotModel.HeapSnapshotModel.NodeFilter} nodeFilter
     * @return {undefined|function(!HeapSnapshotNode):boolean}
     */
    _createFilter(nodeFilter: HeapSnapshotModel.HeapSnapshotModel.NodeFilter): undefined | ((arg0: HeapSnapshotNode) => boolean);
    /**
     * @param {!HeapSnapshotModel.HeapSnapshotModel.SearchConfig} searchConfig
     * @param {!HeapSnapshotModel.HeapSnapshotModel.NodeFilter} nodeFilter
     * @return {!Array.<number>}
     */
    search(searchConfig: HeapSnapshotModel.HeapSnapshotModel.SearchConfig, nodeFilter: HeapSnapshotModel.HeapSnapshotModel.NodeFilter): Array<number>;
    /**
     * @param {!HeapSnapshotModel.HeapSnapshotModel.NodeFilter} nodeFilter
     * @return {!Object.<string, !HeapSnapshotModel.HeapSnapshotModel.Aggregate>}
     */
    aggregatesWithFilter(nodeFilter: HeapSnapshotModel.HeapSnapshotModel.NodeFilter): {
        [x: string]: HeapSnapshotModel.HeapSnapshotModel.Aggregate;
    };
    /**
     * @param {number} minNodeId
     * @param {number} maxNodeId
     * @return {function(!HeapSnapshotNode):boolean}
     */
    _createNodeIdFilter(minNodeId: number, maxNodeId: number): (arg0: HeapSnapshotNode) => boolean;
    /**
     * @param {number} bottomUpAllocationNodeId
     * @return {undefined|function(!HeapSnapshotNode):boolean}
     */
    _createAllocationStackFilter(bottomUpAllocationNodeId: number): undefined | ((arg0: HeapSnapshotNode) => boolean);
    /**
     * @param {boolean} sortedIndexes
     * @param {string=} key
     * @param {function(!HeapSnapshotNode):boolean=} filter
     * @return {!Object.<string, !HeapSnapshotModel.HeapSnapshotModel.Aggregate>}
     */
    aggregates(sortedIndexes: boolean, key?: string | undefined, filter?: ((arg0: HeapSnapshotNode) => boolean) | undefined): {
        [x: string]: HeapSnapshotModel.HeapSnapshotModel.Aggregate;
    };
    /**
     * @return {!Array.<!HeapSnapshotModel.HeapSnapshotModel.SerializedAllocationNode>}
     */
    allocationTracesTops(): Array<HeapSnapshotModel.HeapSnapshotModel.SerializedAllocationNode>;
    /**
     * @param {number} nodeId
     * @return {!HeapSnapshotModel.HeapSnapshotModel.AllocationNodeCallers}
     */
    allocationNodeCallers(nodeId: number): HeapSnapshotModel.HeapSnapshotModel.AllocationNodeCallers;
    /**
     * @param {number} nodeIndex
     * @return {?Array.<!HeapSnapshotModel.HeapSnapshotModel.AllocationStackFrame>}
     */
    allocationStack(nodeIndex: number): Array<HeapSnapshotModel.HeapSnapshotModel.AllocationStackFrame> | null;
    /**
     * @return {!Object.<string, !HeapSnapshotModel.HeapSnapshotModel.AggregateForDiff>}
     */
    aggregatesForDiff(): {
        [x: string]: HeapSnapshotModel.HeapSnapshotModel.AggregateForDiff;
    };
    /**
     * @protected
     * @param {!HeapSnapshotNode} node
     * @return {boolean}
     */
    protected isUserRoot(node: HeapSnapshotNode): boolean;
    /**
     * @param {function(!HeapSnapshotNode,!HeapSnapshotEdge):boolean=} filter
     */
    calculateDistances(filter?: ((arg0: HeapSnapshotNode, arg1: HeapSnapshotEdge) => boolean) | undefined): void;
    /**
     * @param {!Uint32Array} nodesToVisit
     * @param {number} nodesToVisitLength
     * @param {!Int32Array} distances
     * @param {function(!HeapSnapshotNode,!HeapSnapshotEdge):boolean=} filter
     */
    _bfs(nodesToVisit: Uint32Array, nodesToVisitLength: number, distances: Int32Array, filter?: ((arg0: HeapSnapshotNode, arg1: HeapSnapshotEdge) => boolean) | undefined): void;
    /**
     * @param {function(!HeapSnapshotNode):boolean=} filter
     * @return {!{aggregatesByClassName: !Object<string, !AggregatedInfo>,
     *     aggregatesByClassIndex: !Object<number, !AggregatedInfo>}}
     */
    _buildAggregates(filter?: ((arg0: HeapSnapshotNode) => boolean) | undefined): {
        aggregatesByClassName: {
            [x: string]: AggregatedInfo;
        };
        aggregatesByClassIndex: {
            [x: number]: AggregatedInfo;
        };
    };
    /**
     * @param {!Object<number, !AggregatedInfo>} aggregates
     * @param {function(!HeapSnapshotNode):boolean=} filter
     */
    _calculateClassesRetainedSize(aggregates: {
        [x: number]: AggregatedInfo;
    }, filter?: ((arg0: HeapSnapshotNode) => boolean) | undefined): void;
    /**
     * @param {!Object<string, !AggregatedInfo>} aggregates
     */
    _sortAggregateIndexes(aggregates: {
        [x: string]: AggregatedInfo;
    }): void;
    /**
     * The function checks is the edge should be considered during building
     * postorder iterator and dominator tree.
     *
     * @param {number} nodeIndex
     * @param {number} edgeType
     * @return {boolean}
     */
    _isEssentialEdge(nodeIndex: number, edgeType: number): boolean;
    _buildPostOrderIndex(): {
        postOrderIndex2NodeOrdinal: Uint32Array;
        nodeOrdinal2PostOrderIndex: Uint32Array;
    };
    /**
     * @param {number} nodeOrdinal
     * @return {boolean}
     */
    _hasOnlyWeakRetainers(nodeOrdinal: number): boolean;
    /**
     * @param {!Uint32Array} postOrderIndex2NodeOrdinal
     * @param {!Uint32Array} nodeOrdinal2PostOrderIndex
     */
    _buildDominatorTree(postOrderIndex2NodeOrdinal: Uint32Array, nodeOrdinal2PostOrderIndex: Uint32Array): Uint32Array;
    /**
     * @param {!Uint32Array} postOrderIndex2NodeOrdinal
     */
    _calculateRetainedSizes(postOrderIndex2NodeOrdinal: Uint32Array): void;
    _buildDominatedNodes(): void;
    /**
     * Iterates children of a node.
     *
     * @param {number} nodeOrdinal The ordinal number representing the node.
     * @param {function(number):boolean} edgeFilterCallback Callback that allows for filtering edge types.
     * @param {function(number):void} childCallback Callback invoked with the ordinal number representing the child.
     */
    _iterateFilteredChildren(nodeOrdinal: number, edgeFilterCallback: (arg0: number) => boolean, childCallback: (arg0: number) => void): void;
    /**
     * Adds a string to the snapshot.
     *
     * @param {string} string added to the snapshot.
     * @returns the index to refer to the string through snapshot.strings[index].
     */
    _addString(string: string): number;
    /**
      * The phase propagates whether a node is attached or detached through the
      * graph and adjusts the low-level representation of nodes.
      *
      * State propagation:
      * 1. Any object reachable from an attached object is itself attached.
      * 2. Any object reachable from a detached object that is not already
      *    attached is considered detached.
      *
      * Representation:
      * - Name of any detached node is changed from "<Name>"" to
      *   "Detached <Name>".
      */
    _propagateDOMState(): void;
    _buildSamples(): void;
    _buildLocationMap(): void;
    /**
     * @param {number} nodeIndex
     * @return {?HeapSnapshotModel.HeapSnapshotModel.Location}
     */
    getLocation(nodeIndex: number): HeapSnapshotModel.HeapSnapshotModel.Location | null;
    /**
     * @return {?HeapSnapshotModel.HeapSnapshotModel.Samples}
     */
    getSamples(): HeapSnapshotModel.HeapSnapshotModel.Samples | null;
    /**
     * @protected
     */
    protected calculateFlags(): void;
    /**
     * @protected
     */
    protected calculateStatistics(): void;
    /**
     * @protected
     * @return {?{map: !Uint32Array, flag: number}}
     */
    protected userObjectsMapAndFlag(): {
        map: Uint32Array;
        flag: number;
    } | null;
    /**
     * @param {string} baseSnapshotId
     * @param {!Object.<string, !HeapSnapshotModel.HeapSnapshotModel.AggregateForDiff>} baseSnapshotAggregates
     * @return {!Object.<string, !HeapSnapshotModel.HeapSnapshotModel.Diff>}
     */
    calculateSnapshotDiff(baseSnapshotId: string, baseSnapshotAggregates: {
        [x: string]: HeapSnapshotModel.HeapSnapshotModel.AggregateForDiff;
    }): {
        [x: string]: HeapSnapshotModel.HeapSnapshotModel.Diff;
    };
    /**
     * @param {!HeapSnapshotModel.HeapSnapshotModel.AggregateForDiff} baseAggregate
     * @param {!HeapSnapshotModel.HeapSnapshotModel.Aggregate} aggregate
     * @return {?HeapSnapshotModel.HeapSnapshotModel.Diff}
     */
    _calculateDiffForClass(baseAggregate: HeapSnapshotModel.HeapSnapshotModel.AggregateForDiff, aggregate: HeapSnapshotModel.HeapSnapshotModel.Aggregate): HeapSnapshotModel.HeapSnapshotModel.Diff | null;
    /**
     * @param {number} snapshotObjectId
     */
    _nodeForSnapshotObjectId(snapshotObjectId: number): HeapSnapshotNode | null;
    /**
     * @param {number} snapshotObjectId
     * @return {?string}
     */
    nodeClassName(snapshotObjectId: number): string | null;
    /**
     * @param {string} name
     * @return {!Array.<number>}
     */
    idsOfObjectsWithName(name: string): Array<number>;
    /**
     * @param {number} nodeIndex
     * @return {!HeapSnapshotEdgesProvider}
     */
    createEdgesProvider(nodeIndex: number): HeapSnapshotEdgesProvider;
    /**
     * @param {number} nodeIndex
     * @param {?function(!HeapSnapshotEdge):boolean} filter
     * @return {!HeapSnapshotEdgesProvider}
     */
    createEdgesProviderForTest(nodeIndex: number, filter: ((arg0: HeapSnapshotEdge) => boolean) | null): HeapSnapshotEdgesProvider;
    /**
     * @return {?function(!HeapSnapshotEdge):boolean}
     */
    retainingEdgesFilter(): ((arg0: HeapSnapshotEdge) => boolean) | null;
    /**
     * @return {?function(!HeapSnapshotEdge):boolean}
     */
    containmentEdgesFilter(): ((arg0: HeapSnapshotEdge) => boolean) | null;
    /**
     * @param {number} nodeIndex
     * @return {!HeapSnapshotEdgesProvider}
     */
    createRetainingEdgesProvider(nodeIndex: number): HeapSnapshotEdgesProvider;
    /**
     * @param {string} baseSnapshotId
     * @param {string} className
     * @return {!HeapSnapshotNodesProvider}
     */
    createAddedNodesProvider(baseSnapshotId: string, className: string): HeapSnapshotNodesProvider;
    /**
     * @param {!Array.<number>} nodeIndexes
     * @return {!HeapSnapshotNodesProvider}
     */
    createDeletedNodesProvider(nodeIndexes: Array<number>): HeapSnapshotNodesProvider;
    /**
     * @param {string} className
     * @param {!HeapSnapshotModel.HeapSnapshotModel.NodeFilter} nodeFilter
     * @return {!HeapSnapshotNodesProvider}
     */
    createNodesProviderForClass(className: string, nodeFilter: HeapSnapshotModel.HeapSnapshotModel.NodeFilter): HeapSnapshotNodesProvider;
    /**
     * @return {number}
     */
    _maxJsNodeId(): number;
    /**
     * @return {!HeapSnapshotModel.HeapSnapshotModel.StaticData}
     */
    updateStaticData(): HeapSnapshotModel.HeapSnapshotModel.StaticData;
}
/**
 * @unrestricted
 */
export class HeapSnapshotHeader {
    title: string;
    meta: {
        /**
         * @type {!Array<string>}
         */
        location_fields: Array<string>;
        /**
         * @type {!Array<string>}
         */
        node_fields: Array<string>;
        /**
         * @type {!Array<!Array<string>>}
         */
        node_types: Array<Array<string>>;
        /**
         * @type {!Array<string>}
         */
        edge_fields: Array<string>;
        /**
         * @type {!Array<!Array<string>>}
         */
        edge_types: Array<Array<string>>;
        /**
         * @type {!Array<string>}
         */
        trace_function_info_fields: Array<string>;
        /**
         * @type {!Array<string>}
         */
        trace_node_fields: Array<string>;
        /**
         * @type {!Array<string>}
         */
        sample_fields: Array<string>;
        /**
         * @type {!Object<string, string>}
         */
        type_strings: {
            [x: string]: string;
        };
    };
    node_count: number;
    edge_count: number;
    trace_function_count: number;
    root_index: number;
}
/**
 * @unrestricted
 */
export class HeapSnapshotItemProvider {
    /**
     * @param {!HeapSnapshotItemIterator} iterator
     * @param {!HeapSnapshotItemIndexProvider} indexProvider
     */
    constructor(iterator: HeapSnapshotItemIterator, indexProvider: HeapSnapshotItemIndexProvider);
    _iterator: HeapSnapshotItemIterator;
    _indexProvider: HeapSnapshotItemIndexProvider;
    _isEmpty: boolean;
    /** @type {?Array.<number>} */
    _iterationOrder: Array<number> | null;
    _currentComparator: HeapSnapshotModel.HeapSnapshotModel.ComparatorConfig | null;
    _sortedPrefixLength: number;
    _sortedSuffixLength: number;
    _createIterationOrder(): void;
    /**
     * @return {boolean}
     */
    isEmpty(): boolean;
    /**
     * @param {number} begin
     * @param {number} end
     * @return {!HeapSnapshotModel.HeapSnapshotModel.ItemsRange}
     */
    serializeItemsRange(begin: number, end: number): HeapSnapshotModel.HeapSnapshotModel.ItemsRange;
    /**
     * @param {!HeapSnapshotModel.HeapSnapshotModel.ComparatorConfig} comparator
     */
    sortAndRewind(comparator: HeapSnapshotModel.HeapSnapshotModel.ComparatorConfig): void;
    /**
     * @param {!HeapSnapshotModel.HeapSnapshotModel.ComparatorConfig} comparator
     * @param {number} leftBound
     * @param {number} rightBound
     * @param {number} windowLeft
     * @param {number} windowRight
     */
    sort(comparator: HeapSnapshotModel.HeapSnapshotModel.ComparatorConfig, leftBound: number, rightBound: number, windowLeft: number, windowRight: number): void;
}
/**
 * @unrestricted
 */
export class HeapSnapshotEdgesProvider extends HeapSnapshotItemProvider {
    /**
     * @param {!HeapSnapshot} snapshot
     * @param {?function(!HeapSnapshotEdge):boolean} filter
     * @param {!HeapSnapshotEdgeIterator|!HeapSnapshotRetainerEdgeIterator} edgesIter
     * @param {!HeapSnapshotItemIndexProvider} indexProvider
     */
    constructor(snapshot: HeapSnapshot, filter: ((arg0: HeapSnapshotEdge) => boolean) | null, edgesIter: HeapSnapshotEdgeIterator | HeapSnapshotRetainerEdgeIterator, indexProvider: HeapSnapshotItemIndexProvider);
    snapshot: HeapSnapshot;
}
/**
 * @unrestricted
 */
export class HeapSnapshotNodesProvider extends HeapSnapshotItemProvider {
    /**
     * @param {!HeapSnapshot} snapshot
     * @param {!Array<number>|!Uint32Array} nodeIndexes
     */
    constructor(snapshot: HeapSnapshot, nodeIndexes: Array<number> | Uint32Array);
    snapshot: HeapSnapshot;
    /**
     * @param {number} snapshotObjectId
     * @return {number}
     */
    nodePosition(snapshotObjectId: number): number;
    /**
     * @param {!HeapSnapshotModel.HeapSnapshotModel.ComparatorConfig} comparator
     * @return {function(number,number):number}
     */
    _buildCompareFunction(comparator: HeapSnapshotModel.HeapSnapshotModel.ComparatorConfig): (arg0: number, arg1: number) => number;
}
/**
 * @unrestricted
 */
export class JSHeapSnapshot extends HeapSnapshot {
    /**
     * @param {!Profile} profile
     * @param {!HeapSnapshotProgress} progress
     */
    constructor(profile: Profile, progress: HeapSnapshotProgress);
    _nodeFlags: {
        canBeQueried: number;
        detachedDOMTreeNode: number;
        pageObject: number;
    };
    /** @type {!Uint32Array} */
    _flags: Uint32Array;
    /**
     * @param {!HeapSnapshotNode} node
     * @return {number}
     */
    _flagsOfNode(node: HeapSnapshotNode): number;
    _markDetachedDOMTreeNodes(): void;
    _markQueriableHeapObjects(): void;
    _markPageOwnedNodes(): void;
    _statistics: HeapSnapshotModel.HeapSnapshotModel.Statistics | undefined;
    /**
     * @param {!HeapSnapshotNode} node
     * @return {number}
     */
    _calculateArraySize(node: HeapSnapshotNode): number;
    /**
     * @return {!HeapSnapshotModel.HeapSnapshotModel.Statistics}
     */
    getStatistics(): HeapSnapshotModel.HeapSnapshotModel.Statistics;
}
/**
 * @unrestricted
 */
export class JSHeapSnapshotNode extends HeapSnapshotNode {
    /**
     * @param {!JSHeapSnapshot} snapshot
     * @param {number=} nodeIndex
     */
    constructor(snapshot: JSHeapSnapshot, nodeIndex?: number | undefined);
    /**
     * @return {boolean}
     */
    canBeQueried(): boolean;
    /**
     * @return {string}
     */
    _consStringName(): string;
    /**
     * @return {boolean}
     */
    isSynthetic(): boolean;
}
/**
 * @unrestricted
 */
export class JSHeapSnapshotEdge extends HeapSnapshotEdge {
    /**
     * @param {!JSHeapSnapshot} snapshot
     * @param {number=} edgeIndex
     */
    constructor(snapshot: JSHeapSnapshot, edgeIndex?: number | undefined);
    /**
     * @return {boolean}
     */
    isElement(): boolean;
    /**
     * @return {boolean}
     */
    isHidden(): boolean;
    /**
     * @return {boolean}
     */
    isInternal(): boolean;
    /**
     * @return {boolean}
     */
    isShortcut(): boolean;
    /**
     * @return {boolean}
     */
    _hasStringName(): boolean;
    /**
     * @return {string|number}
     */
    _name(): string | number;
    /**
     * @return {number}
     */
    _nameOrIndex(): number;
}
/**
 * @unrestricted
 */
export class JSHeapSnapshotRetainerEdge extends HeapSnapshotRetainerEdge {
    /**
     * @param {!JSHeapSnapshot} snapshot
     * @param {number} retainerIndex
     */
    constructor(snapshot: JSHeapSnapshot, retainerIndex: number);
    /**
     * @return {boolean}
     */
    isHidden(): boolean;
    /**
     * @return {boolean}
     */
    isInternal(): boolean;
    /**
     * @return {boolean}
     */
    isInvisible(): boolean;
    /**
     * @return {boolean}
     */
    isShortcut(): boolean;
    /**
     * @return {boolean}
     */
    isWeak(): boolean;
}
export type AggregatedInfo = {
    count: number;
    distance: number;
    self: number;
    maxRet: number;
    name: string | null;
    idxs: Array<number>;
};
/**
 * @typedef {!{
 *   count: number,
 *   distance: number,
 *   self: number,
 *   maxRet: number,
 *   name: ?string,
 *   idxs: !Array<number>
 * }}
 */
export let AggregatedInfo: any;
import * as HeapSnapshotModel from "../heap_snapshot_model/heap_snapshot_model.js";
import { HeapSnapshotWorkerDispatcher } from "./HeapSnapshotWorkerDispatcher.js";
import { AllocationProfile } from "./AllocationProfile.js";
