export class UserMetrics {
    _panelChangedSinceLaunch: boolean;
    _firedLaunchHistogram: boolean;
    _launchPanelName: string;
    /**
     * @param {string} contrastThreshold
     */
    colorFixed(contrastThreshold: string): void;
    /**
     * @param {string} panelName
     */
    panelShown(panelName: string): void;
    /**
     * Fired when a panel is closed (regardless if it exists in the main panel or the drawer)
     * @param {string} panelName
     */
    panelClosed(panelName: string): void;
    /**
     * @param {string} sidebarPaneName
     */
    sidebarPaneShown(sidebarPaneName: string): void;
    /**
     * @param {string} settingsViewId
     */
    settingsPanelShown(settingsViewId: string): void;
    /**
     * @param {!Action} action
     */
    actionTaken(action: Action): void;
    /**
     * @param {string} panelName
     * @param {string} histogramName
     * @suppressGlobalPropertiesCheck
     */
    panelLoaded(panelName: string, histogramName: string): void;
    /**
     * @param {?string} panelName
     */
    setLaunchPanel(panelName: string | null): void;
    /**
     * @param {string} keybindSet
     */
    keybindSetSettingChanged(keybindSet: string): void;
    /**
     * @param {string} actionId
     */
    keyboardShortcutFired(actionId: string): void;
    /**
     * @param {!IssueOpener} issueOpener
     */
    issuesPanelOpenedFrom(issueOpener: IssueOpener): void;
    /**
     * @param {string | undefined} issueExpandedCategory
     */
    issuesPanelIssueExpanded(issueExpandedCategory: string | undefined): void;
    /**
     * @param {symbol} issueCategory
     * @param {string} type
     */
    issuesPanelResourceOpened(issueCategory: symbol, type: string): void;
    /**
     * @param {!DualScreenDeviceEmulated} emulationAction
     */
    dualScreenDeviceEmulated(emulationAction: DualScreenDeviceEmulated): void;
    /**
     * @param {string} gridSettingId
     */
    cssGridSettings(gridSettingId: string): void;
    /**
     * @param {number} count The number of highlighted persistent grids
     */
    highlightedPersistentCssGridCount(count: number): void;
    /**
     * @param {string} experimentId
     */
    experimentEnabledAtLaunch(experimentId: string): void;
    /**
     * @param {string} experimentId
     * @param {boolean} isEnabled
     */
    experimentChanged(experimentId: string, isEnabled: boolean): void;
    /**
     * @param {boolean} isEnabled
     */
    computedStyleGrouping(isEnabled: boolean): void;
    /**
     * @param {!GridOverlayOpener} gridOverlayOpener
     */
    gridOverlayOpenedFrom(gridOverlayOpener: GridOverlayOpener): void;
}
export type Action = number;
/** @enum {number} */
export const Action: {
    WindowDocked: number;
    WindowUndocked: number;
    ScriptsBreakpointSet: number;
    TimelineStarted: number;
    ProfilesCPUProfileTaken: number;
    ProfilesHeapProfileTaken: number;
    'LegacyAuditsStarted-deprecated': number;
    ConsoleEvaluated: number;
    FileSavedInWorkspace: number;
    DeviceModeEnabled: number;
    AnimationsPlaybackRateChanged: number;
    RevisionApplied: number;
    FileSystemDirectoryContentReceived: number;
    StyleRuleEdited: number;
    CommandEvaluatedInConsolePanel: number;
    DOMPropertiesExpanded: number;
    ResizedViewInResponsiveMode: number;
    TimelinePageReloadStarted: number;
    ConnectToNodeJSFromFrontend: number;
    ConnectToNodeJSDirectly: number;
    CpuThrottlingEnabled: number;
    CpuProfileNodeFocused: number;
    CpuProfileNodeExcluded: number;
    SelectFileFromFilePicker: number;
    SelectCommandFromCommandMenu: number;
    ChangeInspectedNodeInElementsPanel: number;
    StyleRuleCopied: number;
    CoverageStarted: number;
    LighthouseStarted: number;
    LighthouseFinished: number;
    ShowedThirdPartyBadges: number;
    LighthouseViewTrace: number;
    FilmStripStartedRecording: number;
    CoverageReportFiltered: number;
    CoverageStartedPerBlock: number;
    'SettingsOpenedFromGear-deprecated': number;
    'SettingsOpenedFromMenu-deprecated': number;
    'SettingsOpenedFromCommandMenu-deprecated': number;
    TabMovedToDrawer: number;
    TabMovedToMainPanel: number;
    CaptureCssOverviewClicked: number;
    VirtualAuthenticatorEnvironmentEnabled: number;
    SourceOrderViewActivated: number;
    UserShortcutAdded: number;
    ShortcutRemoved: number;
    ShortcutModified: number;
};
/** @type {!Object<string, number>} */
export const ContrastThresholds: {
    [x: string]: number;
};
/** @type {!Object<string, number>} */
export const PanelCodes: {
    [x: string]: number;
};
/** @type {!Object<string, number>} */
export const SidebarPaneCodes: {
    [x: string]: number;
};
/** @type {!Object<string, number>} */
export const KeybindSetSettings: {
    [x: string]: number;
};
/** @type {!Object<string, number>} */
export const KeyboardShortcutAction: {
    [x: string]: number;
};
export type IssueOpener = number;
export namespace IssueOpener {
    const ConsoleInfoBar: number;
    const LearnMoreLinkCOEP: number;
    const StatusBarIssuesCounter: number;
    const HamburgerMenu: number;
    const Adorner: number;
}
export type DualScreenDeviceEmulated = number;
export namespace DualScreenDeviceEmulated {
    const DualScreenDeviceSelected: number;
    const SpanButtonClicked: number;
    const PlatformSupportUsed: number;
}
/** @type {!Object<string, number>} */
export const CSSGridSettings: {
    [x: string]: number;
};
export const HighlightedPersistentCSSGridCount: {
    threshold: number;
    code: number;
}[];
/**
 * This list should contain the currently active Devtools Experiments.
 * Therefore, it is possible that the id's will no longer be continuous
 * as experiemnts are removed.
 * When adding a new experiemnt:
 * 1. Add an entry to the bottom of the list before '__lastValidEnumPosition'
 * 2. Set the value of the new entry and '__lastValidEnumPosition' to
 *    __lastValidEnumPosition + 1
 * When removing an experiment, simply delete the line from the enum.
 */
/** @type {!Object<string, number>} */
export const DevtoolsExperiments: {
    [x: string]: number;
};
/** @type {!Object<string, number>} */
export const ComputedStyleGroupingState: {
    [x: string]: number;
};
/** @type {!Object<string, number>} */
export const IssueExpanded: {
    [x: string]: number;
};
/** @type {!Object<string, number>} */
export const IssueResourceOpened: {
    [x: string]: number;
};
export type GridOverlayOpener = number;
export namespace GridOverlayOpener {
    const Adorner_1: number;
    export { Adorner_1 as Adorner };
    export const LayoutPane: number;
}
