import { StringOutputStream, ParsedURL, UIString, Console, ObjectWrapper, Settings, EventTarget } from '../common/common.js';
import { StringUtilities } from '../platform/platform.js';
import { Runtime } from '../root/root.js';

// Copyright (c) 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
/** @enum {symbol} */
const Events = {
    AppendedToURL: Symbol('appendedToURL'),
    CanceledSaveURL: Symbol('canceledSaveURL'),
    ContextMenuCleared: Symbol('contextMenuCleared'),
    ContextMenuItemSelected: Symbol('contextMenuItemSelected'),
    DeviceCountUpdated: Symbol('deviceCountUpdated'),
    DevicesDiscoveryConfigChanged: Symbol('devicesDiscoveryConfigChanged'),
    DevicesPortForwardingStatusChanged: Symbol('devicesPortForwardingStatusChanged'),
    DevicesUpdated: Symbol('devicesUpdated'),
    DispatchMessage: Symbol('dispatchMessage'),
    DispatchMessageChunk: Symbol('dispatchMessageChunk'),
    EnterInspectElementMode: Symbol('enterInspectElementMode'),
    EyeDropperPickedColor: Symbol('eyeDropperPickedColor'),
    FileSystemsLoaded: Symbol('fileSystemsLoaded'),
    FileSystemRemoved: Symbol('fileSystemRemoved'),
    FileSystemAdded: Symbol('fileSystemAdded'),
    FileSystemFilesChangedAddedRemoved: Symbol('FileSystemFilesChangedAddedRemoved'),
    IndexingTotalWorkCalculated: Symbol('indexingTotalWorkCalculated'),
    IndexingWorked: Symbol('indexingWorked'),
    IndexingDone: Symbol('indexingDone'),
    KeyEventUnhandled: Symbol('keyEventUnhandled'),
    ReattachMainTarget: Symbol('reattachMainTarget'),
    ReloadInspectedPage: Symbol('reloadInspectedPage'),
    RevealSourceLine: Symbol('revealSourceLine'),
    SavedURL: Symbol('savedURL'),
    SearchCompleted: Symbol('searchCompleted'),
    SetInspectedTabId: Symbol('setInspectedTabId'),
    SetUseSoftMenu: Symbol('setUseSoftMenu'),
    ShowPanel: Symbol('showPanel')
};
const EventDescriptors = [
    [Events.AppendedToURL, 'appendedToURL', ['url']],
    [Events.CanceledSaveURL, 'canceledSaveURL', ['url']],
    [Events.ContextMenuCleared, 'contextMenuCleared', []],
    [Events.ContextMenuItemSelected, 'contextMenuItemSelected', ['id']],
    [Events.DeviceCountUpdated, 'deviceCountUpdated', ['count']],
    [Events.DevicesDiscoveryConfigChanged, 'devicesDiscoveryConfigChanged', ['config']],
    [Events.DevicesPortForwardingStatusChanged, 'devicesPortForwardingStatusChanged', ['status']],
    [Events.DevicesUpdated, 'devicesUpdated', ['devices']],
    [Events.DispatchMessage, 'dispatchMessage', ['messageObject']],
    [Events.DispatchMessageChunk, 'dispatchMessageChunk', ['messageChunk', 'messageSize']],
    [Events.EnterInspectElementMode, 'enterInspectElementMode', []],
    [Events.EyeDropperPickedColor, 'eyeDropperPickedColor', ['color']],
    [Events.FileSystemsLoaded, 'fileSystemsLoaded', ['fileSystems']],
    [Events.FileSystemRemoved, 'fileSystemRemoved', ['fileSystemPath']],
    [Events.FileSystemAdded, 'fileSystemAdded', ['errorMessage', 'fileSystem']],
    [Events.FileSystemFilesChangedAddedRemoved, 'fileSystemFilesChangedAddedRemoved', ['changed', 'added', 'removed']],
    [Events.IndexingTotalWorkCalculated, 'indexingTotalWorkCalculated', ['requestId', 'fileSystemPath', 'totalWork']],
    [Events.IndexingWorked, 'indexingWorked', ['requestId', 'fileSystemPath', 'worked']],
    [Events.IndexingDone, 'indexingDone', ['requestId', 'fileSystemPath']],
    [Events.KeyEventUnhandled, 'keyEventUnhandled', ['event']],
    [Events.ReattachMainTarget, 'reattachMainTarget', []],
    [Events.ReloadInspectedPage, 'reloadInspectedPage', ['hard']],
    [Events.RevealSourceLine, 'revealSourceLine', ['url', 'lineNumber', 'columnNumber']],
    [Events.SavedURL, 'savedURL', ['url', 'fileSystemPath']],
    [Events.SearchCompleted, 'searchCompleted', ['requestId', 'fileSystemPath', 'files']],
    [Events.SetInspectedTabId, 'setInspectedTabId', ['tabId']],
    [Events.SetUseSoftMenu, 'setUseSoftMenu', ['useSoftMenu']],
    [Events.ShowPanel, 'showPanel', ['panelName']]
];
/** @interface */
class InspectorFrontendHostAPI {
    /**
     * @param {string=} type
     */
    addFileSystem(type) {
    }
    loadCompleted() {
    }
    /**
     * @param {number} requestId
     * @param {string} fileSystemPath
     * @param {string} excludedFolders
     */
    indexPath(requestId, fileSystemPath, excludedFolders) {
    }
    /**
     * Requests inspected page to be placed atop of the inspector frontend with specified bounds.
     * @param {{x: number, y: number, width: number, height: number}} bounds
     */
    setInspectedPageBounds(bounds) {
    }
    /**
     * @param {!Array<string>} certChain
     */
    showCertificateViewer(certChain) {
    }
    /**
     * @param {string} shortcuts
     */
    setWhitelistedShortcuts(shortcuts) {
    }
    /**
     * @param {boolean} active
     */
    setEyeDropperActive(active) {
    }
    inspectElementCompleted() {
    }
    /**
     * @param {string} url
     */
    openInNewTab(url) {
    }
    /**
     * @param {string} fileSystemPath
     */
    showItemInFolder(fileSystemPath) {
    }
    /**
     * @param {string} fileSystemPath
     */
    removeFileSystem(fileSystemPath) {
    }
    requestFileSystems() {
    }
    /**
     * @param {string} url
     * @param {string} content
     * @param {boolean} forceSaveAs
     */
    save(url, content, forceSaveAs) {
    }
    /**
     * @param {string} url
     * @param {string} content
     */
    append(url, content) {
    }
    /**
     * @param {string} url
     */
    close(url) {
    }
    /**
     * @param {number} requestId
     * @param {string} fileSystemPath
     * @param {string} query
     */
    searchInPath(requestId, fileSystemPath, query) {
    }
    /**
     * @param {number} requestId
     */
    stopIndexing(requestId) {
    }
    bringToFront() {
    }
    closeWindow() {
    }
    /**
     * @param {?(string|undefined)} text
     */
    copyText(text) {
    }
    /**
     * @param {string} url
     */
    inspectedURLChanged(url) {
    }
    /**
     * @param {string} fileSystemId
     * @param {string} registeredName
     * @return {?FileSystem}
     */
    isolatedFileSystem(fileSystemId, registeredName) {
        throw new Error('not implemented');
    }
    /**
     * @param {string} url
     * @param {string} headers
     * @param {number} streamId
     * @param {function(!LoadNetworkResourceResult):void} callback
     */
    loadNetworkResource(url, headers, streamId, callback) {
    }
    /**
     * @param {function(!Object<string, string>):void} callback
     */
    getPreferences(callback) {
    }
    /**
     * @param {string} name
     * @param {string} value
     */
    setPreference(name, value) {
    }
    /**
     * @param {string} name
     */
    removePreference(name) {
    }
    clearPreferences() {
    }
    /**
     * @param {!FileSystem} fileSystem
     */
    upgradeDraggedFileSystemPermissions(fileSystem) {
    }
    /**
     * @return {string}
     */
    platform() {
        throw new Error('Not implemented');
    }
    /**
     * @param {!EnumeratedHistogram} actionName
     * @param {number} actionCode
     * @param {number} bucketSize
     */
    recordEnumeratedHistogram(actionName, actionCode, bucketSize) {
    }
    /**
     * @param {string} histogramName
     * @param {number} duration
     */
    recordPerformanceHistogram(histogramName, duration) {
    }
    /**
     * @param {string} umaName
     */
    recordUserMetricsAction(umaName) {
    }
    /**
     * @param {string} message
     */
    sendMessageToBackend(message) {
    }
    /**
     * @param {!Adb.Config} config
     */
    setDevicesDiscoveryConfig(config) {
    }
    /**
     * @param {boolean} enabled
     */
    setDevicesUpdatesEnabled(enabled) {
    }
    /**
     * @param {string} pageId
     * @param {string} action
     */
    performActionOnRemotePage(pageId, action) {
    }
    /**
     * @param {string} browserId
     * @param {string} url
     */
    openRemotePage(browserId, url) {
    }
    openNodeFrontend() {
    }
    /**
     * @param {string} origin
     * @param {string} script
     */
    setInjectedScriptForOrigin(origin, script) {
    }
    /**
     * @param {boolean} isDocked
     * @param {function():void} callback
     */
    setIsDocked(isDocked, callback) {
    }
    /**
     * @return {number}
     */
    zoomFactor() {
        throw new Error('Not implemented');
    }
    zoomIn() {
    }
    zoomOut() {
    }
    resetZoom() {
    }
    /**
     * @param {number} x
     * @param {number} y
     * @param {!Array.<!ContextMenuDescriptor>} items
     * @param {!Document} document
     */
    showContextMenuAtPoint(x, y, items, document) {
    }
    /**
     * @param {function():void} callback
     */
    reattach(callback) {
    }
    readyForTest() {
    }
    connectionReady() {
    }
    /**
     * @param {boolean} value
     */
    setOpenNewWindowForPopups(value) {
    }
    /**
     * @return {boolean}
     */
    isHostedMode() {
        throw new Error('Not implemented');
    }
    /**
     * @param {function(!Root.Runtime.RuntimeExtensionDescriptor):void} callback
     */
    setAddExtensionCallback(callback) {
    }
}
/** @typedef
{{
    type: string,
    id: (number|undefined),
    label: (string|undefined),
    enabled: (boolean|undefined),
    checked: (boolean|undefined),
    subItems: (!Array.<!ContextMenuDescriptor>|undefined)
}} */
// @ts-ignore typedef
let ContextMenuDescriptor;
/** @typedef
{{
    statusCode: number,
    headers: (!Object.<string, string>|undefined),
    netError: (number|undefined),
    netErrorName: (string|undefined),
    urlValid: (boolean|undefined),
    messageOverride: (string|undefined)
}} */
// @ts-ignore typedef
let LoadNetworkResourceResult;
/** @typedef
{{
  startPage: string,
  name: string,
  exposeExperimentalAPIs: boolean
}} */
// @ts-ignore typedef
let ExtensionDescriptor;
/**
 * Enum for recordPerformanceHistogram
 * Warning: There are two other definitions of this enum in the DevTools code
 * base, keep them in sync:
 * front_end/extern.js
 * front_end/devtools_compatibility.js
 * @readonly
 * @enum {string}
 */
const EnumeratedHistogram = {
    ActionTaken: 'DevTools.ActionTaken',
    ColorPickerFixedColor: 'DevTools.ColorPicker.FixedColor',
    PanelClosed: 'DevTools.PanelClosed',
    PanelShown: 'DevTools.PanelShown',
    SidebarPaneShown: 'DevTools.SidebarPaneShown',
    KeyboardShortcutFired: 'DevTools.KeyboardShortcutFired',
    IssuesPanelIssueExpanded: 'DevTools.IssuesPanelIssueExpanded',
    IssuesPanelOpenedFrom: 'DevTools.IssuesPanelOpenedFrom',
    IssuesPanelResourceOpened: 'DevTools.IssuesPanelResourceOpened',
    KeybindSetSettingChanged: 'DevTools.KeybindSetSettingChanged',
    DualScreenDeviceEmulated: 'DevTools.DualScreenDeviceEmulated',
    CSSGridSettings: 'DevTools.CSSGridSettings2',
    HighlightedPersistentCSSGridCount: 'DevTools.HighlightedPersistentCSSGridCount',
    ExperimentEnabledAtLaunch: 'DevTools.ExperimentEnabledAtLaunch',
    ExperimentEnabled: 'DevTools.ExperimentEnabled',
    ExperimentDisabled: 'DevTools.ExperimentDisabled',
    ComputedStyleGrouping: 'DevTools.ComputedStyleGrouping',
    GridOverlayOpenedFrom: 'DevTools.GridOverlayOpenedFrom',
};

var InspectorFrontendHostAPI$1 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  Events: Events,
  EventDescriptors: EventDescriptors,
  InspectorFrontendHostAPI: InspectorFrontendHostAPI,
  ContextMenuDescriptor: ContextMenuDescriptor,
  LoadNetworkResourceResult: LoadNetworkResourceResult,
  ExtensionDescriptor: ExtensionDescriptor,
  EnumeratedHistogram: EnumeratedHistogram
});

// Copyright (c) 2015 The Chromium Authors. All rights reserved.
const ResourceLoader = {};
let _lastStreamId = 0;
/** @type {!Object.<number, !Common.StringOutputStream.OutputStream>} */
const _boundStreams = {};
/**
 * @param {!Common.StringOutputStream.OutputStream} stream
 * @return {number}
 */
const _bindOutputStream = function (stream) {
    _boundStreams[++_lastStreamId] = stream;
    return _lastStreamId;
};
/**
 * @param {number} id
 */
const _discardOutputStream = function (id) {
    _boundStreams[id].close();
    delete _boundStreams[id];
};
/**
 * @param {number} id
 * @param {string} chunk
 */
const streamWrite = function (id, chunk) {
    _boundStreams[id].write(chunk);
};
/** @typedef
{{
    statusCode: number,
    netError: (number|undefined),
    netErrorName: (string|undefined),
    urlValid: (boolean|undefined),
    message: (string|undefined)
}} */
// @ts-ignore typedef.
let LoadErrorDescription;
/**
 * @param {string} url
 * @param {?Object.<string, string>} headers
 * @param {function(boolean, !Object.<string, string>, string, !LoadErrorDescription):void} callback
 */
let load = function (url, headers, callback) {
    const stream = new StringOutputStream.StringOutputStream();
    loadAsStream(url, headers, stream, mycallback);
    /**
     * @param {boolean} success
     * @param {!Object.<string, string>} headers
     * @param {!LoadErrorDescription} errorDescription
     */
    function mycallback(success, headers, errorDescription) {
        callback(success, headers, stream.data(), errorDescription);
    }
};
/**
 * @param {function(string, ?Object<string, string>, function(boolean, !Object<string, string>, string, !LoadErrorDescription): void): void} newLoad
 */
function setLoadForTest(newLoad) {
    load = newLoad;
}
/**
 * @param {number} netError
 * Keep this function in sync with `net_error_list.h` on the Chromium side.
 * @returns {string}
 */
function getNetErrorCategory(netError) {
    if (netError > -100) {
        return ls `System error`;
    }
    if (netError > -200) {
        return ls `Connection error`;
    }
    if (netError > -300) {
        return ls `Certificate error`;
    }
    if (netError > -400) {
        return ls `HTTP error`;
    }
    if (netError > -500) {
        return ls `Cache error`;
    }
    if (netError > -600) {
        return ls `Signed Exchange error`;
    }
    if (netError > -700) {
        return ls `FTP error`;
    }
    if (netError > -800) {
        return ls `Certificate manager error`;
    }
    if (netError > -900) {
        return ls `DNS resolver error`;
    }
    return ls `Unknown error`;
}
/**
 * @param {number} netError
 * @returns {boolean}
 */
function isHTTPError(netError) {
    return netError <= -300 && netError > -400;
}
/**
 *
 * @param {number|undefined} netError
 * @param {number|undefined} httpStatusCode
 * @param {string|undefined} netErrorName
 */
function netErrorToMessage(netError, httpStatusCode, netErrorName) {
    if (netError === undefined || httpStatusCode === undefined || netErrorName === undefined) {
        return null;
    }
    if (netError !== 0) {
        if (isHTTPError(netError)) {
            return ls `HTTP error: status code ${httpStatusCode}, ${netErrorName}`;
        }
        const errorCategory = getNetErrorCategory(netError);
        // We don't localize here, as `errorCategory` is already localized,
        // and `netErrorName` is an error code like 'net::ERR_CERT_AUTHORITY_INVALID'.
        return `${errorCategory}: ${netErrorName}`;
    }
    return null;
}
/**
 * @param {!LoadNetworkResourceResult} response
 * @returns {!{success:boolean, description: !LoadErrorDescription}}
 */
function createErrorMessageFromResponse(response) {
    const { statusCode, netError, netErrorName, urlValid, messageOverride } = response;
    let message = '';
    const success = statusCode >= 200 && statusCode < 300;
    if (typeof messageOverride === 'string') {
        message = messageOverride;
    }
    else if (!success) {
        if (typeof netError === 'undefined') {
            if (urlValid === false) {
                message = ls `Invalid URL`;
            }
            else {
                message = ls `Unknown error`;
            }
        }
        else {
            const maybeMessage = netErrorToMessage(netError, statusCode, netErrorName);
            if (maybeMessage) {
                message = maybeMessage;
            }
        }
    }
    console.assert(success === (message.length === 0));
    return { success, description: { statusCode, netError, netErrorName, urlValid, message } };
}
/**
 * @param {string} url
 * @return {!Promise<string>}
 */
const loadXHR = url => {
    return new Promise((successCallback, failureCallback) => {
        function onReadyStateChanged() {
            if (xhr.readyState !== XMLHttpRequest.DONE) {
                return;
            }
            if (xhr.status !== 200) {
                xhr.onreadystatechange = null;
                failureCallback(new Error(String(xhr.status)));
                return;
            }
            xhr.onreadystatechange = null;
            successCallback(xhr.responseText);
        }
        const xhr = new XMLHttpRequest();
        xhr.withCredentials = false;
        xhr.open('GET', url, true);
        xhr.onreadystatechange = onReadyStateChanged;
        xhr.send(null);
    });
};
/**
 * @param {string} url
 * @param {?Object.<string, string>} headers
 * @param {!Common.StringOutputStream.OutputStream} stream
 * @param {function(boolean, !Object.<string, string>, !LoadErrorDescription):void=} callback
 */
const loadAsStream = function (url, headers, stream, callback) {
    const streamId = _bindOutputStream(stream);
    const parsedURL = new ParsedURL.ParsedURL(url);
    if (parsedURL.isDataURL()) {
        loadXHR(url).then(dataURLDecodeSuccessful).catch(dataURLDecodeFailed);
        return;
    }
    const rawHeaders = [];
    if (headers) {
        for (const key in headers) {
            rawHeaders.push(key + ': ' + headers[key]);
        }
    }
    InspectorFrontendHostInstance.loadNetworkResource(url, rawHeaders.join('\r\n'), streamId, finishedCallback);
    /**
     * @param {!LoadNetworkResourceResult} response
     */
    function finishedCallback(response) {
        if (callback) {
            const { success, description } = createErrorMessageFromResponse(response);
            callback(success, response.headers || {}, description);
        }
        _discardOutputStream(streamId);
    }
    /**
     * @param {string} text
     */
    function dataURLDecodeSuccessful(text) {
        streamWrite(streamId, text);
        finishedCallback(/** @type {!LoadNetworkResourceResult} */ ({ statusCode: 200 }));
    }
    /**
     * @param {*} xhrStatus
     */
    function dataURLDecodeFailed(xhrStatus) {
        const messageOverride = ls `Decoding Data URL failed`;
        finishedCallback(
        /** @type {!LoadNetworkResourceResult} */ ({ statusCode: 404, messageOverride }));
    }
};

var ResourceLoader$1 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  ResourceLoader: ResourceLoader,
  streamWrite: streamWrite,
  LoadErrorDescription: LoadErrorDescription,
  get load () { return load; },
  setLoadForTest: setLoadForTest,
  netErrorToMessage: netErrorToMessage,
  loadAsStream: loadAsStream
});

/*
 * Copyright (C) 2009 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/**
 * @implements {InspectorFrontendHostAPI}
 * @unrestricted
 */
class InspectorFrontendHostStub {
    /**
     * @suppressGlobalPropertiesCheck
     */
    constructor() {
        /**
         * @param {!KeyboardEvent} event
         * @this {InspectorFrontendHostAPI}
         */
        function stopEventPropagation(event) {
            // Let browser handle Ctrl+/Ctrl- shortcuts in hosted mode.
            const zoomModifier = this.platform() === 'mac' ? event.metaKey : event.ctrlKey;
            if (zoomModifier && (event.keyCode === 187 || event.keyCode === 189)) {
                event.stopPropagation();
            }
        }
        document.addEventListener('keydown', event => {
            stopEventPropagation.call(this, /** @type {!KeyboardEvent} */ (event));
        }, true);
        /**
         * @type {!Map<string, !Array<string>>}
         */
        this._urlsBeingSaved = new Map();
        /**
         * @type {!Common.EventTarget.EventTarget}
         */
        this.events;
    }
    /**
     * @override
     * @return {string}
     */
    platform() {
        let match = navigator.userAgent.match(/Windows NT/);
        if (match) {
            return 'windows';
        }
        match = navigator.userAgent.match(/Mac OS X/);
        if (match) {
            return 'mac';
        }
        return 'linux';
    }
    /**
     * @override
     */
    loadCompleted() {
    }
    /**
     * @override
     */
    bringToFront() {
        this._windowVisible = true;
    }
    /**
     * @override
     */
    closeWindow() {
        this._windowVisible = false;
    }
    /**
     * @override
     * @param {boolean} isDocked
     * @param {function():void} callback
     */
    setIsDocked(isDocked, callback) {
        setTimeout(callback, 0);
    }
    /**
     * Requests inspected page to be placed atop of the inspector frontend with specified bounds.
     * @override
     * @param {{x: number, y: number, width: number, height: number}} bounds
     */
    setInspectedPageBounds(bounds) {
    }
    /**
     * @override
     */
    inspectElementCompleted() {
    }
    /**
     * @override
     * @param {string} origin
     * @param {string} script
     */
    setInjectedScriptForOrigin(origin, script) {
    }
    /**
     * @override
     * @param {string} url
     * @suppressGlobalPropertiesCheck
     */
    inspectedURLChanged(url) {
        document.title = UIString.UIString('DevTools - %s', url.replace(/^https?:\/\//, ''));
    }
    /**
     * @override
     * @param {?(string|undefined)} text
     * @suppressGlobalPropertiesCheck
     */
    copyText(text) {
        if (text === undefined || text === null) {
            return;
        }
        if (navigator.clipboard) {
            navigator.clipboard.writeText(text);
        }
        else if (document.queryCommandSupported('copy')) {
            const input = document.createElement('input');
            input.value = text;
            document.body.appendChild(input);
            input.select();
            document.execCommand('copy');
            document.body.removeChild(input);
        }
        else {
            Console.Console.instance().error('Clipboard is not enabled in hosted mode. Please inspect using chrome://inspect');
        }
    }
    /**
     * @override
     * @param {string} url
     */
    openInNewTab(url) {
        window.open(url, '_blank');
    }
    /**
     * @override
     * @param {string} fileSystemPath
     */
    showItemInFolder(fileSystemPath) {
        Console.Console.instance().error('Show item in folder is not enabled in hosted mode. Please inspect using chrome://inspect');
    }
    /**
     * @override
     * @param {string} url
     * @param {string} content
     * @param {boolean} forceSaveAs
     */
    save(url, content, forceSaveAs) {
        let buffer = this._urlsBeingSaved.get(url);
        if (!buffer) {
            buffer = [];
            this._urlsBeingSaved.set(url, buffer);
        }
        buffer.push(content);
        this.events.dispatchEventToListeners(Events.SavedURL, { url, fileSystemPath: url });
    }
    /**
     * @override
     * @param {string} url
     * @param {string} content
     */
    append(url, content) {
        const buffer = this._urlsBeingSaved.get(url);
        if (buffer) {
            buffer.push(content);
            this.events.dispatchEventToListeners(Events.AppendedToURL, url);
        }
    }
    /**
     * @override
     * @param {string} url
     */
    close(url) {
        const buffer = this._urlsBeingSaved.get(url) || [];
        this._urlsBeingSaved.delete(url);
        let fileName = '';
        if (url) {
            const trimmed = StringUtilities.trimURL(url);
            fileName = StringUtilities.removeURLFragment(trimmed);
        }
        const link = document.createElement('a');
        link.download = fileName;
        const blob = new Blob([buffer.join('')], { type: 'text/plain' });
        const blobUrl = URL.createObjectURL(blob);
        link.href = blobUrl;
        link.click();
        URL.revokeObjectURL(blobUrl);
    }
    /**
     * @override
     * @param {string} message
     */
    sendMessageToBackend(message) {
    }
    /**
     * @override
     * @param {!EnumeratedHistogram} actionName
     * @param {number} actionCode
     * @param {number} bucketSize
     */
    recordEnumeratedHistogram(actionName, actionCode, bucketSize) {
    }
    /**
     * @override
     * @param {string} histogramName
     * @param {number} duration
     */
    recordPerformanceHistogram(histogramName, duration) {
    }
    /**
     * @override
     * @param {string} umaName
     */
    recordUserMetricsAction(umaName) {
    }
    /**
     * @override
     */
    requestFileSystems() {
        this.events.dispatchEventToListeners(Events.FileSystemsLoaded, []);
    }
    /**
     * @override
     * @param {string=} type
     */
    addFileSystem(type) {
    }
    /**
     * @override
     * @param {string} fileSystemPath
     */
    removeFileSystem(fileSystemPath) {
    }
    /**
     * @override
     * @param {string} fileSystemId
     * @param {string} registeredName
     * @return {?FileSystem}
     */
    isolatedFileSystem(fileSystemId, registeredName) {
        return null;
    }
    /**
     * @override
     * @param {string} url
     * @param {string} headers
     * @param {number} streamId
     * @param {function(!LoadNetworkResourceResult):void} callback
     */
    loadNetworkResource(url, headers, streamId, callback) {
        Runtime.loadResourcePromise(url)
            .then(function (text) {
            streamWrite(streamId, text);
            callback({
                statusCode: 200,
                headers: undefined,
                messageOverride: undefined,
                netError: undefined,
                netErrorName: undefined,
                urlValid: undefined
            });
        })
            .catch(function () {
            callback({
                statusCode: 404,
                headers: undefined,
                messageOverride: undefined,
                netError: undefined,
                netErrorName: undefined,
                urlValid: undefined
            });
        });
    }
    /**
     * @override
     * @param {function(!Object<string, string>):void} callback
     */
    getPreferences(callback) {
        /** @type {!Object<string, string>} */
        const prefs = {};
        for (const name in window.localStorage) {
            prefs[name] = window.localStorage[name];
        }
        callback(prefs);
    }
    /**
     * @override
     * @param {string} name
     * @param {string} value
     */
    setPreference(name, value) {
        window.localStorage[name] = value;
    }
    /**
     * @override
     * @param {string} name
     */
    removePreference(name) {
        delete window.localStorage[name];
    }
    /**
     * @override
     */
    clearPreferences() {
        window.localStorage.clear();
    }
    /**
     * @override
     * @param {!FileSystem} fileSystem
     */
    upgradeDraggedFileSystemPermissions(fileSystem) {
    }
    /**
     * @override
     * @param {number} requestId
     * @param {string} fileSystemPath
     * @param {string} excludedFolders
     */
    indexPath(requestId, fileSystemPath, excludedFolders) {
    }
    /**
     * @override
     * @param {number} requestId
     */
    stopIndexing(requestId) {
    }
    /**
     * @override
     * @param {number} requestId
     * @param {string} fileSystemPath
     * @param {string} query
     */
    searchInPath(requestId, fileSystemPath, query) {
    }
    /**
     * @override
     * @return {number}
     */
    zoomFactor() {
        return 1;
    }
    /**
     * @override
     */
    zoomIn() {
    }
    /**
     * @override
     */
    zoomOut() {
    }
    /**
     * @override
     */
    resetZoom() {
    }
    /**
     * @override
     * @param {string} shortcuts
     */
    setWhitelistedShortcuts(shortcuts) {
    }
    /**
     * @override
     * @param {boolean} active
     */
    setEyeDropperActive(active) {
    }
    /**
     * @param {!Array<string>} certChain
     * @override
     */
    showCertificateViewer(certChain) {
    }
    /**
     * @override
     * @param {function():void} callback
     */
    reattach(callback) {
    }
    /**
     * @override
     */
    readyForTest() {
    }
    /**
     * @override
     */
    connectionReady() {
    }
    /**
     * @override
     * @param {boolean} value
     */
    setOpenNewWindowForPopups(value) {
    }
    /**
     * @override
     * @param {!Adb.Config} config
     */
    setDevicesDiscoveryConfig(config) {
    }
    /**
     * @override
     * @param {boolean} enabled
     */
    setDevicesUpdatesEnabled(enabled) {
    }
    /**
     * @override
     * @param {string} pageId
     * @param {string} action
     */
    performActionOnRemotePage(pageId, action) {
    }
    /**
     * @override
     * @param {string} browserId
     * @param {string} url
     */
    openRemotePage(browserId, url) {
    }
    /**
     * @override
     */
    openNodeFrontend() {
    }
    /**
     * @override
     * @param {number} x
     * @param {number} y
     * @param {!Array.<!ContextMenuDescriptor>} items
     * @param {!Document} document
     */
    showContextMenuAtPoint(x, y, items, document) {
        throw 'Soft context menu should be used';
    }
    /**
     * @override
     * @return {boolean}
     */
    isHostedMode() {
        return true;
    }
    /**
     * @override
     * @param {function(!Root.Runtime.RuntimeExtensionDescriptor):void} callback
     */
    setAddExtensionCallback(callback) {
        // Extensions are not supported in hosted mode.
    }
}
/**
 * @type {!InspectorFrontendHostStub}
 */
// @ts-ignore Global injected by devtools-compatibility.js
let InspectorFrontendHostInstance = window.InspectorFrontendHost;
/**
 * @unrestricted
 */
class InspectorFrontendAPIImpl {
    constructor() {
        this._debugFrontend = (!!Runtime.Runtime.queryParam('debugFrontend')) ||
            // @ts-ignore Compatibility hacks
            (window['InspectorTest'] && window['InspectorTest']['debugTest']);
        const descriptors = EventDescriptors;
        for (let i = 0; i < descriptors.length; ++i) {
            // @ts-ignore Dispatcher magic
            this[descriptors[i][1]] = this._dispatch.bind(this, descriptors[i][0], descriptors[i][2], descriptors[i][3]);
        }
    }
    /**
     * @param {symbol} name
     * @param {!Array.<string>} signature
     * @param {boolean} runOnceLoaded
     */
    _dispatch(name, signature, runOnceLoaded) {
        const params = Array.prototype.slice.call(arguments, 3);
        if (this._debugFrontend) {
            setTimeout(() => innerDispatch(), 0);
        }
        else {
            innerDispatch();
        }
        function innerDispatch() {
            // Single argument methods get dispatched with the param.
            if (signature.length < 2) {
                try {
                    InspectorFrontendHostInstance.events.dispatchEventToListeners(name, params[0]);
                }
                catch (e) {
                    console.error(e + ' ' + e.stack);
                }
                return;
            }
            /** @type {!Object<string, string>} */
            const data = {};
            for (let i = 0; i < signature.length; ++i) {
                data[signature[i]] = params[i];
            }
            try {
                InspectorFrontendHostInstance.events.dispatchEventToListeners(name, data);
            }
            catch (e) {
                console.error(e + ' ' + e.stack);
            }
        }
    }
    /**
     * @param {number} id
     * @param {string} chunk
     */
    streamWrite(id, chunk) {
        streamWrite(id, chunk);
    }
}
(function () {
    function initializeInspectorFrontendHost() {
        /** @type {*} */
        let proto;
        if (!InspectorFrontendHostInstance) {
            // Instantiate stub for web-hosted mode if necessary.
            // @ts-ignore Global injected by devtools-compatibility.js
            window.InspectorFrontendHost = InspectorFrontendHostInstance = new InspectorFrontendHostStub();
        }
        else {
            // Otherwise add stubs for missing methods that are declared in the interface.
            proto = InspectorFrontendHostStub.prototype;
            for (const name of Object.getOwnPropertyNames(proto)) {
                const stub = proto[name];
                // @ts-ignore Global injected by devtools-compatibility.js
                if (typeof stub !== 'function' || InspectorFrontendHostInstance[name]) {
                    continue;
                }
                console.error('Incompatible embedder: method Host.InspectorFrontendHost.' + name + ' is missing. Using stub instead.');
                // @ts-ignore Global injected by devtools-compatibility.js
                InspectorFrontendHostInstance[name] = stub;
            }
        }
        // Attach the events object.
        InspectorFrontendHostInstance.events = new ObjectWrapper.ObjectWrapper();
    }
    // FIXME: This file is included into both apps, since the devtools_app needs the InspectorFrontendHostAPI only,
    // so the host instance should not initialized there.
    initializeInspectorFrontendHost();
    // @ts-ignore Global injected by devtools-compatibility.js
    window.InspectorFrontendAPI = new InspectorFrontendAPIImpl();
})();
/**
 * @param {!Object<string, string>=} prefs
 * @return {boolean}
 */
function isUnderTest(prefs) {
    // Integration tests rely on test queryParam.
    if (Runtime.Runtime.queryParam('test')) {
        return true;
    }
    // Browser tests rely on prefs.
    if (prefs) {
        return prefs['isUnderTest'] === 'true';
    }
    return Settings.Settings.hasInstance() &&
        Settings.Settings.instance().createSetting('isUnderTest', false).get();
}

var InspectorFrontendHost = /*#__PURE__*/Object.freeze({
  __proto__: null,
  InspectorFrontendHostStub: InspectorFrontendHostStub,
  get InspectorFrontendHostInstance () { return InspectorFrontendHostInstance; },
  isUnderTest: isUnderTest
});

/*
 * Copyright (C) 2014 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/** @type {string} */
let _platform;
/**
 * @return {string}
 */
function platform() {
    if (!_platform) {
        _platform = InspectorFrontendHostInstance.platform();
    }
    return _platform;
}
/** @type {boolean} */
let _isMac;
/**
 * @return {boolean}
 */
function isMac() {
    if (typeof _isMac === 'undefined') {
        _isMac = platform() === 'mac';
    }
    return _isMac;
}
/** @type {boolean} */
let _isWin;
/**
 * @return {boolean}
 */
function isWin() {
    if (typeof _isWin === 'undefined') {
        _isWin = platform() === 'windows';
    }
    return _isWin;
}
/** @type {boolean} */
let _isCustomDevtoolsFrontend;
/**
 * @return {boolean}
 */
function isCustomDevtoolsFrontend() {
    if (typeof _isCustomDevtoolsFrontend === 'undefined') {
        _isCustomDevtoolsFrontend = window.location.toString().startsWith('devtools://devtools/custom/');
    }
    return _isCustomDevtoolsFrontend;
}
/** @type {string} */
let _fontFamily;
/**
 * @return {string}
 */
function fontFamily() {
    if (_fontFamily) {
        return _fontFamily;
    }
    switch (platform()) {
        case 'linux':
            _fontFamily = 'Roboto, Ubuntu, Arial, sans-serif';
            break;
        case 'mac':
            _fontFamily = '\'Lucida Grande\', sans-serif';
            break;
        case 'windows':
            _fontFamily = '\'Segoe UI\', Tahoma, sans-serif';
            break;
    }
    return _fontFamily;
}

var Platform = /*#__PURE__*/Object.freeze({
  __proto__: null,
  platform: platform,
  isMac: isMac,
  isWin: isWin,
  isCustomDevtoolsFrontend: isCustomDevtoolsFrontend,
  fontFamily: fontFamily
});

/*
 * Copyright (C) 2011 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
class UserMetrics {
    constructor() {
        this._panelChangedSinceLaunch = false;
        this._firedLaunchHistogram = false;
        this._launchPanelName = '';
    }
    /**
     * @param {string} contrastThreshold
     */
    colorFixed(contrastThreshold) {
        const code = ContrastThresholds[contrastThreshold];
        if (code === undefined) {
            console.warn(`Unknown contrast threshold: ${contrastThreshold}`);
            return;
        }
        const size = Object.keys(ContrastThresholds).length + 1;
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.ColorPickerFixedColor, code, size);
        EventTarget.fireEvent(EnumeratedHistogram.ColorPickerFixedColor, { value: code });
    }
    /**
     * @param {string} panelName
     */
    panelShown(panelName) {
        const code = PanelCodes[panelName] || 0;
        const size = Object.keys(PanelCodes).length + 1;
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.PanelShown, code, size);
        EventTarget.fireEvent(EnumeratedHistogram.PanelShown, { value: code });
        // Store that the user has changed the panel so we know launch histograms should not be fired.
        this._panelChangedSinceLaunch = true;
    }
    /**
     * Fired when a panel is closed (regardless if it exists in the main panel or the drawer)
     * @param {string} panelName
     */
    panelClosed(panelName) {
        const code = PanelCodes[panelName] || 0;
        const size = Object.keys(PanelCodes).length + 1;
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.PanelClosed, code, size);
        EventTarget.fireEvent(EnumeratedHistogram.PanelClosed, { value: code });
        // Store that the user has changed the panel so we know launch histograms should not be fired.
        this._panelChangedSinceLaunch = true;
    }
    /**
     * @param {string} sidebarPaneName
     */
    sidebarPaneShown(sidebarPaneName) {
        const code = SidebarPaneCodes[sidebarPaneName] || 0;
        const size = Object.keys(SidebarPaneCodes).length + 1;
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.SidebarPaneShown, code, size);
        EventTarget.fireEvent(EnumeratedHistogram.SidebarPaneShown, { value: code });
    }
    /**
     * @param {string} settingsViewId
     */
    settingsPanelShown(settingsViewId) {
        this.panelShown('settings-' + settingsViewId);
    }
    /**
     * @param {!Action} action
     */
    actionTaken(action) {
        const size = Object.keys(Action).length + 1;
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.ActionTaken, action, size);
        EventTarget.fireEvent(EnumeratedHistogram.ActionTaken, { value: action });
    }
    /**
     * @param {string} panelName
     * @param {string} histogramName
     * @suppressGlobalPropertiesCheck
     */
    panelLoaded(panelName, histogramName) {
        if (this._firedLaunchHistogram || panelName !== this._launchPanelName) {
            return;
        }
        this._firedLaunchHistogram = true;
        // Use rAF and setTimeout to ensure the marker is fired after layout and rendering.
        // This will give the most accurate representation of the tool being ready for a user.
        requestAnimationFrame(() => {
            setTimeout(() => {
                // Mark the load time so that we can pinpoint it more easily in a trace.
                performance.mark(histogramName);
                // If the user has switched panel before we finished loading, ignore the histogram,
                // since the launch timings will have been affected and are no longer valid.
                if (this._panelChangedSinceLaunch) {
                    return;
                }
                // This fires the event for the appropriate launch histogram.
                // The duration is measured as the time elapsed since the time origin of the document.
                InspectorFrontendHostInstance.recordPerformanceHistogram(histogramName, performance.now());
                EventTarget.fireEvent('DevTools.PanelLoaded', { value: { panelName, histogramName } });
            }, 0);
        });
    }
    /**
     * @param {?string} panelName
     */
    setLaunchPanel(panelName) {
        // Store the panel name that we should use for the launch histogram.
        // Other calls to panelLoaded will be ignored if the name does not match the one set here.
        this._launchPanelName = /** @type {string} */ (panelName);
    }
    /**
     * @param {string} keybindSet
     */
    keybindSetSettingChanged(keybindSet) {
        const size = Object.keys(KeybindSetSettings).length + 1;
        const value = KeybindSetSettings[keybindSet] || 0;
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.KeybindSetSettingChanged, value, size);
        EventTarget.fireEvent(EnumeratedHistogram.KeybindSetSettingChanged, { value });
    }
    /**
     * @param {string} actionId
     */
    keyboardShortcutFired(actionId) {
        const size = Object.keys(KeyboardShortcutAction).length + 1;
        const action = KeyboardShortcutAction[actionId] || KeyboardShortcutAction.OtherShortcut;
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.KeyboardShortcutFired, action, size);
        EventTarget.fireEvent(EnumeratedHistogram.KeyboardShortcutFired, { value: action });
    }
    /**
     * @param {!IssueOpener} issueOpener
     */
    issuesPanelOpenedFrom(issueOpener) {
        const size = Object.keys(IssueOpener).length + 1;
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.IssuesPanelOpenedFrom, issueOpener, size);
        EventTarget.fireEvent(EnumeratedHistogram.IssuesPanelOpenedFrom, { value: issueOpener });
    }
    /**
     * @param {string | undefined} issueExpandedCategory
     */
    issuesPanelIssueExpanded(issueExpandedCategory) {
        if (issueExpandedCategory === undefined) {
            return;
        }
        const size = Object.keys(IssueExpanded).length + 1;
        const issueExpanded = IssueExpanded[issueExpandedCategory];
        if (issueExpanded === undefined) {
            return;
        }
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.IssuesPanelIssueExpanded, issueExpanded, size);
        EventTarget.fireEvent(EnumeratedHistogram.IssuesPanelIssueExpanded, { value: issueExpanded });
    }
    /**
     * @param {symbol} issueCategory
     * @param {string} type
     */
    issuesPanelResourceOpened(issueCategory, type) {
        const size = Object.keys(IssueResourceOpened).length + 1;
        const key = issueCategory.description + type;
        const value = IssueResourceOpened[key];
        if (value === undefined) {
            return;
        }
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.IssuesPanelResourceOpened, value, size);
        EventTarget.fireEvent(EnumeratedHistogram.IssuesPanelResourceOpened, { value });
    }
    /**
     * @param {!DualScreenDeviceEmulated} emulationAction
     */
    dualScreenDeviceEmulated(emulationAction) {
        const size = Object.keys(DualScreenDeviceEmulated).length + 1;
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.DualScreenDeviceEmulated, emulationAction, size);
        EventTarget.fireEvent(EnumeratedHistogram.DualScreenDeviceEmulated, { value: emulationAction });
    }
    /**
     * @param {string} gridSettingId
     */
    cssGridSettings(gridSettingId) {
        const size = Object.keys(CSSGridSettings).length + 1;
        const gridSetting = CSSGridSettings[gridSettingId];
        if (gridSetting === undefined) {
            return;
        }
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.CSSGridSettings, gridSetting, size);
        EventTarget.fireEvent(EnumeratedHistogram.CSSGridSettings, { value: gridSetting });
    }
    /**
     * @param {number} count The number of highlighted persistent grids
     */
    highlightedPersistentCssGridCount(count) {
        const size = HighlightedPersistentCSSGridCount.length;
        let code;
        for (let i = 0; i < size; i++) {
            const min = HighlightedPersistentCSSGridCount[i];
            const max = HighlightedPersistentCSSGridCount[i + 1] || { threshold: Infinity };
            if (count >= min.threshold && count < max.threshold) {
                code = min.code;
                break;
            }
        }
        if (typeof code === 'undefined') {
            return;
        }
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.HighlightedPersistentCSSGridCount, code, size);
        EventTarget.fireEvent(EnumeratedHistogram.HighlightedPersistentCSSGridCount, { value: code });
    }
    /**
     * @param {string} experimentId
     */
    experimentEnabledAtLaunch(experimentId) {
        const size = DevtoolsExperiments['__lastValidEnumPosition'] + 1;
        const experiment = DevtoolsExperiments[experimentId];
        if (experiment === undefined) {
            return;
        }
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.ExperimentEnabledAtLaunch, experiment, size);
        EventTarget.fireEvent(EnumeratedHistogram.ExperimentEnabledAtLaunch, { value: experiment });
    }
    /**
     * @param {string} experimentId
     * @param {boolean} isEnabled
     */
    experimentChanged(experimentId, isEnabled) {
        const size = DevtoolsExperiments['__lastValidEnumPosition'] + 1;
        const experiment = DevtoolsExperiments[experimentId];
        if (experiment === undefined) {
            return;
        }
        const actionName = isEnabled ? EnumeratedHistogram.ExperimentEnabled : EnumeratedHistogram.ExperimentDisabled;
        InspectorFrontendHostInstance.recordEnumeratedHistogram(actionName, experiment, size);
        EventTarget.fireEvent(actionName, { value: experiment });
    }
    /**
     * @param {boolean} isEnabled
     */
    computedStyleGrouping(isEnabled) {
        const size = Object.keys(ComputedStyleGroupingState).length + 1;
        const code = isEnabled ? ComputedStyleGroupingState.enabled : ComputedStyleGroupingState.disabled;
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.ComputedStyleGrouping, code, size);
        EventTarget.fireEvent(EnumeratedHistogram.ComputedStyleGrouping, { value: code });
    }
    /**
     * @param {!GridOverlayOpener} gridOverlayOpener
     */
    gridOverlayOpenedFrom(gridOverlayOpener) {
        const size = Object.keys(GridOverlayOpener).length + 1;
        InspectorFrontendHostInstance.recordEnumeratedHistogram(EnumeratedHistogram.GridOverlayOpenedFrom, gridOverlayOpener, size);
        EventTarget.fireEvent(EnumeratedHistogram.GridOverlayOpenedFrom, { value: gridOverlayOpener });
    }
}
// Codes below are used to collect UMA histograms in the Chromium port.
// Do not change the values below, additional actions are needed on the Chromium side
// in order to add more codes.
/** @enum {number} */
const Action = {
    WindowDocked: 1,
    WindowUndocked: 2,
    ScriptsBreakpointSet: 3,
    TimelineStarted: 4,
    ProfilesCPUProfileTaken: 5,
    ProfilesHeapProfileTaken: 6,
    // Keep key around because length of object is important. See Host.UserMetrics.actionTaken.
    'LegacyAuditsStarted-deprecated': 7,
    ConsoleEvaluated: 8,
    FileSavedInWorkspace: 9,
    DeviceModeEnabled: 10,
    AnimationsPlaybackRateChanged: 11,
    RevisionApplied: 12,
    FileSystemDirectoryContentReceived: 13,
    StyleRuleEdited: 14,
    CommandEvaluatedInConsolePanel: 15,
    DOMPropertiesExpanded: 16,
    ResizedViewInResponsiveMode: 17,
    TimelinePageReloadStarted: 18,
    ConnectToNodeJSFromFrontend: 19,
    ConnectToNodeJSDirectly: 20,
    CpuThrottlingEnabled: 21,
    CpuProfileNodeFocused: 22,
    CpuProfileNodeExcluded: 23,
    SelectFileFromFilePicker: 24,
    SelectCommandFromCommandMenu: 25,
    ChangeInspectedNodeInElementsPanel: 26,
    StyleRuleCopied: 27,
    CoverageStarted: 28,
    LighthouseStarted: 29,
    LighthouseFinished: 30,
    ShowedThirdPartyBadges: 31,
    LighthouseViewTrace: 32,
    FilmStripStartedRecording: 33,
    CoverageReportFiltered: 34,
    CoverageStartedPerBlock: 35,
    'SettingsOpenedFromGear-deprecated': 36,
    'SettingsOpenedFromMenu-deprecated': 37,
    'SettingsOpenedFromCommandMenu-deprecated': 38,
    TabMovedToDrawer: 39,
    TabMovedToMainPanel: 40,
    CaptureCssOverviewClicked: 41,
    VirtualAuthenticatorEnvironmentEnabled: 42,
    SourceOrderViewActivated: 43,
    UserShortcutAdded: 44,
    ShortcutRemoved: 45,
    ShortcutModified: 46,
};
/** @type {!Object<string, number>} */
const ContrastThresholds = {
    aa: 0,
    aaa: 1,
};
/** @type {!Object<string, number>} */
const PanelCodes = {
    elements: 1,
    resources: 2,
    network: 3,
    sources: 4,
    timeline: 5,
    heap_profiler: 6,
    // Keep key around because length of object is important. See Host.UserMetrics.panelShown.
    'legacy-audits-deprecated': 7,
    console: 8,
    layers: 9,
    'console-view': 10,
    'animations': 11,
    'network.config': 12,
    'rendering': 13,
    'sensors': 14,
    'sources.search': 15,
    security: 16,
    js_profiler: 17,
    lighthouse: 18,
    'coverage': 19,
    'protocol-monitor': 20,
    'remote-devices': 21,
    'web-audio': 22,
    'changes.changes': 23,
    'performance.monitor': 24,
    'release-note': 25,
    'live_heap_profile': 26,
    'sources.quick': 27,
    'network.blocked-urls': 28,
    'settings-preferences': 29,
    'settings-workspace': 30,
    'settings-experiments': 31,
    'settings-blackbox': 32,
    'settings-devices': 33,
    'settings-throttling-conditions': 34,
    'settings-emulation-locations': 35,
    'settings-shortcuts': 36,
    'issues-pane': 37,
    'settings-keybinds': 38,
    'cssoverview': 39
};
/** @type {!Object<string, number>} */
const SidebarPaneCodes = {
    'OtherSidebarPane': 0,
    'Styles': 1,
    'Computed': 2,
    'elements.layout': 3,
    'elements.eventListeners': 4,
    'elements.domBreakpoints': 5,
    'elements.domProperties': 6,
    'accessibility.view': 7,
};
/** @type {!Object<string, number>} */
const KeybindSetSettings = {
    'devToolsDefault': 0,
    'vsCode': 1,
};
/** @type {!Object<string, number>} */
const KeyboardShortcutAction = {
    OtherShortcut: 0,
    'commandMenu.show': 1,
    'console.clear': 2,
    'console.show': 3,
    'debugger.step': 4,
    'debugger.step-into': 5,
    'debugger.step-out': 6,
    'debugger.step-over': 7,
    'debugger.toggle-breakpoint': 8,
    'debugger.toggle-breakpoint-enabled': 9,
    'debugger.toggle-pause': 10,
    'elements.edit-as-html': 11,
    'elements.hide-element': 12,
    'elements.redo': 13,
    'elements.toggle-element-search': 14,
    'elements.undo': 15,
    'main.search-in-panel.find': 16,
    'main.toggle-drawer': 17,
    'network.hide-request-details': 18,
    'network.search': 19,
    'network.toggle-recording': 20,
    'quickOpen.show': 21,
    'settings.show': 22,
    'sources.search': 23,
    'background-service.toggle-recording': 24,
    'components.collect-garbage': 25,
    'console.clear.history': 26,
    'console.create-pin': 27,
    'coverage.start-with-reload': 28,
    'coverage.toggle-recording': 29,
    'debugger.breakpoint-input-window': 30,
    'debugger.evaluate-selection': 31,
    'debugger.next-call-frame': 32,
    'debugger.previous-call-frame': 33,
    'debugger.run-snippet': 34,
    'debugger.toggle-breakpoints-active': 35,
    'elements.capture-area-screenshot': 36,
    'emulation.capture-full-height-screenshot': 37,
    'emulation.capture-node-screenshot': 38,
    'emulation.capture-screenshot': 39,
    'emulation.show-sensors': 40,
    'emulation.toggle-device-mode': 41,
    'help.release-notes': 42,
    'help.report-issue': 43,
    'input.start-replaying': 44,
    'input.toggle-pause': 45,
    'input.toggle-recording': 46,
    'inspector_main.focus-debuggee': 47,
    'inspector_main.hard-reload': 48,
    'inspector_main.reload': 49,
    'live-heap-profile.start-with-reload': 50,
    'live-heap-profile.toggle-recording': 51,
    'main.debug-reload': 52,
    'main.next-tab': 53,
    'main.previous-tab': 54,
    'main.search-in-panel.cancel': 55,
    'main.search-in-panel.find-next': 56,
    'main.search-in-panel.find-previous': 57,
    'main.toggle-dock': 58,
    'main.zoom-in': 59,
    'main.zoom-out': 60,
    'main.zoom-reset': 61,
    'network-conditions.network-low-end-mobile': 62,
    'network-conditions.network-mid-tier-mobile': 63,
    'network-conditions.network-offline': 64,
    'network-conditions.network-online': 65,
    'profiler.heap-toggle-recording': 66,
    'profiler.js-toggle-recording': 67,
    'resources.clear': 68,
    'settings.documentation': 69,
    'settings.shortcuts': 70,
    'sources.add-folder-to-workspace': 71,
    'sources.add-to-watch': 72,
    'sources.close-all': 73,
    'sources.close-editor-tab': 74,
    'sources.create-snippet': 75,
    'sources.go-to-line': 76,
    'sources.go-to-member': 77,
    'sources.jump-to-next-location': 78,
    'sources.jump-to-previous-location': 79,
    'sources.rename': 80,
    'sources.save': 81,
    'sources.save-all': 82,
    'sources.switch-file': 83,
    'timeline.jump-to-next-frame': 84,
    'timeline.jump-to-previous-frame': 85,
    'timeline.load-from-file': 86,
    'timeline.next-recording': 87,
    'timeline.previous-recording': 88,
    'timeline.record-reload': 89,
    'timeline.save-to-file': 90,
    'timeline.show-history': 91,
    'timeline.toggle-recording': 92,
};
/** @enum {number} */
const IssueOpener = {
    ConsoleInfoBar: 0,
    LearnMoreLinkCOEP: 1,
    StatusBarIssuesCounter: 2,
    HamburgerMenu: 3,
    Adorner: 4
};
/** @enum {number} */
const DualScreenDeviceEmulated = {
    DualScreenDeviceSelected: 0,
    SpanButtonClicked: 1,
    PlatformSupportUsed: 2 // user starts to use platform dual screen support feature.
};
/** @type {!Object<string, number>} */
const CSSGridSettings = {
    'showGridLineLabels.none': 0,
    'showGridLineLabels.lineNumbers': 1,
    'showGridLineLabels.lineNames': 2,
    'extendGridLines.false': 3,
    'extendGridLines.true': 4,
    'showGridAreas.false': 5,
    'showGridAreas.true': 6,
    'showGridTrackSizes.false': 7,
    'showGridTrackSizes.true': 8,
};
const HighlightedPersistentCSSGridCount = [
    { threshold: 0, code: 0 },
    { threshold: 1, code: 1 },
    { threshold: 2, code: 2 },
    { threshold: 3, code: 3 },
    { threshold: 4, code: 4 },
    { threshold: 5, code: 5 },
    { threshold: 10, code: 6 },
    { threshold: 20, code: 7 },
    { threshold: 50, code: 8 },
];
/**
 * This list should contain the currently active Devtools Experiments.
 * Therefore, it is possible that the id's will no longer be continuous
 * as experiemnts are removed.
 * When adding a new experiemnt:
 * 1. Add an entry to the bottom of the list before '__lastValidEnumPosition'
 * 2. Set the value of the new entry and '__lastValidEnumPosition' to
 *    __lastValidEnumPosition + 1
 * When removing an experiment, simply delete the line from the enum.
 */
/** @type {!Object<string, number>} */
const DevtoolsExperiments = {
    'applyCustomStylesheet': 0,
    'captureNodeCreationStacks': 1,
    'sourcesPrettyPrint': 2,
    'backgroundServices': 3,
    'backgroundServicesNotifications': 4,
    'backgroundServicesPaymentHandler': 5,
    'backgroundServicesPushMessaging': 6,
    'blackboxJSFramesOnTimeline': 7,
    'cssOverview': 8,
    'emptySourceMapAutoStepping': 9,
    'inputEventsOnTimelineOverview': 10,
    'liveHeapProfile': 11,
    'nativeHeapProfiler': 12,
    'protocolMonitor': 13,
    'developerResourcesView': 15,
    'recordCoverageWithPerformanceTracing': 16,
    'samplingHeapProfilerTimeline': 17,
    'showOptionToNotTreatGlobalObjectsAsRoots': 18,
    'sourceDiff': 19,
    'sourceOrderViewer': 20,
    'spotlight': 21,
    'webauthnPane': 22,
    'customKeyboardShortcuts': 23,
    'timelineEventInitiators': 24,
    'timelineFlowEvents': 25,
    'timelineInvalidationTracking': 26,
    'timelineShowAllEvents': 27,
    'timelineV8RuntimeCallStats': 28,
    'timelineWebGL': 29,
    'timelineReplayEvent': 30,
    'wasmDWARFDebugging': 31,
    'dualScreenSupport': 32,
    'cssGridFeatures': 33,
    'keyboardShortcutEditor': 35,
    '__lastValidEnumPosition': 35,
};
/** @type {!Object<string, number>} */
const ComputedStyleGroupingState = {
    'enabled': 0,
    'disabled': 1,
};
/** @type {!Object<string, number>} */
const IssueExpanded = {
    CrossOriginEmbedderPolicy: 0,
    MixedContent: 1,
    SameSiteCookie: 2,
    HeavyAd: 3,
    ContentSecurityPolicy: 4,
    Other: 5
};
/** @type {!Object<string, number>} */
const IssueResourceOpened = {
    CrossOriginEmbedderPolicyRequest: 0,
    CrossOriginEmbedderPolicyElement: 1,
    MixedContentRequest: 2,
    SameSiteCookieCookie: 3,
    SameSiteCookieRequest: 4,
    HeavyAdElement: 5,
    ContentSecurityPolicyDirective: 6,
    ContentSecurityPolicyElement: 7
};
/** @enum {number} */
const GridOverlayOpener = {
    Adorner: 0,
    LayoutPane: 1,
};

var UserMetrics$1 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  UserMetrics: UserMetrics,
  Action: Action,
  ContrastThresholds: ContrastThresholds,
  PanelCodes: PanelCodes,
  SidebarPaneCodes: SidebarPaneCodes,
  KeybindSetSettings: KeybindSetSettings,
  KeyboardShortcutAction: KeyboardShortcutAction,
  IssueOpener: IssueOpener,
  DualScreenDeviceEmulated: DualScreenDeviceEmulated,
  CSSGridSettings: CSSGridSettings,
  HighlightedPersistentCSSGridCount: HighlightedPersistentCSSGridCount,
  DevtoolsExperiments: DevtoolsExperiments,
  ComputedStyleGroupingState: ComputedStyleGroupingState,
  IssueExpanded: IssueExpanded,
  IssueResourceOpened: IssueResourceOpened,
  GridOverlayOpener: GridOverlayOpener
});

// Copyright 2019 The Chromium Authors. All rights reserved.
const userMetrics = new UserMetrics();

export { InspectorFrontendHost, InspectorFrontendHostAPI$1 as InspectorFrontendHostAPI, Platform, ResourceLoader$1 as ResourceLoader, UserMetrics$1 as UserMetrics, userMetrics };
