/**
 * Take the locale passed in from the browser(host), run through the fallback logic (example: es-419 -> es)
 * to find the DevTools supported locale and register it.
 * @param {string} locale
 */
export function registerLocale(locale: string): void;
/**
 * Retrieve the localized string.
 * @param {function(string, ?Object):string} str_
 * @param {string} id
 * @param {!Object} values
 * @return {string} the localized version of the
 */
export function getLocalizedString(str_: (arg0: string, arg1: Object | null) => string, id: string, values?: Object): string;
/**
 * Register a file's UIStrings with i18n, return function to generate the string ids.
 * @param {string} path
 * @param {!Object} UIStrings
 * @return {function(string, ?Object):string} return function to generate the string ids.
 */
export function registerUIStrings(path: string, UIStrings: Object): (arg0: string, arg1: Object | null) => string;
/**
 * Returns a span element that may contains other DOM element as placeholders
 * @param {function(string, ?Object):string} str_
 * @param {string} stringId
 * @param {!ArrayLike<?Object>} placeholders
 * @return {!Element} the localized result
 */
export function getFormatLocalizedString(str_: (arg0: string, arg1: Object | null) => string, stringId: string, placeholders?: ArrayLike<Object | null>): Element;
/**
 * @param {string} formattedString
 * @param {?ArrayLike<?>} args
 * @return {!Element} the formatted result.
 */
export function formatLocalized(formattedString: string, args: ArrayLike<unknown> | null): Element;
/**
 * The locale that DevTools displays
 * @param {string} locale
 * @param {*} lhlMessages
 */
export const registerLocaleData: (locale: string, lhlMessages: any) => void;
/**
 * The locale that DevTools displays
 * @type {string}
 */
export let registeredLocale: string;
