/**
 * @implements {ProtocolProxyApi.ProfilerDispatcher}
 */
export class CPUProfilerModel extends SDKModel implements ProtocolProxyApi.ProfilerDispatcher {
    /**
     * @param {!Target} target
     */
    constructor(target: Target);
    _isRecording: boolean;
    _nextAnonymousConsoleProfileNumber: number;
    _anonymousConsoleProfileIdToTitle: Map<any, any>;
    _profilerAgent: ProtocolProxyApi.ProfilerApi;
    /** @type {?function(number, string, !Array<!Protocol.Profiler.ScriptCoverage>):void} */
    _preciseCoverageDeltaUpdateCallback: ((arg0: number, arg1: string, arg2: Array<Protocol.Profiler.ScriptCoverage>) => void) | null;
    _debuggerModel: DebuggerModel;
    /**
     * @return {!RuntimeModel}
     */
    runtimeModel(): RuntimeModel;
    /**
     * @return {!DebuggerModel}
     */
    debuggerModel(): DebuggerModel;
    /**
     * @override
     * @param {!Protocol.Profiler.ConsoleProfileStartedEvent} event
     */
    consoleProfileStarted({ id, location, title }: Protocol.Profiler.ConsoleProfileStartedEvent): void;
    /**
     * @override
     * @param {!Protocol.Profiler.ConsoleProfileFinishedEvent} event
     */
    consoleProfileFinished({ id, location, profile, title }: Protocol.Profiler.ConsoleProfileFinishedEvent): void;
    /**
     * @param {symbol} eventName
     * @param {string} id
     * @param {!Protocol.Debugger.Location} scriptLocation
     * @param {string=} title
     * @param {!Protocol.Profiler.Profile=} cpuProfile
     */
    _dispatchProfileEvent(eventName: symbol, id: string, scriptLocation: Protocol.Debugger.Location, title?: string | undefined, cpuProfile?: Protocol.Profiler.Profile | undefined): void;
    /**
     * @return {boolean}
     */
    isRecordingProfile(): boolean;
    /**
     * @return {!Promise<?>}
     */
    startRecording(): Promise<unknown>;
    /**
     * @return {!Promise<?Protocol.Profiler.Profile>}
     */
    stopRecording(): Promise<Protocol.Profiler.Profile | null>;
    /**
     * @param {boolean} jsCoveragePerBlock - Collect per Block coverage if `true`, per function coverage otherwise.
     * @param {?function(number, string, !Array<!Protocol.Profiler.ScriptCoverage>):void} preciseCoverageDeltaUpdateCallback - Callback for coverage updates initiated from the back-end
     * @return {!Promise<?>}
     */
    startPreciseCoverage(jsCoveragePerBlock: boolean, preciseCoverageDeltaUpdateCallback: ((arg0: number, arg1: string, arg2: Array<Protocol.Profiler.ScriptCoverage>) => void) | null): Promise<unknown>;
    /**
     * @return {!Promise<{timestamp:number, coverage:!Array<!Protocol.Profiler.ScriptCoverage>}>}
     */
    takePreciseCoverage(): Promise<{
        timestamp: number;
        coverage: Array<Protocol.Profiler.ScriptCoverage>;
    }>;
    /**
     * @return {!Promise<?>}
     */
    stopPreciseCoverage(): Promise<unknown>;
    /**
     * @override
     * @param {!Protocol.Profiler.PreciseCoverageDeltaUpdateEvent} event
     */
    preciseCoverageDeltaUpdate({ timestamp, occassion, result }: Protocol.Profiler.PreciseCoverageDeltaUpdateEvent): void;
    /**
     * @return {!Protocol.UsesObjectNotation}
     */
    usesObjectNotation(): Protocol.UsesObjectNotation;
}
export type Events = symbol;
export namespace Events {
    const ConsoleProfileStarted: symbol;
    const ConsoleProfileFinished: symbol;
}
export type EventData = {
    id: string;
    scriptLocation: Location;
    title: string;
    cpuProfile: (Protocol.Profiler.Profile | undefined);
    cpuProfilerModel: CPUProfilerModel;
};
/** @typedef {!{id: string, scriptLocation: !Location, title: string, cpuProfile: (!Protocol.Profiler.Profile|undefined), cpuProfilerModel: !CPUProfilerModel}} */
export let EventData: any;
import { SDKModel } from "./SDKModel.js";
import { DebuggerModel } from "./DebuggerModel.js";
import { RuntimeModel } from "./RuntimeModel.js";
import { Location } from "./DebuggerModel.js";
import { Target } from "./SDKModel.js";
