/**
 * Extracts information about font variation settings assuming
 * value is valid according to the spec: https://drafts.csswg.org/css-fonts-4/#font-variation-settings-def
 *
 * @param {string} value A valid CSS font-variation-settings property value
 * @return {!Array<!{tag:string, value:number}>}
 */
export function parseFontVariationSettings(value: string): Array<{
    tag: string;
    value: number;
}>;
/**
 * Extracts font families assuming the value is valid according to
 * the spec: https://drafts.csswg.org/css-fonts-4/#font-family-prop
 *
 * @param {string} value A valid CSS font-family property value
 * @return {!Array<string>}
 */
export function parseFontFamily(value: string): Array<string>;
/**
 * Splits a list of values by comma and trims parts
 * @param {string} value
 * @return {!Array<string>}
 */
export function splitByComma(value: string): Array<string>;
/**
 * @param {string} value
 * @return {string}
 * @suppress {missingProperties} Closure doesn't know String.p.replaceAll exists.
 */
export function stripComments(value: string): string;
