/**
 * The `IssuesModel` is a thin dispatch that does not store issues, but only creates the representation
 * class (usually derived from `Issue`) and passes the instances on via a dispatched event.
 * We chose this approach here because the lifetime of the Model is tied to the target, but DevTools
 * wants to preserve issues for targets (e.g. iframes) that are already gone as well.
 * @implements {ProtocolProxyApi.AuditsDispatcher}
 */
export class IssuesModel extends SDKModel implements ProtocolProxyApi.AuditsDispatcher {
    /**
     * @param {!Target} target
     */
    constructor(target: Target);
    _enabled: boolean;
    /** @type {*} */
    _auditsAgent: any;
    _disposed: boolean;
    /**
     * @return {!Protocol.UsesObjectNotation}
     */
    usesObjectNotation(): Protocol.UsesObjectNotation;
    ensureEnabled(): void;
    /**
     * @override
     * @param {!Protocol.Audits.IssueAddedEvent} issueAddedEvent
     */
    issueAdded(issueAddedEvent: Protocol.Audits.IssueAddedEvent): void;
    /**
     * @param {!Issue} issue
     */
    addIssue(issue: Issue): void;
    /**
     * Each issue reported by the backend can result in multiple {!Issue} instances.
     * Handlers are simple functions hard-coded into a map.
     * @param {!Protocol.Audits.InspectorIssue} inspectorIssue} inspectorIssue
     * @return {!Array<!Issue>}
     */
    _createIssuesFromProtocolIssue(inspectorIssue: Protocol.Audits.InspectorIssue): Array<Issue>;
    /**
     * @returns {?Target}
     */
    getTargetIfNotDisposed(): Target | null;
}
export type Events = symbol;
export namespace Events {
    const IssueAdded: symbol;
}
import { SDKModel } from "./SDKModel.js";
import { Issue } from "./Issue.js";
import { Target } from "./SDKModel.js";
