export type HighlightColor = {
    r: number;
    g: number;
    b: number;
    a: number;
};
/**
 * @typedef {{r: number, g: number, b: number, a: number}}
 */
export let HighlightColor: any;
export type HighlightRect = {
    x: number;
    y: number;
    width: number;
    height: number;
    color: HighlightColor;
    outlineColor: HighlightColor;
};
/**
 * @typedef {{x: number, y: number, width: number, height: number, color: HighlightColor, outlineColor: HighlightColor}}
 */
export let HighlightRect: any;
export type Hinge = {
    width: number;
    height: number;
    x: number;
    y: number;
    contentColor: HighlightColor;
    outlineColor: HighlightColor;
};
/** @typedef {!{width: number, height: number, x: number, y: number, contentColor:HighlightColor, outlineColor: HighlightColor}} */
export let Hinge: any;
/**
 * @implements {ProtocolProxyApi.OverlayDispatcher}
 */
export class OverlayModel extends SDKModel implements ProtocolProxyApi.OverlayDispatcher {
    /**
     * @param {!RemoteObject} object
     */
    static highlightObjectAsDOMNode(object: RemoteObject): void;
    static hideDOMNodeHighlight(): void;
    static muteHighlight(): Promise<any[]>;
    static unmuteHighlight(): Promise<any[]>;
    /**
     * @param {!HighlightRect} rect
     */
    static highlightRect(rect: HighlightRect): void;
    static clearHighlight(): void;
    /**
     * @param {function(!DOMNode):void} handler
     */
    static setInspectNodeHandler(handler: (arg0: DOMNode) => void): void;
    /**
     * @param {!Target} target
     */
    constructor(target: Target);
    _domModel: DOMModel;
    _overlayAgent: ProtocolProxyApi.OverlayApi;
    _debuggerModel: any;
    _inspectModeEnabled: boolean;
    _gridFeaturesExperimentEnabled: boolean;
    _hideHighlightTimeout: number | null;
    /** @type {!Highlighter} */
    _defaultHighlighter: Highlighter;
    _highlighter: Highlighter;
    _showPaintRectsSetting: Common.Settings.Setting<any>;
    _showLayoutShiftRegionsSetting: Common.Settings.Setting<any>;
    _showAdHighlightsSetting: Common.Settings.Setting<any>;
    _showDebugBordersSetting: Common.Settings.Setting<any>;
    _showFPSCounterSetting: Common.Settings.Setting<any>;
    _showScrollBottleneckRectsSetting: Common.Settings.Setting<any>;
    _showHitTestBordersSetting: Common.Settings.Setting<any>;
    /**
     * @type {!Array<!Common.EventTarget.EventDescriptor>}
     */
    _registeredListeners: Array<Common.EventTarget.EventDescriptor>;
    /** @type {boolean} */
    _showViewportSizeOnResize: boolean;
    /** @type {?DefaultPersistentGridHighlighter} */
    _persistentGridHighlighter: DefaultPersistentGridHighlighter | null;
    _sourceOrderHighlighter: SourceOrderHighlighter;
    _sourceOrderModeActive: boolean;
    /**
     * @return {!Protocol.UsesObjectNotation}
     */
    usesObjectNotation(): Protocol.UsesObjectNotation;
    /**
     * @return {!DOMModel}
     */
    getDOMModel(): DOMModel;
    /**
     * @param {!HighlightRect} rect
     * @return {!Promise<*>}
     */
    highlightRect({ x, y, width, height, color, outlineColor }: HighlightRect): Promise<any>;
    /**
     * @return {!Promise<*>}
     */
    clearHighlight(): Promise<any>;
    /**
     * @return {!Promise<void>}
     */
    _wireAgentToSettings(): Promise<void>;
    /**
     * @param {boolean} show
     */
    setShowViewportSizeOnResize(show: boolean): void;
    _updatePausedInDebuggerMessage(): void;
    /**
     * @param {?Highlighter} highlighter
     */
    setHighlighter(highlighter: Highlighter | null): void;
    /**
     * @param {!Protocol.Overlay.InspectMode} mode
     * @param {boolean=} showDetailedTooltip
     * @return {!Promise<void>}
     */
    setInspectMode(mode: Protocol.Overlay.InspectMode, showDetailedTooltip?: boolean | undefined): Promise<void>;
    /**
     * @return {boolean}
     */
    inspectModeEnabled(): boolean;
    /**
     * @param {!HighlightData} data
     * @param {string=} mode
     * @param {boolean=} showInfo
     */
    highlightInOverlay(data: HighlightData, mode?: string | undefined, showInfo?: boolean | undefined): void;
    /**
     * @param {!HighlightData} data
     */
    highlightInOverlayForTwoSeconds(data: HighlightData): void;
    /**
     * @param {number} nodeId
     * @param {!Host.UserMetrics.GridOverlayOpener} gridOverlayOpener
     */
    highlightGridInPersistentOverlay(nodeId: number, gridOverlayOpener: Host.UserMetrics.GridOverlayOpener): void;
    /**
     * @param {number} nodeId
     */
    isHighlightedGridInPersistentOverlay(nodeId: number): boolean | undefined;
    /**
     * @param {number} nodeId
     */
    hideGridInPersistentOverlay(nodeId: number): void;
    /**
     * @param {!DOMNode} node
     */
    highlightSourceOrderInOverlay(node: DOMNode): void;
    /**
     * @param {number} nodeId
     * @return {string|null}
     */
    colorOfGridInPersistentOverlay(nodeId: number): string | null;
    /**
     * @param {number} nodeId
     * @param {string} colorStr
     */
    setColorOfGridInPersistentOverlay(nodeId: number, colorStr: string): void;
    hideSourceOrderInOverlay(): void;
    /**
     * @param {boolean} isActive
     */
    setSourceOrderActive(isActive: boolean): void;
    sourceOrderModeActive(): boolean;
    /**
     * @param {number} delay
     */
    _delayedHideHighlight(delay: number): void;
    /**
     * @param {!Protocol.Page.FrameId} frameId
     */
    highlightFrame(frameId: Protocol.Page.FrameId): void;
    /**
     * @param {?Hinge} hinge
     */
    showHingeForDualScreen(hinge: Hinge | null): void;
    /**
     * @param {string=} mode
     * @param {boolean=} showDetailedToolip
     * @return {!Protocol.Overlay.HighlightConfig}
     */
    _buildHighlightConfig(mode?: string | undefined, showDetailedToolip?: boolean | undefined): Protocol.Overlay.HighlightConfig;
    /**
     * @override
     * @param {!Protocol.Overlay.NodeHighlightRequestedEvent} event
     */
    nodeHighlightRequested({ nodeId }: Protocol.Overlay.NodeHighlightRequestedEvent): void;
    /**
     * @override
     * @param {!Protocol.Overlay.InspectNodeRequestedEvent} event
     */
    inspectNodeRequested({ backendNodeId }: Protocol.Overlay.InspectNodeRequestedEvent): void;
    /**
     * @override
     * @param {!Protocol.Overlay.ScreenshotRequestedEvent} event
     */
    screenshotRequested({ viewport }: Protocol.Overlay.ScreenshotRequestedEvent): void;
    /**
     * @override
     */
    inspectModeCanceled(): void;
}
export namespace OverlayModel {
    const _inspectNodeHandler: ((arg0: DOMNode) => void) | null;
}
export type Events = symbol;
export namespace Events {
    const InspectModeWillBeToggled: symbol;
    const ExitedInspectMode: symbol;
    const HighlightNodeRequested: symbol;
    const ScreenshotRequested: symbol;
    const PersistentGridOverlayCleared: symbol;
    const PersistentGridOverlayStateChanged: symbol;
}
/**
 * @interface
 */
export class Highlighter {
    /**
     * @param {!HighlightData} data
     * @param {!Protocol.Overlay.HighlightConfig} config
     */
    highlightInOverlay(data: HighlightData, config: Protocol.Overlay.HighlightConfig): void;
    /**
     * @param {!Protocol.Overlay.InspectMode} mode
     * @param {!Protocol.Overlay.HighlightConfig} config
     * @return {!Promise<void>}
     */
    setInspectMode(mode: Protocol.Overlay.InspectMode, config: Protocol.Overlay.HighlightConfig): Promise<void>;
    /**
     * @param {!Protocol.Page.FrameId} frameId
     */
    highlightFrame(frameId: Protocol.Page.FrameId): void;
}
/**
 * @interface
 */
export class PersistentGridHighlighter {
    /**
     * @param {number} nodeId
     * @param {!Protocol.Overlay.GridHighlightConfig} config
     */
    highlightInOverlay(nodeId: number, config: Protocol.Overlay.GridHighlightConfig): void;
    /**
     * @param {number} nodeId
     */
    hideInOverlay(nodeId: number): void;
    hideAllInOverlay(): void;
    refreshHighlights(): void;
    /**
     * @param {number} nodeId
     * @return {boolean}
     */
    isHighlighted(nodeId: number): boolean;
}
export class SourceOrderHighlighter {
    /**
     * @param {!OverlayModel} model
     */
    constructor(model: OverlayModel);
    _model: OverlayModel;
    /**
     * @param {!DOMNode} node
     * @param {!Protocol.Overlay.SourceOrderConfig} sourceOrderConfig
     */
    highlightSourceOrderInOverlay(node: DOMNode, sourceOrderConfig: Protocol.Overlay.SourceOrderConfig): void;
    hideSourceOrderHighlight(): void;
}
export type HighlightData = {
    node: DOMNode;
    selectorList: (string | undefined);
} | {
    deferredNode: DeferredDOMNode;
    selectorList: (string | undefined);
} | {
    object: RemoteObject;
    selectorList: (string | undefined);
} | {
    clear: any;
};
/** @typedef {!{node: !DOMNode, selectorList: (string|undefined)} | !{deferredNode: DeferredDOMNode, selectorList: (string|undefined)} | !{object: !RemoteObject, selectorList: (string|undefined)} | !{clear: *}} */
export let HighlightData: any;
import { SDKModel } from "./SDKModel.js";
import { DOMModel } from "./DOMModel.js";
import * as Common from "../common/common.js";
/**
 * @implements {PersistentGridHighlighter}
 */
declare class DefaultPersistentGridHighlighter implements PersistentGridHighlighter {
    /**
     * @returns {boolean}
     */
    static getGridTelemetryLogged(): boolean;
    /**
     * @param {boolean} isLogged
     */
    static setGridTelemetryLogged(isLogged: boolean): void;
    /**
     * @param {!OverlayModel} model
     */
    constructor(model: OverlayModel);
    _model: OverlayModel;
    /** @type {!Map<number, !Protocol.Overlay.GridHighlightConfig>} */
    _gridHighlights: Map<number, Protocol.Overlay.GridHighlightConfig>;
    /** @type {!Map<number, !Common.Color.Color>} */
    _gridColors: Map<number, Common.Color.Color>;
    _colorGenerator: OverlayColorGenerator;
    /** @type {!Common.Settings.Setting<*>} */
    _showGridLineLabelsSetting: Common.Settings.Setting<any>;
    /** @type {!Common.Settings.Setting<*>} */
    _extendGridLinesSetting: Common.Settings.Setting<any>;
    /** @type {!Common.Settings.Setting<*>} */
    _showGridAreasSetting: Common.Settings.Setting<any>;
    /** @type {!Common.Settings.Setting<*>} */
    _showGridTrackSizesSetting: Common.Settings.Setting<any>;
    _recordHighlightedGridCount: Function;
    /** @type {!Array<number>} */
    _previouslyRecordedGridCountNodeIds: Array<number>;
    _onSettingChange(): void;
    _logCurrentGridSettings(): void;
    /**
     * @param {?Common.Settings.Setting<*>} setting
     */
    _recordGridSetting(setting: Common.Settings.Setting<any> | null): void;
    _doRecordHighlightedGridCount(): void;
    /**
     * @param {number} nodeId
     * @return {!Protocol.Overlay.GridHighlightConfig}
     */
    _buildGridHighlightConfig(nodeId: number): Protocol.Overlay.GridHighlightConfig;
    /**
     * @override
     * @param {number} nodeId
     */
    highlightInOverlay(nodeId: number): void;
    /**
     * @override
     * @param {number} nodeId
     * @return {boolean}
     */
    isHighlighted(nodeId: number): boolean;
    /**
     * @param {number} nodeId
     * @return {!Common.Color.Color}
     */
    colorOfGrid(nodeId: number): Common.Color.Color;
    /**
     * @param {number} nodeId
     * @param {!Common.Color.Color} color
     */
    setColorOfGrid(nodeId: number, color: Common.Color.Color): void;
    /**
     * @override
     * @param {number} nodeId
     */
    hideInOverlay(nodeId: number): void;
    /**
     * @override
     */
    hideAllInOverlay(): void;
    /**
     * @override
     */
    refreshHighlights(): void;
    _resetOverlay(): void;
    _updateHighlightsInOverlay(): void;
}
declare namespace DefaultPersistentGridHighlighter {
    const gridTelemetryLogged: boolean;
}
import * as Host from "../host/host.js";
import { DOMNode } from "./DOMModel.js";
import { RemoteObject } from "./RemoteObject.js";
import { Target } from "./SDKModel.js";
import { DeferredDOMNode } from "./DOMModel.js";
/**
 * Used to cycle through a list of predetermined colors for the grid overlay.
 * This helps users differentiate between overlays when several are shown at the
 * same time.
 */
declare class OverlayColorGenerator {
    _colors: Common.Color.Color[];
    _index: number;
    /**
     * Generate the next color in the spectrum
     * @return {!Common.Color.Color}
     */
    next(): Common.Color.Color;
}
export {};
