/**
 * @param {?ResourceTreeFrame} topFrame
 * @param {(string|undefined)} cookieUrl
 * @return {boolean}
 *
 * Exported for unit test.
 */
export function isCausedByThirdParty(topFrame: ResourceTreeFrame | null, cookieUrl: (string | undefined)): boolean;
export class SameSiteCookieIssue extends Issue {
    /**
     * Returns an array of issues from a given SameSiteCookieIssueDetails.
     *
     * @param {!Protocol.Audits.SameSiteCookieIssueDetails} sameSiteDetails
     * @return {!Array<!Issue>}
     */
    static createIssuesFromSameSiteDetails(sameSiteDetails: Protocol.Audits.SameSiteCookieIssueDetails): Array<Issue>;
    /**
     * Calculates an issue code from a reason, an operation, and an array of warningReasons. All these together
     * can uniquely identify a specific SameSite cookie issue.
     * warningReasons is only needed for some SameSiteCookieExclusionReason in order to determine if an issue should be raised.
     * It is not required if reason is a SameSiteCookieWarningReason.
     *
     * @param {!Protocol.Audits.SameSiteCookieExclusionReason|!Protocol.Audits.SameSiteCookieWarningReason} reason
     * @param {!Array<!Protocol.Audits.SameSiteCookieWarningReason>} warningReasons
     * @param {!Protocol.Audits.SameSiteCookieOperation} operation
     * @param {string|undefined} cookieUrl
     * @returns {?string}
     */
    static codeForSameSiteDetails(reason: Protocol.Audits.SameSiteCookieExclusionReason | Protocol.Audits.SameSiteCookieWarningReason, warningReasons: Array<Protocol.Audits.SameSiteCookieWarningReason>, operation: Protocol.Audits.SameSiteCookieOperation, cookieUrl: string | undefined): string | null;
    /**
     * @param {string} code
     * @param {!Protocol.Audits.SameSiteCookieIssueDetails} issueDetails
     */
    constructor(code: string, issueDetails: Protocol.Audits.SameSiteCookieIssueDetails);
    _issueDetails: Protocol.Audits.SameSiteCookieIssueDetails;
}
import { ResourceTreeFrame } from "./ResourceTreeModel.js";
import { Issue } from "./Issue.js";
