/**
 * @unrestricted
 */
export class ServiceManager {
    /**
     * @param {string} serviceName
     * @return {!Promise<?Service>}
     */
    createRemoteService(serviceName: string): Promise<Service | null>;
    _remoteConnection: Connection | undefined;
    /**
     * @param {string} appName
     * @param {string} serviceName
     * @return {!Promise<?Service>}
     */
    createAppService(appName: string, serviceName: string): Promise<Service | null>;
}
/**
 * @unrestricted
 */
export class Connection {
    /**
     * @param {!ServicePort} port
     */
    constructor(port: ServicePort);
    _port: ServicePort;
    _lastId: number;
    /** @type {!Map<number, function(?Object):void>}*/
    _callbacks: Map<number, (arg0: Object | null) => void>;
    /** @type {!Map<string, !Service>}*/
    _services: Map<string, Service>;
    /**
     * @param {string} serviceName
     * @return {!Promise<?Service>}
     */
    _createService(serviceName: string): Promise<Service | null>;
    /**
     * @param {!Service} service
     */
    _serviceDisposed(service: Service): void;
    /**
     * @param {string} method
     * @param {!Object=} params
     * @return {!Promise<?Object<string, ?>>}
     */
    _sendCommand(method: string, params?: Object | undefined): Promise<{
        [x: string]: unknown;
    } | null>;
    /**
     * @param {string} data
     */
    _onMessage(data: string): void;
    _connectionClosed(): void;
}
/**
 * @unrestricted
 */
export class Service {
    /**
     * @param {!Connection} connection
     * @param {string} serviceName
     * @param {string} objectId
     */
    constructor(connection: Connection, serviceName: string, objectId: string);
    _connection: Connection;
    _serviceName: string;
    _objectId: string;
    /** @type {!Map<string, function(!Object=):void>}*/
    _notificationHandlers: Map<string, (arg0?: Object | undefined) => void>;
    /**
     * @return {!Promise<?>}
     */
    dispose(): Promise<unknown>;
    /**
     * @param {string} methodName
     * @param {function(!Object=):void} handler
     */
    on(methodName: string, handler: (arg0: Object | undefined) => void): void;
    /**
     * @param {string} methodName
     * @param {!Object<string, ?>=} params
     * @return {!Promise<?>}
     */
    send(methodName: string, params?: {
        [x: string]: unknown;
    } | undefined): Promise<unknown>;
    /**
     * @param {string} methodName
     * @param {!Object=} params
     */
    _dispatchNotification(methodName: string, params?: Object | undefined): void;
}
/**
 * @implements {ServicePort}
 * @unrestricted
 */
export class RemoteServicePort implements ServicePort {
    /**
     * @param {string} url
     */
    constructor(url: string);
    _url: string;
    /** @type {?WebSocket} */
    _socket: WebSocket | null;
    /**
     * @override
     * @param {function(string):void} messageHandler
     * @param {function():void} closeHandler
     */
    setHandlers(messageHandler: (arg0: string) => void, closeHandler: () => void): void;
    _messageHandler: ((arg0: string) => void) | undefined;
    _closeHandler: (() => void) | undefined;
    /**
     * @return {!Promise<boolean>}
     */
    _open(): Promise<boolean>;
    _connectionPromise: Promise<boolean> | undefined;
    /**
     * @override
     * @param {string} message
     * @return {!Promise<boolean>}
     */
    send(message: string): Promise<boolean>;
    /**
     * @override
     * @return {!Promise<?>}
     */
    close(): Promise<unknown>;
    /**
     * @param {boolean=} notifyClient
     */
    _socketClosed(notifyClient?: boolean | undefined): void;
}
/**
 * @implements {ServicePort}
 * @unrestricted
 */
export class WorkerServicePort implements ServicePort {
    /**
     * @param {!Worker} worker
     */
    constructor(worker: Worker);
    _worker: Worker;
    _workerPromise: Promise<any>;
    /**
     * @override
     * @param {function(string):void} messageHandler
     * @param {function():void} closeHandler
     */
    setHandlers(messageHandler: (arg0: string) => void, closeHandler: () => void): void;
    _messageHandler: ((arg0: string) => void) | undefined;
    _closeHandler: (() => void) | undefined;
    /**
     * @override
     * @param {string} message
     * @return {!Promise<boolean>}
     */
    send(message: string): Promise<boolean>;
    /**
     * @override
     * @return {!Promise<?>}
     */
    close(): Promise<unknown>;
}
