import { StringUtilities } from '../platform/platform.js';

/*
 * Copyright (C) 2012 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/**
 * @interface
 */
class ContentProvider {
    /**
     * @return {string}
     */
    contentURL() {
        throw new Error('not implemented');
    }
    /**
     * @return {!Common.ResourceType.ResourceType}
     */
    contentType() {
        throw new Error('not implemented');
    }
    /**
     * @return {!Promise<boolean>}
     */
    contentEncoded() {
        throw new Error('not implemented');
    }
    /**
     * @return {!Promise<!DeferredContent>}
     */
    requestContent() {
        throw new Error('not implemented');
    }
    /**
     * @param {string} query
     * @param {boolean} caseSensitive
     * @param {boolean} isRegex
     * @return {!Promise<!Array<!SearchMatch>>}
     */
    searchInContent(query, caseSensitive, isRegex) {
        throw new Error('not implemented');
    }
}
/**
 * @unrestricted
 */
class SearchMatch {
    /**
     * @param {number} lineNumber
     * @param {string} lineContent
     */
    constructor(lineNumber, lineContent) {
        this.lineNumber = lineNumber;
        this.lineContent = lineContent;
    }
}
/**
 * @param {?string} content
 * @param {string} mimeType
 * @param {boolean} contentEncoded
 * @param {?string=} charset
 * @return {?string}
 */
const contentAsDataURL = function (content, mimeType, contentEncoded, charset) {
    const maxDataUrlSize = 1024 * 1024;
    if (content === undefined || content === null || content.length > maxDataUrlSize) {
        return null;
    }
    return 'data:' + mimeType + (charset ? ';charset=' + charset : '') + (contentEncoded ? ';base64' : '') + ',' +
        content;
};
/**
 * @typedef {{
 *    content: string,
 *    isEncoded: boolean,
 * }|{
 *    content: null,
 *    error: string,
 *    isEncoded: boolean,
 * }}
 */
// @ts-ignore typedef
let DeferredContent;

var ContentProvider$1 = /*#__PURE__*/Object.freeze({
    __proto__: null,
    ContentProvider: ContentProvider,
    SearchMatch: SearchMatch,
    contentAsDataURL: contentAsDataURL,
    DeferredContent: DeferredContent
});

// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
/**
 * @unrestricted
 */
class TextCursor {
    /**
     * @param {!Array<number>} lineEndings
     */
    constructor(lineEndings) {
        this._lineEndings = lineEndings;
        this._offset = 0;
        this._lineNumber = 0;
        this._columnNumber = 0;
    }
    /**
     * @param {number} offset
     */
    advance(offset) {
        this._offset = offset;
        while (this._lineNumber < this._lineEndings.length && this._lineEndings[this._lineNumber] < this._offset) {
            ++this._lineNumber;
        }
        this._columnNumber = this._lineNumber ? this._offset - this._lineEndings[this._lineNumber - 1] - 1 : this._offset;
    }
    /**
     * @return {number}
     */
    offset() {
        return this._offset;
    }
    /**
     * @param {number} offset
     */
    resetTo(offset) {
        this._offset = offset;
        this._lineNumber = this._lineEndings.lowerBound(offset);
        this._columnNumber = this._lineNumber ? this._offset - this._lineEndings[this._lineNumber - 1] - 1 : this._offset;
    }
    /**
     * @return {number}
     */
    lineNumber() {
        return this._lineNumber;
    }
    /**
     * @return {number}
     */
    columnNumber() {
        return this._columnNumber;
    }
}

var TextCursor$1 = /*#__PURE__*/Object.freeze({
    __proto__: null,
    TextCursor: TextCursor
});

/*
 * Copyright (C) 2013 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/**
 * @unrestricted
 */
class TextRange {
    /**
     * @param {number} startLine
     * @param {number} startColumn
     * @param {number} endLine
     * @param {number} endColumn
     */
    constructor(startLine, startColumn, endLine, endColumn) {
        this.startLine = startLine;
        this.startColumn = startColumn;
        this.endLine = endLine;
        this.endColumn = endColumn;
    }
    /**
     * @param {number} line
     * @param {number} column
     * @return {!TextRange}
     */
    static createFromLocation(line, column) {
        return new TextRange(line, column, line, column);
    }
    /**
     * @param {{startLine: number, startColumn: number, endLine: number, endColumn: number}} serializedTextRange
     * @return {!TextRange}
     */
    static fromObject(serializedTextRange) {
        return new TextRange(serializedTextRange.startLine, serializedTextRange.startColumn, serializedTextRange.endLine, serializedTextRange.endColumn);
    }
    /**
     * @param {!TextRange} range1
     * @param {!TextRange} range2
     * @return {number}
     */
    static comparator(range1, range2) {
        return range1.compareTo(range2);
    }
    /**
     * @param {!TextRange} oldRange
     * @param {string} newText
     * @return {!TextRange}
     */
    static fromEdit(oldRange, newText) {
        let endLine = oldRange.startLine;
        let endColumn = oldRange.startColumn + newText.length;
        const lineEndings = StringUtilities.findLineEndingIndexes(newText);
        if (lineEndings.length > 1) {
            endLine = oldRange.startLine + lineEndings.length - 1;
            const len = lineEndings.length;
            endColumn = lineEndings[len - 1] - lineEndings[len - 2] - 1;
        }
        return new TextRange(oldRange.startLine, oldRange.startColumn, endLine, endColumn);
    }
    /**
     * @return {boolean}
     */
    isEmpty() {
        return this.startLine === this.endLine && this.startColumn === this.endColumn;
    }
    /**
     * @param {!TextRange=} range
     * @return {boolean}
     */
    immediatelyPrecedes(range) {
        if (!range) {
            return false;
        }
        return this.endLine === range.startLine && this.endColumn === range.startColumn;
    }
    /**
     * @param {!TextRange=} range
     * @return {boolean}
     */
    immediatelyFollows(range) {
        if (!range) {
            return false;
        }
        return range.immediatelyPrecedes(this);
    }
    /**
     * @param {!TextRange} range
     * @return {boolean}
     */
    follows(range) {
        return (range.endLine === this.startLine && range.endColumn <= this.startColumn) || range.endLine < this.startLine;
    }
    /**
     * @return {number}
     */
    get linesCount() {
        return this.endLine - this.startLine;
    }
    /**
     * @return {!TextRange}
     */
    collapseToEnd() {
        return new TextRange(this.endLine, this.endColumn, this.endLine, this.endColumn);
    }
    /**
     * @return {!TextRange}
     */
    collapseToStart() {
        return new TextRange(this.startLine, this.startColumn, this.startLine, this.startColumn);
    }
    /**
     * @return {!TextRange}
     */
    normalize() {
        if (this.startLine > this.endLine || (this.startLine === this.endLine && this.startColumn > this.endColumn)) {
            return new TextRange(this.endLine, this.endColumn, this.startLine, this.startColumn);
        }
        return this.clone();
    }
    /**
     * @return {!TextRange}
     */
    clone() {
        return new TextRange(this.startLine, this.startColumn, this.endLine, this.endColumn);
    }
    /**
     * @return {!{startLine: number, startColumn: number, endLine: number, endColumn: number}}
     */
    serializeToObject() {
        const serializedTextRange = {};
        serializedTextRange.startLine = this.startLine;
        serializedTextRange.startColumn = this.startColumn;
        serializedTextRange.endLine = this.endLine;
        serializedTextRange.endColumn = this.endColumn;
        return serializedTextRange;
    }
    /**
     * @param {!TextRange} other
     * @return {number}
     */
    compareTo(other) {
        if (this.startLine > other.startLine) {
            return 1;
        }
        if (this.startLine < other.startLine) {
            return -1;
        }
        if (this.startColumn > other.startColumn) {
            return 1;
        }
        if (this.startColumn < other.startColumn) {
            return -1;
        }
        return 0;
    }
    /**
     * @param {number} lineNumber
     * @param {number} columnNumber
     * @return {number}
     */
    compareToPosition(lineNumber, columnNumber) {
        if (lineNumber < this.startLine || (lineNumber === this.startLine && columnNumber < this.startColumn)) {
            return -1;
        }
        if (lineNumber > this.endLine || (lineNumber === this.endLine && columnNumber > this.endColumn)) {
            return 1;
        }
        return 0;
    }
    /**
     * @param {!TextRange} other
     * @return {boolean}
     */
    equal(other) {
        return this.startLine === other.startLine && this.endLine === other.endLine &&
            this.startColumn === other.startColumn && this.endColumn === other.endColumn;
    }
    /**
     * @param {number} line
     * @param {number} column
     * @return {!TextRange}
     */
    relativeTo(line, column) {
        const relative = this.clone();
        if (this.startLine === line) {
            relative.startColumn -= column;
        }
        if (this.endLine === line) {
            relative.endColumn -= column;
        }
        relative.startLine -= line;
        relative.endLine -= line;
        return relative;
    }
    /**
     * @param {number} line
     * @param {number} column
     * @return {!TextRange}
     */
    relativeFrom(line, column) {
        const relative = this.clone();
        if (this.startLine === 0) {
            relative.startColumn += column;
        }
        if (this.endLine === 0) {
            relative.endColumn += column;
        }
        relative.startLine += line;
        relative.endLine += line;
        return relative;
    }
    /**
     * @param {!TextRange} originalRange
     * @param {!TextRange} editedRange
     * @return {!TextRange}
     */
    rebaseAfterTextEdit(originalRange, editedRange) {
        console.assert(originalRange.startLine === editedRange.startLine);
        console.assert(originalRange.startColumn === editedRange.startColumn);
        const rebase = this.clone();
        if (!this.follows(originalRange)) {
            return rebase;
        }
        const lineDelta = editedRange.endLine - originalRange.endLine;
        const columnDelta = editedRange.endColumn - originalRange.endColumn;
        rebase.startLine += lineDelta;
        rebase.endLine += lineDelta;
        if (rebase.startLine === editedRange.endLine) {
            rebase.startColumn += columnDelta;
        }
        if (rebase.endLine === editedRange.endLine) {
            rebase.endColumn += columnDelta;
        }
        return rebase;
    }
    /**
     * @override
     * @return {string}
     */
    toString() {
        return JSON.stringify(this);
    }
    /**
     * @param {number} lineNumber
     * @param {number} columnNumber
     * @return {boolean}
     */
    containsLocation(lineNumber, columnNumber) {
        if (this.startLine === this.endLine) {
            return this.startLine === lineNumber && this.startColumn <= columnNumber && columnNumber <= this.endColumn;
        }
        if (this.startLine === lineNumber) {
            return this.startColumn <= columnNumber;
        }
        if (this.endLine === lineNumber) {
            return columnNumber <= this.endColumn;
        }
        return this.startLine < lineNumber && lineNumber < this.endLine;
    }
}
/**
 * @unrestricted
 */
class SourceRange {
    /**
     * @param {number} offset
     * @param {number} length
     */
    constructor(offset, length) {
        this.offset = offset;
        this.length = length;
    }
}
/**
 * @unrestricted
 */
class SourceEdit {
    /**
     * @param {string} sourceURL
     * @param {!TextRange} oldRange
     * @param {string} newText
     */
    constructor(sourceURL, oldRange, newText) {
        this.sourceURL = sourceURL;
        this.oldRange = oldRange;
        this.newText = newText;
    }
    /**
     * @param {!SourceEdit} edit1
     * @param {!SourceEdit} edit2
     * @return {number}
     */
    static comparator(edit1, edit2) {
        return TextRange.comparator(edit1.oldRange, edit2.oldRange);
    }
    /**
     * @return {!TextRange}
     */
    newRange() {
        return TextRange.fromEdit(this.oldRange, this.newText);
    }
}

var TextRange$1 = /*#__PURE__*/Object.freeze({
    __proto__: null,
    TextRange: TextRange,
    SourceRange: SourceRange,
    SourceEdit: SourceEdit
});

// Copyright 2016 The Chromium Authors. All rights reserved.
/**
 * @unrestricted
 */
class Text {
    /**
     * @param {string} value
     */
    constructor(value) {
        this._value = value;
    }
    /**
     * @return {!Array<number>}
     */
    lineEndings() {
        if (!this._lineEndings) {
            this._lineEndings = StringUtilities.findLineEndingIndexes(this._value);
        }
        return this._lineEndings;
    }
    /**
     * @return {string}
     */
    value() {
        return this._value;
    }
    /**
     * @return {number}
     */
    lineCount() {
        const lineEndings = this.lineEndings();
        return lineEndings.length;
    }
    /**
     * @param {number} lineNumber
     * @param {number} columnNumber
     * @return {number}
     */
    offsetFromPosition(lineNumber, columnNumber) {
        return (lineNumber ? this.lineEndings()[lineNumber - 1] + 1 : 0) + columnNumber;
    }
    /**
     * @param {number} offset
     * @return {!Position}
     */
    positionFromOffset(offset) {
        const lineEndings = this.lineEndings();
        const lineNumber = lineEndings.lowerBound(offset);
        return { lineNumber: lineNumber, columnNumber: offset - (lineNumber && (lineEndings[lineNumber - 1] + 1)) };
    }
    /**
     * @param {number} lineNumber
     * @return {string}
     */
    lineAt(lineNumber) {
        const lineEndings = this.lineEndings();
        const lineStart = lineNumber > 0 ? lineEndings[lineNumber - 1] + 1 : 0;
        const lineEnd = lineEndings[lineNumber];
        let lineContent = this._value.substring(lineStart, lineEnd);
        if (lineContent.length > 0 && lineContent.charAt(lineContent.length - 1) === '\r') {
            lineContent = lineContent.substring(0, lineContent.length - 1);
        }
        return lineContent;
    }
    /**
     * @param {!TextRange} range
     * @return {!SourceRange}
     */
    toSourceRange(range) {
        const start = this.offsetFromPosition(range.startLine, range.startColumn);
        const end = this.offsetFromPosition(range.endLine, range.endColumn);
        return new SourceRange(start, end - start);
    }
    /**
     * @param {!SourceRange} sourceRange
     * @return {!TextRange}
     */
    toTextRange(sourceRange) {
        const cursor = new TextCursor(this.lineEndings());
        const result = TextRange.createFromLocation(0, 0);
        cursor.resetTo(sourceRange.offset);
        result.startLine = cursor.lineNumber();
        result.startColumn = cursor.columnNumber();
        cursor.advance(sourceRange.offset + sourceRange.length);
        result.endLine = cursor.lineNumber();
        result.endColumn = cursor.columnNumber();
        return result;
    }
    /**
     * @param {!TextRange} range
     * @param {string} replacement
     * @return {string}
     */
    replaceRange(range, replacement) {
        const sourceRange = this.toSourceRange(range);
        return this._value.substring(0, sourceRange.offset) + replacement +
            this._value.substring(sourceRange.offset + sourceRange.length);
    }
    /**
     * @param {!TextRange} range
     * @return {string}
     */
    extract(range) {
        const sourceRange = this.toSourceRange(range);
        return this._value.substr(sourceRange.offset, sourceRange.length);
    }
}
/** @typedef {{lineNumber: number, columnNumber: number}} */
// @ts-ignore typedef
let Position;

var Text$1 = /*#__PURE__*/Object.freeze({
    __proto__: null,
    Text: Text,
    Position: Position
});

/*
 * Copyright (C) 2013 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
const Utils = {
    get _keyValueFilterRegex() {
        return /(?:^|\s)(\-)?([\w\-]+):([^\s]+)/;
    },
    get _regexFilterRegex() {
        return /(?:^|\s)(\-)?\/([^\s]+)\//;
    },
    get _textFilterRegex() {
        return /(?:^|\s)(\-)?([^\s]+)/;
    },
    get _SpaceCharRegex() {
        return /\s/;
    },
    /**
     * @enum {string}
     */
    get Indent() {
        return { TwoSpaces: '  ', FourSpaces: '    ', EightSpaces: '        ', TabCharacter: '\t' };
    },
    /**
     * @param {string} char
     * @return {boolean}
     */
    isStopChar: function (char) {
        return (char > ' ' && char < '0') || (char > '9' && char < 'A') || (char > 'Z' && char < '_') ||
            (char > '_' && char < 'a') || (char > 'z' && char <= '~');
    },
    /**
     * @param {string} char
     * @return {boolean}
     */
    isWordChar: function (char) {
        return !Utils.isStopChar(char) && !Utils.isSpaceChar(char);
    },
    /**
     * @param {string} char
     * @return {boolean}
     */
    isSpaceChar: function (char) {
        return Utils._SpaceCharRegex.test(char);
    },
    /**
     * @param {string} word
     * @return {boolean}
     */
    isWord: function (word) {
        for (let i = 0; i < word.length; ++i) {
            if (!Utils.isWordChar(word.charAt(i))) {
                return false;
            }
        }
        return true;
    },
    /**
     * @param {string} char
     * @return {boolean}
     */
    isOpeningBraceChar: function (char) {
        return char === '(' || char === '{';
    },
    /**
     * @param {string} char
     * @return {boolean}
     */
    isClosingBraceChar: function (char) {
        return char === ')' || char === '}';
    },
    /**
     * @param {string} char
     * @return {boolean}
     */
    isBraceChar: function (char) {
        return Utils.isOpeningBraceChar(char) || Utils.isClosingBraceChar(char);
    },
    /**
     * @param {string} text
     * @param {function(string):boolean} isWordChar
     * @param {function(string)} wordCallback
     */
    textToWords: function (text, isWordChar, wordCallback) {
        let startWord = -1;
        for (let i = 0; i < text.length; ++i) {
            if (!isWordChar(text.charAt(i))) {
                if (startWord !== -1) {
                    wordCallback(text.substring(startWord, i));
                }
                startWord = -1;
            }
            else if (startWord === -1) {
                startWord = i;
            }
        }
        if (startWord !== -1) {
            wordCallback(text.substring(startWord));
        }
    },
    /**
     * @param {string} line
     * @return {string}
     */
    lineIndent: function (line) {
        let indentation = 0;
        while (indentation < line.length && Utils.isSpaceChar(line.charAt(indentation))) {
            ++indentation;
        }
        return line.substr(0, indentation);
    },
    /**
     * @param {string} text
     * @return {boolean}
     */
    isUpperCase: function (text) {
        return text === text.toUpperCase();
    },
    /**
     * @param {string} text
     * @return {boolean}
     */
    isLowerCase: function (text) {
        return text === text.toLowerCase();
    },
    /**
     * @param {string} text
     * @param {!Array<!RegExp>} regexes
     * @return {!Array<{value: string, position: number, regexIndex: number, captureGroups: !Array<string|undefined>}>}
     */
    splitStringByRegexes(text, regexes) {
        /** @type {!Array<{value: string, position: number, regexIndex: number, captureGroups: !Array<string|undefined>}>} */
        const matches = [];
        /** @type {!Array<!RegExp>} */
        const globalRegexes = [];
        for (let i = 0; i < regexes.length; i++) {
            const regex = regexes[i];
            if (!regex.global) {
                globalRegexes.push(new RegExp(regex.source, regex.flags ? regex.flags + 'g' : 'g'));
            }
            else {
                globalRegexes.push(regex);
            }
        }
        doSplit(text, 0, 0);
        return matches;
        /**
         * @param {string} text
         * @param {number} regexIndex
         * @param {number} startIndex
         */
        function doSplit(text, regexIndex, startIndex) {
            if (regexIndex >= globalRegexes.length) {
                // Set regexIndex as -1 if text did not match with any regular expression
                matches.push({ value: text, position: startIndex, regexIndex: -1, captureGroups: [] });
                return;
            }
            const regex = globalRegexes[regexIndex];
            let currentIndex = 0;
            let result;
            regex.lastIndex = 0;
            while ((result = regex.exec(text)) !== null) {
                const stringBeforeMatch = text.substring(currentIndex, result.index);
                if (stringBeforeMatch) {
                    doSplit(stringBeforeMatch, regexIndex + 1, startIndex + currentIndex);
                }
                const match = result[0];
                matches.push({
                    value: match,
                    position: startIndex + result.index,
                    regexIndex: regexIndex,
                    captureGroups: result.slice(1)
                });
                currentIndex = result.index + match.length;
            }
            const stringAfterMatches = text.substring(currentIndex);
            if (stringAfterMatches) {
                doSplit(stringAfterMatches, regexIndex + 1, startIndex + currentIndex);
            }
        }
    }
};
class FilterParser {
    /**
     * @param {!Array<string>} keys
     */
    constructor(keys) {
        this._keys = keys;
    }
    /**
     * @param {!ParsedFilter} filter
     * @return {!ParsedFilter}
     */
    static cloneFilter(filter) {
        return { key: filter.key, text: filter.text, regex: filter.regex, negative: filter.negative };
    }
    /**
     * @param {string} query
     * @return {!Array<!ParsedFilter>}
     */
    parse(query) {
        const splitResult = Utils.splitStringByRegexes(query, [Utils._keyValueFilterRegex, Utils._regexFilterRegex, Utils._textFilterRegex]);
        /** @type {!Array<!ParsedFilter>} */
        const filters = [];
        for (let i = 0; i < splitResult.length; i++) {
            const regexIndex = splitResult[i].regexIndex;
            if (regexIndex === -1) {
                continue;
            }
            const result = splitResult[i].captureGroups;
            if (regexIndex === 0) {
                if (this._keys.indexOf(/** @type {string} */ (result[1])) !== -1) {
                    filters.push({ key: result[1], regex: undefined, text: result[2], negative: !!result[0] });
                }
                else {
                    filters.push({ key: undefined, regex: undefined, text: result[1] + ':' + result[2], negative: !!result[0] });
                }
            }
            else if (regexIndex === 1) {
                try {
                    filters.push({
                        key: undefined,
                        regex: new RegExp(/** @type {string} */ (result[1]), 'i'),
                        text: undefined,
                        negative: !!result[0]
                    });
                }
                catch (e) {
                    filters.push({ key: undefined, regex: undefined, text: '/' + result[1] + '/', negative: !!result[0] });
                }
            }
            else if (regexIndex === 2) {
                filters.push({ key: undefined, regex: undefined, text: result[1], negative: !!result[0] });
            }
        }
        return filters;
    }
}
/**
 * @unrestricted
 */
class BalancedJSONTokenizer {
    /**
     * @param {function(string):void} callback
     * @param {boolean=} findMultiple
     */
    constructor(callback, findMultiple) {
        this._callback = callback;
        /** @type {number} */
        this._index = 0;
        this._balance = 0;
        /** @type {string} */
        this._buffer = '';
        this._findMultiple = findMultiple || false;
        this._closingDoubleQuoteRegex = /[^\\](?:\\\\)*"/g;
    }
    /**
     * @param {string} chunk
     * @return {boolean}
     */
    write(chunk) {
        this._buffer += chunk;
        const lastIndex = this._buffer.length;
        const buffer = this._buffer;
        let index;
        for (index = this._index; index < lastIndex; ++index) {
            const character = buffer[index];
            if (character === '"') {
                this._closingDoubleQuoteRegex.lastIndex = index;
                if (!this._closingDoubleQuoteRegex.test(buffer)) {
                    break;
                }
                index = this._closingDoubleQuoteRegex.lastIndex - 1;
            }
            else if (character === '{') {
                ++this._balance;
            }
            else if (character === '}') {
                --this._balance;
                if (this._balance < 0) {
                    this._reportBalanced();
                    return false;
                }
                if (!this._balance) {
                    this._lastBalancedIndex = index + 1;
                    if (!this._findMultiple) {
                        break;
                    }
                }
            }
            else if (character === ']' && !this._balance) {
                this._reportBalanced();
                return false;
            }
        }
        this._index = index;
        this._reportBalanced();
        return true;
    }
    _reportBalanced() {
        if (!this._lastBalancedIndex) {
            return;
        }
        this._callback(this._buffer.slice(0, this._lastBalancedIndex));
        this._buffer = this._buffer.slice(this._lastBalancedIndex);
        this._index -= this._lastBalancedIndex;
        this._lastBalancedIndex = 0;
    }
    /**
     * @return {string}
     */
    remainder() {
        return this._buffer;
    }
}
/**
 * @interface
 */
class TokenizerFactory {
    /**
     * @param {string} mimeType
     * @return {function(string, function(string, ?string, number, number):void):void}
     */
    createTokenizer(mimeType) {
        throw new Error('not implemented');
    }
}
/**
 * @param {string} text
 * @return {boolean}
 */
function isMinified(text) {
    const kMaxNonMinifiedLength = 500;
    let linesToCheck = 10;
    let lastPosition = 0;
    do {
        let eolIndex = text.indexOf('\n', lastPosition);
        if (eolIndex < 0) {
            eolIndex = text.length;
        }
        if (eolIndex - lastPosition > kMaxNonMinifiedLength && text.substr(lastPosition, 3) !== '//#') {
            return true;
        }
        lastPosition = eolIndex + 1;
    } while (--linesToCheck >= 0 && lastPosition < text.length);
    // Check the end of the text as well
    linesToCheck = 10;
    lastPosition = text.length;
    do {
        let eolIndex = text.lastIndexOf('\n', lastPosition);
        if (eolIndex < 0) {
            eolIndex = 0;
        }
        if (lastPosition - eolIndex > kMaxNonMinifiedLength && text.substr(lastPosition, 3) !== '//#') {
            return true;
        }
        lastPosition = eolIndex - 1;
    } while (--linesToCheck >= 0 && lastPosition > 0);
    return false;
}
/**
 * @param {string} content
 * @param {string} query
 * @param {boolean} caseSensitive
 * @param {boolean} isRegex
 * @return {!Array.<!SearchMatch>}
 */
const performSearchInContent = function (content, query, caseSensitive, isRegex) {
    const regex = StringUtilities.createSearchRegex(query, caseSensitive, isRegex);
    const text = new Text(content);
    const result = [];
    for (let i = 0; i < text.lineCount(); ++i) {
        const lineContent = text.lineAt(i);
        regex.lastIndex = 0;
        if (regex.exec(lineContent)) {
            result.push(new SearchMatch(i, lineContent));
        }
    }
    return result;
};
/** @typedef {{key:(string|undefined), text:(?string|undefined), regex:(!RegExp|undefined), negative:boolean}} */
// @ts-ignore typedef
let ParsedFilter;

var TextUtils = /*#__PURE__*/Object.freeze({
    __proto__: null,
    Utils: Utils,
    FilterParser: FilterParser,
    BalancedJSONTokenizer: BalancedJSONTokenizer,
    TokenizerFactory: TokenizerFactory,
    isMinified: isMinified,
    performSearchInContent: performSearchInContent,
    ParsedFilter: ParsedFilter
});

// Copyright 2014 The Chromium Authors. All rights reserved.
/**
 * @implements {ContentProvider}
 * @unrestricted
 */
class StaticContentProvider {
    /**
     * @param {string} contentURL
     * @param {!Common.ResourceType.ResourceType} contentType
     * @param {function():!Promise<!DeferredContent>} lazyContent
     */
    constructor(contentURL, contentType, lazyContent) {
        this._contentURL = contentURL;
        this._contentType = contentType;
        this._lazyContent = lazyContent;
    }
    /**
     * @param {string} contentURL
     * @param {!Common.ResourceType.ResourceType} contentType
     * @param {string} content
     * @return {!StaticContentProvider}
     */
    static fromString(contentURL, contentType, content) {
        const lazyContent = () => Promise.resolve({ content, isEncoded: false });
        return new StaticContentProvider(contentURL, contentType, lazyContent);
    }
    /**
     * @override
     * @return {string}
     */
    contentURL() {
        return this._contentURL;
    }
    /**
     * @override
     * @return {!Common.ResourceType.ResourceType}
     */
    contentType() {
        return this._contentType;
    }
    /**
     * @override
     * @return {!Promise<boolean>}
     */
    contentEncoded() {
        return Promise.resolve(false);
    }
    /**
     * @override
     * @return {!Promise<!DeferredContent>}
     */
    requestContent() {
        return this._lazyContent();
    }
    /**
     * @override
     * @param {string} query
     * @param {boolean} caseSensitive
     * @param {boolean} isRegex
     * @return {!Promise<!Array<!SearchMatch>>}
     */
    async searchInContent(query, caseSensitive, isRegex) {
        const { content } = /** @type { {content: string, isEncoded: boolean} }*/ (await this._lazyContent());
        return content ? performSearchInContent(content, query, caseSensitive, isRegex) : [];
    }
}

var StaticContentProvider$1 = /*#__PURE__*/Object.freeze({
    __proto__: null,
    StaticContentProvider: StaticContentProvider
});

// Copyright 2019 The Chromium Authors. All rights reserved.

export { ContentProvider$1 as ContentProvider, StaticContentProvider$1 as StaticContentProvider, Text$1 as Text, TextCursor$1 as TextCursor, TextRange$1 as TextRange, TextUtils };
