/**
 * @unrestricted
 */
export class ThemeSupport {
    static hasInstance(): boolean;
    /**
     * @param {{forceNew: ?boolean, setting: ?Common.Settings.Setting<string>}} opts
     */
    static instance(opts?: {
        forceNew: boolean | null;
        setting: Common.Settings.Setting<string> | null;
    }): ThemeSupport;
    /**
     * @private
     * @param {!Common.Settings.Setting<string>} setting
     */
    private constructor();
    _themeName: string;
    _themableProperties: Set<string>;
    /** @type {!Map<string, string>} */
    _cachedThemePatches: Map<string, string>;
    _setting: Common.Settings.Setting<string>;
    _customSheets: Set<any>;
    _computedRoot: () => symbol | CSSStyleDeclaration;
    /**
     * @param {string} variableName
     * @returns {string}
     */
    getComputedValue(variableName: string): string;
    /**
     * @return {boolean}
     */
    hasTheme(): boolean;
    /**
     * @return {string}
     */
    themeName(): string;
    /**
     * @param {!Element|!ShadowRoot} element
     */
    injectHighlightStyleSheets(element: Element | ShadowRoot): void;
    _injectingStyleSheet: boolean | undefined;
    /**
     * Note: this is a duplicate of the function in ui/utils. It exists here
     * so there is no circular dependency between ui/utils and theme_support.
     *
     * @param {!Node} node
     * @param {string} cssFile
     * @suppressGlobalPropertiesCheck
     */
    _appendStyle(node: Node, cssFile: string): void;
    /**
     * @param {!Element|!ShadowRoot} element
     */
    injectCustomStyleSheets(element: Element | ShadowRoot): void;
    /**
     * @return {boolean}
     */
    isForcedColorsMode(): boolean;
    /**
     * @param {string} sheetText
     */
    addCustomStylesheet(sheetText: string): void;
    /**
     * @param {!Document} document
     */
    applyTheme(document: Document): void;
    /**
     * @param {string} id
     * @param {string} text
     * @return {string}
     * @suppressGlobalPropertiesCheck
     */
    themeStyleSheet(id: string, text: string): string;
    /**
     * @param {string} id
     * @param {!StyleSheet} styleSheet
     * @return {string}
     */
    _patchForTheme(id: string, styleSheet: StyleSheet): string;
    /**
     * @param {string} selectorText
     * @param {!CSSStyleDeclaration} style
     * @param {string} name
     * @param {!Array<string>} output
     *
     * Theming API is primarily targeted at making dark theme look good.
     * - If rule has ".-theme-preserve" in selector, it won't be affected.
     * - One can create specializations for dark themes via body.-theme-with-dark-background selector in host context.
     */
    _patchProperty(selectorText: string, style: CSSStyleDeclaration, name: string, output: Array<string>): void;
    /**
     * @param {string} text
     * @param {!ThemeSupport.ColorUsage} colorUsage
     * @return {string}
     */
    patchColorText(text: string, colorUsage: ThemeSupport.ColorUsage): string;
    /**
     * @param {!Common.Color.Color} color
     * @param {!ThemeSupport.ColorUsage} colorUsage
     * @return {!Common.Color.Color}
     */
    patchColor(color: Common.Color.Color, colorUsage: ThemeSupport.ColorUsage): Common.Color.Color;
    /**
     * @param {!Array<number>} hsla
     * @param {!ThemeSupport.ColorUsage} colorUsage
     */
    _patchHSLA(hsla: Array<number>, colorUsage: ThemeSupport.ColorUsage): void;
}
export namespace ThemeSupport {
    namespace ColorUsage {
        const Unknown: number;
        const Foreground: number;
        const Background: number;
    }
    type ColorUsage = number;
}
import * as Common from "../common/common.js";
