/**
 * @unrestricted
 */
export class TimelineFrameModel {
    /**
     * @param {function(!SDK.TracingModel.Event):string} categoryMapper
     */
    constructor(categoryMapper: (arg0: SDK.TracingModel.Event) => string);
    _categoryMapper: (arg0: SDK.TracingModel.Event) => string;
    /** @type {!Array<!TimelineFrame>} */
    _frames: Array<TimelineFrame>;
    /** @type {!Object<number, !TimelineFrame>} */
    _frameById: {
        [x: number]: TimelineFrame;
    };
    /** @type {number} */
    _minimumRecordTime: number;
    /** @type {?TimelineFrame} */
    _lastFrame: TimelineFrame | null;
    /** @type {boolean} */
    _mainFrameCommitted: boolean;
    /** @type {boolean} */
    _mainFrameRequested: boolean;
    /** @type {?TracingFrameLayerTree} */
    _lastLayerTree: TracingFrameLayerTree | null;
    /** @type {?PendingFrame} */
    _framePendingActivation: PendingFrame | null;
    /** @type {!Object<string, number>} */
    _currentTaskTimeByCategory: {
        [x: string]: number;
    };
    /** @type {?SDK.SDKModel.Target} */
    _target: SDK.SDKModel.Target | null;
    /**
     * @param {number=} startTime
     * @param {number=} endTime
     * @return {!Array<!TimelineFrame>}
     */
    frames(startTime?: number | undefined, endTime?: number | undefined): Array<TimelineFrame>;
    /**
     * @param {!SDK.TracingModel.Event} rasterTask
     * @return {boolean}
     */
    hasRasterTile(rasterTask: SDK.TracingModel.Event): boolean;
    /**
     * @param {!SDK.TracingModel.Event} rasterTask
     * @return {!Promise<?{rect: !Protocol.DOM.Rect, snapshot: !SDK.PaintProfiler.PaintProfilerSnapshot}>}
     */
    rasterTilePromise(rasterTask: SDK.TracingModel.Event): Promise<{
        rect: Protocol.DOM.Rect;
        snapshot: SDK.PaintProfiler.PaintProfilerSnapshot;
    } | null>;
    reset(): void;
    _framePendingCommit: PendingFrame | null | undefined;
    _lastBeginFrame: number | null | undefined;
    _lastNeedsBeginFrame: number | null | undefined;
    _lastTaskBeginTime: number | null | undefined;
    _layerTreeId: any;
    /**
     * @param {number} startTime
     */
    handleBeginFrame(startTime: number): void;
    /**
     * @param {number} startTime
     */
    handleDrawFrame(startTime: number): void;
    handleActivateLayerTree(): void;
    handleRequestMainThreadFrame(): void;
    handleCompositeLayers(): void;
    /**
     * @param {!TracingFrameLayerTree} layerTree
     */
    handleLayerTreeSnapshot(layerTree: TracingFrameLayerTree): void;
    /**
     * @param {number} startTime
     * @param {boolean} needsBeginFrame
     */
    handleNeedFrameChanged(startTime: number, needsBeginFrame: boolean): void;
    /**
     * @param {number} startTime
     */
    _startFrame(startTime: number): void;
    /**
     * @param {!TimelineFrame} frame
     * @param {number} endTime
     */
    _flushFrame(frame: TimelineFrame, endTime: number): void;
    _commitPendingFrame(): void;
    /**
     * @param {?SDK.SDKModel.Target} target
     * @param {!Array.<!SDK.TracingModel.Event>} events
     * @param {!Array<!{thread: !SDK.TracingModel.Thread, time: number}>} threadData
     */
    addTraceEvents(target: SDK.SDKModel.Target | null, events: Array<SDK.TracingModel.Event>, threadData: {
        thread: SDK.TracingModel.Thread;
        time: number;
    }[]): void;
    _currentProcessMainThread: SDK.TracingModel.Thread | null | undefined;
    /**
     * @param {!SDK.TracingModel.Event} event
     */
    _addTraceEvent(event: SDK.TracingModel.Event): void;
    /**
     * @param {!SDK.TracingModel.Event} event
     */
    _processCompositorEvents(event: SDK.TracingModel.Event): void;
    /**
     * @param {!SDK.TracingModel.Event} event
     */
    _addMainThreadTraceEvent(event: SDK.TracingModel.Event): void;
    /**
     * @param {!Object.<string, number>} timeByCategory
     * @param {!SDK.TracingModel.Event} event
     */
    _addTimeForCategory(timeByCategory: {
        [x: string]: number;
    }, event: SDK.TracingModel.Event): void;
}
export namespace TimelineFrameModel {
    const _mainFrameMarkers: string[];
}
/**
 * @unrestricted
 */
export class TracingFrameLayerTree {
    /**
     * @param {!SDK.SDKModel.Target} target
     * @param {!SDK.TracingModel.ObjectSnapshot} snapshot
     */
    constructor(target: SDK.SDKModel.Target, snapshot: SDK.TracingModel.ObjectSnapshot);
    _target: SDK.SDKModel.Target;
    _snapshot: SDK.TracingModel.ObjectSnapshot;
    /** @type {!Array<!LayerPaintEvent>|undefined} */
    _paints: Array<LayerPaintEvent> | undefined;
    /**
     * @return {!Promise<?TracingLayerTree>}
     */
    layerTreePromise(): Promise<TracingLayerTree | null>;
    /**
     * @return {!Array<!LayerPaintEvent>}
     */
    paints(): Array<LayerPaintEvent>;
    /**
     * @param {!Array<!LayerPaintEvent>} paints
     */
    _setPaints(paints: Array<LayerPaintEvent>): void;
}
/**
 * @unrestricted
 */
export class TimelineFrame {
    /**
     * @param {number} startTime
     * @param {number} startTimeOffset
     */
    constructor(startTime: number, startTimeOffset: number);
    startTime: number;
    startTimeOffset: number;
    endTime: number;
    duration: number;
    /** @type {!Object<string, number>} */
    timeByCategory: {
        [x: string]: number;
    };
    cpuTime: number;
    idle: boolean;
    /** @type {?TracingFrameLayerTree} */
    layerTree: TracingFrameLayerTree | null;
    /** @type {!Array.<!LayerPaintEvent>} */
    _paints: Array<LayerPaintEvent>;
    /** @type {number|undefined} */
    _mainFrameId: number | undefined;
    /**
     * @return {boolean}
     */
    hasWarnings(): boolean;
    /**
     * @param {number} endTime
     */
    _setEndTime(endTime: number): void;
    /**
     * @param {?TracingFrameLayerTree} layerTree
     */
    _setLayerTree(layerTree: TracingFrameLayerTree | null): void;
    /**
     * @param {!Object<string, number>} timeByCategory
     */
    _addTimeForCategories(timeByCategory: {
        [x: string]: number;
    }): void;
    /**
     * @param {string} category
     * @param {number} time
     */
    _addTimeForCategory(category: string, time: number): void;
}
/**
 * @unrestricted
 */
export class LayerPaintEvent {
    /**
     * @param {!SDK.TracingModel.Event} event
     * @param {?SDK.SDKModel.Target} target
     */
    constructor(event: SDK.TracingModel.Event, target: SDK.SDKModel.Target | null);
    _event: SDK.TracingModel.Event;
    _target: SDK.SDKModel.Target | null;
    /**
     * @return {string}
     */
    layerId(): string;
    /**
     * @return {!SDK.TracingModel.Event}
     */
    event(): SDK.TracingModel.Event;
    /**
     * @return {!Promise<?{rect: !Array<number>, serializedPicture: string}>}
     */
    picturePromise(): Promise<{
        rect: Array<number>;
        serializedPicture: string;
    } | null>;
    /**
     * @return !Promise<?{rect: !Array<number>, snapshot: !SDK.PaintProfiler.PaintProfilerSnapshot}>}
     */
    snapshotPromise(): Promise<any>;
}
/**
 * @unrestricted
 */
export class PendingFrame {
    /**
     * @param {number} triggerTime
     * @param {!Object.<string, number>} timeByCategory
     */
    constructor(triggerTime: number, timeByCategory: {
        [x: string]: number;
    });
    /** @type {!Object.<string, number>} */
    timeByCategory: {
        [x: string]: number;
    };
    /** @type {!Array.<!LayerPaintEvent>} */
    paints: Array<LayerPaintEvent>;
    /** @type {number|undefined} */
    mainFrameId: number | undefined;
    triggerTime: number;
}
import * as SDK from "../sdk/sdk.js";
import { TracingLayerTree } from "./TracingLayerTree.js";
