/**
 * @unrestricted
 */
export class TimelineIRModel {
    /**
     * @param {!SDK.TracingModel.Event} event
     * @return {!Phases}
     */
    static phaseForEvent(event: SDK.TracingModel.Event): Phases;
    /**
     * @param {?Array<!SDK.TracingModel.AsyncEvent>} inputLatencies
     * @param {?Array<!SDK.TracingModel.AsyncEvent>} animations
     */
    populate(inputLatencies: Array<SDK.TracingModel.AsyncEvent> | null, animations: Array<SDK.TracingModel.AsyncEvent> | null): void;
    _segments: any[] | undefined;
    /**
     * @param {!Array<!SDK.TracingModel.AsyncEvent>} events
     */
    _processInputLatencies(events: Array<SDK.TracingModel.AsyncEvent>): void;
    /**
     * @param {!Array<!SDK.TracingModel.AsyncEvent>} events
     */
    _processAnimations(events: Array<SDK.TracingModel.AsyncEvent>): void;
    /**
     * @param {!SDK.TracingModel.AsyncEvent} event
     * @param {!Phases} phase
     * @return {!Common.SegmentedRange.Segment}
     */
    _segmentForEvent(event: SDK.TracingModel.AsyncEvent, phase: Phases): Common.SegmentedRange.Segment;
    /**
     * @param {!SDK.TracingModel.AsyncEvent} startEvent
     * @param {!SDK.TracingModel.AsyncEvent} endEvent
     * @param {!Phases} phase
     * @return {!Common.SegmentedRange.Segment}
     */
    _segmentForEventRange(startEvent: SDK.TracingModel.AsyncEvent, endEvent: SDK.TracingModel.AsyncEvent, phase: Phases): Common.SegmentedRange.Segment;
    /**
     * @param {!SDK.TracingModel.AsyncEvent} asyncEvent
     * @param {!Phases} phase
     */
    _setPhaseForEvent(asyncEvent: SDK.TracingModel.AsyncEvent, phase: Phases): void;
    /**
     * @return {!Array<!Common.SegmentedRange.Segment>}
     */
    interactionRecords(): Array<Common.SegmentedRange.Segment>;
    reset(): void;
    _drags: Common.SegmentedRange.SegmentedRange | undefined;
    _cssAnimations: Common.SegmentedRange.SegmentedRange | undefined;
    _responses: Common.SegmentedRange.SegmentedRange | undefined;
    _scrolls: Common.SegmentedRange.SegmentedRange | undefined;
    /**
     * @param {string} eventName
     * @return {?InputEvents}
     */
    _inputEventType(eventName: string): InputEvents | null;
}
export namespace TimelineIRModel {
    namespace _mergeThresholdsMs {
        const animation: number;
        const mouse: number;
    }
    const _eventIRPhase: symbol;
}
export type Phases = string;
export namespace Phases {
    const Idle: string;
    const Response: string;
    const Scroll: string;
    const Fling: string;
    const Drag: string;
    const Animation: string;
    const Uncategorized: string;
}
export type InputEvents = string;
export namespace InputEvents {
    const Char: string;
    const Click: string;
    const ContextMenu: string;
    const FlingCancel: string;
    const FlingStart: string;
    const ImplSideFling: string;
    const KeyDown: string;
    const KeyDownRaw: string;
    const KeyUp: string;
    const LatencyScrollUpdate: string;
    const MouseDown: string;
    const MouseMove: string;
    const MouseUp: string;
    const MouseWheel: string;
    const PinchBegin: string;
    const PinchEnd: string;
    const PinchUpdate: string;
    const ScrollBegin: string;
    const ScrollEnd: string;
    const ScrollUpdate: string;
    const ScrollUpdateRenderer: string;
    const ShowPress: string;
    const Tap: string;
    const TapCancel: string;
    const TapDown: string;
    const TouchCancel: string;
    const TouchEnd: string;
    const TouchMove: string;
    const TouchStart: string;
}
import * as SDK from "../sdk/sdk.js";
import * as Common from "../common/common.js";
