/**
 * @unrestricted
 */
export class TimelineModelImpl {
    /**
     * @param {!Array<!SDK.TracingModel.Event>} events
     * @param {function(!SDK.TracingModel.Event)} onStartEvent
     * @param {function(!SDK.TracingModel.Event)} onEndEvent
     * @param {function(!SDK.TracingModel.Event,?SDK.TracingModel.Event)|undefined=} onInstantEvent
     * @param {number=} startTime
     * @param {number=} endTime
     * @param {function(!SDK.TracingModel.Event):boolean=} filter
     */
    static forEachEvent(events: Array<SDK.TracingModel.Event>, onStartEvent: (arg0: SDK.TracingModel.Event) => any, onEndEvent: (arg0: SDK.TracingModel.Event) => any, onInstantEvent?: (((arg0: SDK.TracingModel.Event, arg1: SDK.TracingModel.Event | null) => any) | undefined) | undefined, startTime?: number | undefined, endTime?: number | undefined, filter?: ((arg0: SDK.TracingModel.Event) => boolean) | undefined): void;
    /**
     * @param {!Array<!SDK.TracingModel.Event>} events
     * @param {number} time
     */
    static _topLevelEventEndingAfter(events: Array<SDK.TracingModel.Event>, time: number): number;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @param {string} field
     * @return {string}
     */
    static globalEventId(event: SDK.TracingModel.Event, field: string): string;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @return {string}
     */
    static eventFrameId(event: SDK.TracingModel.Event): string;
    _estimatedTotalBlockingTime: number;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @return {boolean}
     */
    isMarkerEvent(event: SDK.TracingModel.Event): boolean;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @return {boolean}
     */
    isInteractiveTimeEvent(event: SDK.TracingModel.Event): boolean;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @return {boolean}
     */
    isLayoutShiftEvent(event: SDK.TracingModel.Event): boolean;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @return {boolean}
     */
    isUserTimingEvent(event: SDK.TracingModel.Event): boolean;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @return {boolean}
     */
    isParseHTMLEvent(event: SDK.TracingModel.Event): boolean;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @return {boolean}
     */
    isLCPCandidateEvent(event: SDK.TracingModel.Event): boolean;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @return {boolean}
     */
    isLCPInvalidateEvent(event: SDK.TracingModel.Event): boolean;
    /**
     * @return {!Array<!SDK.CPUProfileDataModel.CPUProfileDataModel>}
     */
    cpuProfiles(): Array<SDK.CPUProfileDataModel.CPUProfileDataModel>;
    /**
     * @return {{time: number, estimated: boolean}}
     */
    totalBlockingTime(): {
        time: number;
        estimated: boolean;
    };
    /**
     * @param {!SDK.TracingModel.Event} event
     * @return {?SDK.SDKModel.Target}
     */
    targetByEvent(event: SDK.TracingModel.Event): SDK.SDKModel.Target | null;
    /**
     * @return {!Map<string, !SDK.TracingModel.Event>}
     */
    navStartTimes(): Map<string, SDK.TracingModel.Event>;
    /**
     * @param {!SDK.TracingModel.TracingModel} tracingModel
     */
    setEvents(tracingModel: SDK.TracingModel.TracingModel): void;
    _tracingModel: SDK.TracingModel.TracingModel | undefined;
    _minimumRecordTime: number | undefined;
    _maximumRecordTime: number | undefined;
    _isGenericTrace: boolean | undefined;
    /**
     * @param {!SDK.TracingModel.TracingModel} tracingModel
     */
    _processGenericTrace(tracingModel: SDK.TracingModel.TracingModel): void;
    /**
     * @param {!SDK.TracingModel.TracingModel} tracingModel
     * @param {!MetadataEvents} metadataEvents
     */
    _processMetadataAndThreads(tracingModel: SDK.TracingModel.TracingModel, metadataEvents: MetadataEvents): void;
    _legacyCurrentPage: any;
    /**
     * @param {!SDK.TracingModel.TracingModel} tracingModel
     */
    _processThreadsForBrowserFrames(tracingModel: SDK.TracingModel.TracingModel): void;
    /**
     * @param {!SDK.TracingModel.TracingModel} tracingModel
     * @return {?MetadataEvents}
     */
    _processMetadataEvents(tracingModel: SDK.TracingModel.TracingModel): MetadataEvents | null;
    _persistentIds: boolean | undefined;
    _mainFrame: PageFrame | null | undefined;
    _mainFrameNodeId: number | null | undefined;
    _sessionId: string | null | undefined;
    /**
     * @param {!SDK.TracingModel.TracingModel} tracingModel
     */
    _processSyncBrowserEvents(tracingModel: SDK.TracingModel.TracingModel): void;
    /**
     * @param {!SDK.TracingModel.TracingModel} tracingModel
     */
    _processAsyncBrowserEvents(tracingModel: SDK.TracingModel.TracingModel): void;
    /**
     * @param {!SDK.TracingModel.TracingModel} tracingModel
     */
    _buildGPUEvents(tracingModel: SDK.TracingModel.TracingModel): void;
    /**
     * @param {!SDK.TracingModel.TracingModel} tracingModel
     * @param {!Array<!SDK.TracingModel.Event>} events
     */
    _buildLoadingEvents(tracingModel: SDK.TracingModel.TracingModel, events: Array<SDK.TracingModel.Event>): void;
    _resetProcessingState(): void;
    _asyncEventTracker: TimelineAsyncEventTracker | undefined;
    _invalidationTracker: InvalidationTracker | undefined;
    _layoutInvalidate: {} | undefined;
    _lastScheduleStyleRecalculation: {} | undefined;
    _paintImageEventByPixelRefId: {} | undefined;
    _lastPaintForLayer: {} | undefined;
    _lastRecalculateStylesEvent: SDK.TracingModel.Event | null | undefined;
    _currentScriptEvent: SDK.TracingModel.Event | null | undefined;
    _eventStack: any[] | undefined;
    /** @type {!Set<string>} */
    _knownInputEvents: Set<string> | undefined;
    _browserFrameTracking: boolean | undefined;
    /**
     * @param {!SDK.TracingModel.TracingModel} tracingModel
     * @param {!SDK.TracingModel.Thread} thread
     * @return {?SDK.CPUProfileDataModel.CPUProfileDataModel}
     */
    _extractCpuProfile(tracingModel: SDK.TracingModel.TracingModel, thread: SDK.TracingModel.Thread): SDK.CPUProfileDataModel.CPUProfileDataModel | null;
    /**
     * @param {!SDK.TracingModel.TracingModel} tracingModel
     * @param {!SDK.TracingModel.Thread} thread
     * @return {!Array<!SDK.TracingModel.Event>}
     */
    _injectJSFrameEvents(tracingModel: SDK.TracingModel.TracingModel, thread: SDK.TracingModel.Thread): Array<SDK.TracingModel.Event>;
    /**
     * @param {!SDK.TracingModel.TracingModel} tracingModel
     * @param {!Array<!{from: number, to: number}>} ranges
     * @param {!SDK.TracingModel.Thread} thread
     * @param {boolean} isMainThread
     * @param {boolean} isWorker
     * @param {boolean} forMainFrame
     * @param {?string} url
     */
    _processThreadEvents(tracingModel: SDK.TracingModel.TracingModel, ranges: {
        from: number;
        to: number;
    }[], thread: SDK.TracingModel.Thread, isMainThread: boolean, isWorker: boolean, forMainFrame: boolean, url: string | null): void;
    _totalBlockingTime: any;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @param {!SDK.TracingModel.Event} child
     */
    _fixNegativeDuration(event: SDK.TracingModel.Event, child: SDK.TracingModel.Event): void;
    /**
     * @param {!SDK.TracingModel.Thread} thread
     * @param {!Array<!{from: number, to: number}>} ranges
     */
    _processAsyncEvents(thread: SDK.TracingModel.Thread, ranges: {
        from: number;
        to: number;
    }[]): void;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @return {boolean}
     */
    _processEvent(event: SDK.TracingModel.Event): boolean;
    _currentTaskLayoutAndRecalcEvents: any[] | undefined;
    _mainFrameLayerTreeId: any;
    /**
     * @param {!SDK.TracingModel.Event} event
     */
    _processBrowserEvent(event: SDK.TracingModel.Event): void;
    /**
     * @param {!TrackType} type
     * @return {!Track}
     */
    _ensureNamedTrack(type: TrackType): Track;
    /**
     * @param {string} name
     * @return {?SDK.TracingModel.Event}
     */
    _findAncestorEvent(name: string): SDK.TracingModel.Event | null;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @param {!Object} payload
     * @return {boolean}
     */
    _addPageFrame(event: SDK.TracingModel.Event, payload: Object): boolean;
    _reset(): void;
    /** @type {!Array<!Track>} */
    _tracks: Track[] | undefined;
    /** @type {!Map<!TrackType, !Track>} */
    _namedTracks: Map<symbol, Track> | undefined;
    /** @type {!Array<!SDK.TracingModel.Event>} */
    _inspectedTargetEvents: SDK.TracingModel.Event[] | undefined;
    /** @type {!Array<!SDK.TracingModel.Event>} */
    _timeMarkerEvents: SDK.TracingModel.Event[] | undefined;
    /** @type {!Array<!SDK.CPUProfileDataModel.CPUProfileDataModel>} */
    _cpuProfiles: SDK.CPUProfileDataModel.CPUProfileDataModel[] | undefined;
    /** @type {!WeakMap<!SDK.TracingModel.Thread, string>} */
    _workerIdByThread: WeakMap<SDK.TracingModel.Thread, string> | undefined;
    /** @type {!Map<string, !PageFrame>} */
    _pageFrames: Map<string, PageFrame> | undefined;
    /** @type {!Map<string, !SDK.TracingModel.Event>} */
    _requestsFromBrowser: Map<string, SDK.TracingModel.Event> | undefined;
    /**
     * @return {boolean}
     */
    isGenericTrace(): boolean;
    /**
     * @return {!SDK.TracingModel.TracingModel}
     */
    tracingModel(): SDK.TracingModel.TracingModel;
    /**
     * @return {number}
     */
    minimumRecordTime(): number;
    /**
     * @return {number}
     */
    maximumRecordTime(): number;
    /**
     * @return {!Array<!SDK.TracingModel.Event>}
     */
    inspectedTargetEvents(): Array<SDK.TracingModel.Event>;
    /**
     * @return {!Array<!Track>}
     */
    tracks(): Array<Track>;
    /**
     * @return {boolean}
     */
    isEmpty(): boolean;
    /**
     * @return {!Array<!SDK.TracingModel.Event>}
     */
    timeMarkerEvents(): Array<SDK.TracingModel.Event>;
    /**
     * @return {!Array<!PageFrame>}
     */
    rootFrames(): Array<PageFrame>;
    /**
     * @return {string}
     */
    pageURL(): string;
    /**
     * @param {string} frameId
     * @return {?PageFrame}
     */
    pageFrameById(frameId: string): PageFrame | null;
    /**
     * @return {!Array<!NetworkRequest>}
     */
    networkRequests(): Array<NetworkRequest>;
}
export namespace TimelineModelImpl {
    namespace Category {
        const Console: string;
        const UserTiming: string;
        const LatencyInfo: string;
        const Loading: string;
    }
    namespace WarningType {
        const LongTask: string;
        const ForcedStyle: string;
        const ForcedLayout: string;
        const IdleDeadlineExceeded: string;
        const LongHandler: string;
        const LongRecurringHandler: string;
        const V8Deopt: string;
    }
    type WarningType = string;
    const WorkerThreadName: string;
    const WorkerThreadNameLegacy: string;
    const RendererMainThreadName: string;
    const BrowserMainThreadName: string;
    namespace DevToolsMetadataEvent {
        const TracingStartedInBrowser: string;
        const TracingStartedInPage: string;
        const TracingSessionIdForWorker: string;
        const FrameCommittedInBrowser: string;
        const ProcessReadyInBrowser: string;
        const FrameDeletedInBrowser: string;
    }
    namespace Thresholds {
        const LongTask_1: number;
        export { LongTask_1 as LongTask };
        export const Handler: number;
        export const RecurringHandler: number;
        const ForcedLayout_1: number;
        export { ForcedLayout_1 as ForcedLayout };
        export const IdleCallbackAddon: number;
    }
}
export type RecordType = string;
export namespace RecordType {
    export const Task: string;
    export const Program: string;
    export const EventDispatch: string;
    export const GPUTask: string;
    export const Animation: string;
    export const RequestMainThreadFrame: string;
    export const BeginFrame: string;
    export const NeedsBeginFrameChanged: string;
    export const BeginMainThreadFrame: string;
    export const ActivateLayerTree: string;
    export const DrawFrame: string;
    export const HitTest: string;
    export const ScheduleStyleRecalculation: string;
    export const RecalculateStyles: string;
    export const UpdateLayoutTree: string;
    export const InvalidateLayout: string;
    export const Layout: string;
    export const LayoutShift: string;
    export const UpdateLayer: string;
    export const UpdateLayerTree: string;
    export const PaintSetup: string;
    export const Paint: string;
    export const PaintImage: string;
    export const Rasterize: string;
    export const RasterTask: string;
    export const ScrollLayer: string;
    export const CompositeLayers: string;
    export const InteractiveTime: string;
    export const ScheduleStyleInvalidationTracking: string;
    export const StyleRecalcInvalidationTracking: string;
    export const StyleInvalidatorInvalidationTracking: string;
    export const LayoutInvalidationTracking: string;
    export const ParseHTML: string;
    export const ParseAuthorStyleSheet: string;
    export const TimerInstall: string;
    export const TimerRemove: string;
    export const TimerFire: string;
    export const XHRReadyStateChange: string;
    export const XHRLoad: string;
    export const CompileScript: string;
    export const EvaluateScript: string;
    export const CompileModule: string;
    export const EvaluateModule: string;
    export const WasmStreamFromResponseCallback: string;
    export const WasmCompiledModule: string;
    export const WasmCachedModule: string;
    export const WasmModuleCacheHit: string;
    export const WasmModuleCacheInvalid: string;
    export const FrameStartedLoading: string;
    export const CommitLoad: string;
    export const MarkLoad: string;
    export const MarkDOMContent: string;
    export const MarkFirstPaint: string;
    export const MarkFCP: string;
    export const MarkLCPCandidate: string;
    export const MarkLCPInvalidate: string;
    export const NavigationStart: string;
    export const TimeStamp: string;
    export const ConsoleTime: string;
    const UserTiming_1: string;
    export { UserTiming_1 as UserTiming };
    export const ResourceWillSendRequest: string;
    export const ResourceSendRequest: string;
    export const ResourceReceiveResponse: string;
    export const ResourceReceivedData: string;
    export const ResourceFinish: string;
    export const ResourceMarkAsCached: string;
    export const RunMicrotasks: string;
    export const FunctionCall: string;
    export const GCEvent: string;
    export const MajorGC: string;
    export const MinorGC: string;
    export const JSFrame: string;
    export const JSSample: string;
    export const V8Sample: string;
    export const JitCodeAdded: string;
    export const JitCodeMoved: string;
    export const StreamingCompileScript: string;
    export const StreamingCompileScriptWaiting: string;
    export const StreamingCompileScriptParsing: string;
    export const V8Execute: string;
    export const UpdateCounters: string;
    export const RequestAnimationFrame: string;
    export const CancelAnimationFrame: string;
    export const FireAnimationFrame: string;
    export const RequestIdleCallback: string;
    export const CancelIdleCallback: string;
    export const FireIdleCallback: string;
    export const WebSocketCreate: string;
    export const WebSocketSendHandshakeRequest: string;
    export const WebSocketReceiveHandshakeResponse: string;
    export const WebSocketDestroy: string;
    export const EmbedderCallback: string;
    export const SetLayerTreeId: string;
    const TracingStartedInPage_1: string;
    export { TracingStartedInPage_1 as TracingStartedInPage };
    const TracingSessionIdForWorker_1: string;
    export { TracingSessionIdForWorker_1 as TracingSessionIdForWorker };
    export const DecodeImage: string;
    export const ResizeImage: string;
    export const DrawLazyPixelRef: string;
    export const DecodeLazyPixelRef: string;
    export const LazyPixelRef: string;
    export const LayerTreeHostImplSnapshot: string;
    export const PictureSnapshot: string;
    export const DisplayItemListSnapshot: string;
    const LatencyInfo_1: string;
    export { LatencyInfo_1 as LatencyInfo };
    export const LatencyInfoFlow: string;
    export const InputLatencyMouseMove: string;
    export const InputLatencyMouseWheel: string;
    export const ImplSideFling: string;
    export const GCCollectGarbage: string;
    export const CryptoDoEncrypt: string;
    export const CryptoDoEncryptReply: string;
    export const CryptoDoDecrypt: string;
    export const CryptoDoDecryptReply: string;
    export const CryptoDoDigest: string;
    export const CryptoDoDigestReply: string;
    export const CryptoDoSign: string;
    export const CryptoDoSignReply: string;
    export const CryptoDoVerify: string;
    export const CryptoDoVerifyReply: string;
    export const CpuProfile: string;
    export const Profile: string;
    export const AsyncTask: string;
}
export class Track {
    name: string;
    type: symbol;
    forMainFrame: boolean;
    url: string;
    /** @type {!Array<!SDK.TracingModel.Event>} */
    events: Array<SDK.TracingModel.Event>;
    /** @type {!Array<!SDK.TracingModel.AsyncEvent>} */
    asyncEvents: Array<SDK.TracingModel.AsyncEvent>;
    /** @type {!Array<!SDK.TracingModel.Event>} */
    tasks: Array<SDK.TracingModel.Event>;
    _syncEvents: any[] | null;
    /** @type {?SDK.TracingModel.Thread} */
    thread: SDK.TracingModel.Thread | null;
    /**
     * @return {!Array<!SDK.TracingModel.Event>}
     */
    syncEvents(): Array<SDK.TracingModel.Event>;
}
export type TrackType = symbol;
export namespace TrackType {
    export const MainThread: symbol;
    export const Worker: symbol;
    export const Input: symbol;
    const Animation_1: symbol;
    export { Animation_1 as Animation };
    export const Timings: symbol;
    const Console_1: symbol;
    export { Console_1 as Console };
    export const Raster: symbol;
    export const GPU: symbol;
    export const Experience: symbol;
    export const Other: symbol;
}
export class PageFrame {
    /**
     * @param {!Object} payload
     */
    constructor(payload: Object);
    frameId: any;
    url: any;
    name: any;
    /** @type {!Array<!PageFrame>} */
    children: Array<PageFrame>;
    /** @type {?PageFrame} */
    parent: PageFrame | null;
    /** @type {!Array<!{time: number, processId: number, processPseudoId: ?string, url: string}>} */
    processes: {
        time: number;
        processId: number;
        processPseudoId: string | null;
        url: string;
    }[];
    /** @type {?number} */
    deletedTime: number | null;
    ownerNode: any;
    /**
     * @param {number} time
     * @param {!Object} payload
     */
    update(time: number, payload: Object): void;
    /**
     * @param {string} processPseudoId
     * @param {number} processId
     */
    processReady(processPseudoId: string, processId: number): void;
    /**
     * @param {!PageFrame} child
     */
    addChild(child: PageFrame): void;
}
/**
 * @unrestricted
 */
export class NetworkRequest {
    /**
     * @param {!SDK.TracingModel.Event} event
     */
    constructor(event: SDK.TracingModel.Event);
    startTime: number;
    endTime: number;
    encodedDataLength: number;
    decodedBodyLength: number;
    /** @type {!Array<!SDK.TracingModel.Event>} */
    children: Array<SDK.TracingModel.Event>;
    /** @type {?Object} */
    timing: Object | null;
    /** @type {string} */
    mimeType: string;
    /** @type {string} */
    url: string;
    /** @type {string} */
    requestMethod: string;
    /** @type {number} */
    _transferSize: number;
    /** @type {boolean} */
    _maybeDiskCached: boolean;
    /** @type {boolean} */
    _memoryCached: boolean;
    /**
     * @param {!SDK.TracingModel.Event} event
     */
    addEvent(event: SDK.TracingModel.Event): void;
    priority: any;
    finishTime: number | undefined;
    responseTime: number | undefined;
    fromServiceWorker: boolean | undefined;
    hasCachedResource: boolean | undefined;
    /**
     * Return whether this request was cached. This works around BUG(chromium:998397),
     * which reports pushed resources, and resources serverd by a service worker as
     * disk cached. Pushed resources that were not disk cached, however, have a non-zero
     * `_transferSize`.
     * @return {boolean}
     */
    cached(): boolean;
    /**
     * Return whether this request was served from a memory cache.
     * @return {boolean}
     */
    memoryCached(): boolean;
    /**
     * Get the timing information for this request. If the request was cached,
     * the timing refers to the original (uncached) load, and should not be used.
     * @return {!{sendStartTime: number, headersEndTime: number}}
     */
    getSendReceiveTiming(): {
        sendStartTime: number;
        headersEndTime: number;
    };
    /**
     * Get the start time of this request, i.e. the time when the browser or
     * renderer queued this request. There are two cases where request time is
     * earlier than `startTime`: (1) if the request is served from cache, because
     * it refers to the original load of the resource. (2) if the request was
     * initiated by the browser instead of the renderer. Only in case (2) the
     * the request time must be used instead of the start time to work around
     * BUG(chromium:865066).
     * @return {number}
     */
    getStartTime(): number;
    /**
     * Returns the time where the earliest event belonging to this request starts.
     * This differs from `getStartTime()` if a previous HTTP/2 request pushed the
     * resource proactively: Then `beginTime()` refers to the time the push was received.
     * @return {number}
     */
    beginTime(): number;
}
/**
 * @unrestricted
 */
export class InvalidationTrackingEvent {
    /**
     * @param {!SDK.TracingModel.Event} event
     */
    constructor(event: SDK.TracingModel.Event);
    /** @type {string} */
    type: string;
    /** @type {number} */
    startTime: number;
    /** @type {!SDK.TracingModel.Event} */
    _tracingEvent: SDK.TracingModel.Event;
    /** @type {number} */
    frame: number;
    /** @type {?number} */
    nodeId: number | null;
    /** @type {?string} */
    nodeName: string | null;
    /** @type {?number} */
    invalidationSet: number | null;
    /** @type {?string} */
    invalidatedSelectorId: string | null;
    /** @type {?string} */
    changedId: string | null;
    /** @type {?string} */
    changedClass: string | null;
    /** @type {?string} */
    changedAttribute: string | null;
    /** @type {?string} */
    changedPseudo: string | null;
    /** @type {?string} */
    selectorPart: string | null;
    /** @type {?string} */
    extraData: string | null;
    /** @type {?Array.<!Object.<string, number>>} */
    invalidationList: Array<{
        [x: string]: number;
    }> | null;
    /** @type {!InvalidationCause} */
    cause: InvalidationCause;
}
export class InvalidationTracker {
    /**
     * @param {!SDK.TracingModel.Event} event
     * @return {?Array<!InvalidationTrackingEvent>}
     */
    static invalidationEventsFor(event: SDK.TracingModel.Event): Array<InvalidationTrackingEvent> | null;
    /** @type {?SDK.TracingModel.Event} */
    _lastRecalcStyle: SDK.TracingModel.Event | null;
    /** @type {?SDK.TracingModel.Event} */
    _lastPaintWithLayer: SDK.TracingModel.Event | null;
    _didPaint: boolean;
    /**
     * @param {!InvalidationTrackingEvent} invalidation
     */
    addInvalidation(invalidation: InvalidationTrackingEvent): void;
    /**
     * @param {!SDK.TracingModel.Event} recalcStyleEvent
     */
    didRecalcStyle(recalcStyleEvent: SDK.TracingModel.Event): void;
    /**
     * @param {!InvalidationTrackingEvent} invalidation
     */
    _associateWithLastRecalcStyleEvent(invalidation: InvalidationTrackingEvent): void;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @param {number} frameId
     * @param {!InvalidationTrackingEvent} styleInvalidatorInvalidation
     */
    _addSyntheticStyleRecalcInvalidations(event: SDK.TracingModel.Event, frameId: number, styleInvalidatorInvalidation: InvalidationTrackingEvent): void;
    /**
     * @param {!SDK.TracingModel.Event} baseEvent
     * @param {!InvalidationTrackingEvent} styleInvalidatorInvalidation
     */
    _addSyntheticStyleRecalcInvalidation(baseEvent: SDK.TracingModel.Event, styleInvalidatorInvalidation: InvalidationTrackingEvent): void;
    /**
     * @param {!SDK.TracingModel.Event} layoutEvent
     */
    didLayout(layoutEvent: SDK.TracingModel.Event): void;
    /**
     * @param {!SDK.TracingModel.Event} paintEvent
     */
    didPaint(paintEvent: SDK.TracingModel.Event): void;
    /**
     * @param {!SDK.TracingModel.Event} event
     * @param {number} eventFrameId
     * @param {!InvalidationTrackingEvent} invalidation
     */
    _addInvalidationToEvent(event: SDK.TracingModel.Event, eventFrameId: number, invalidation: InvalidationTrackingEvent): void;
    /**
     * @param {!Array.<string>=} types
     * @return {!Generator<!InvalidationTrackingEvent>}
     */
    _invalidationsOfTypes(types?: Array<string> | undefined): Generator<InvalidationTrackingEvent>;
    _startNewFrameIfNeeded(): void;
    _initializePerFrameState(): void;
    /** @type {!Object.<string, !Array.<!InvalidationTrackingEvent>>} */
    _invalidations: {
        [x: string]: InvalidationTrackingEvent[];
    } | undefined;
    /** @type {!Object.<number, !Array.<!InvalidationTrackingEvent>>} */
    _invalidationsByNodeId: {
        [x: number]: InvalidationTrackingEvent[];
    } | undefined;
}
export namespace InvalidationTracker {
    const _invalidationTrackingEventsSymbol: symbol;
}
/**
 * @unrestricted
 */
export class TimelineAsyncEventTracker {
    static _initialize(): void;
    /** @type {!Map<!RecordType, !Map<string, !SDK.TracingModel.Event>>} */
    _initiatorByType: Map<RecordType, Map<string, SDK.TracingModel.Event>>;
    /**
     * @param {!SDK.TracingModel.Event} event
     */
    processEvent(event: SDK.TracingModel.Event): void;
}
export class TimelineData {
    /**
     * @param {!SDK.TracingModel.Event} event
     * @return {!TimelineData}
     */
    static forEvent(event: SDK.TracingModel.Event): TimelineData;
    /** @type {?string} */
    warning: string | null;
    /** @type {?Element} */
    previewElement: Element | null;
    /** @type {?string} */
    url: string | null;
    /** @type {number} */
    backendNodeId: number;
    /** @type {?Array<!Protocol.Runtime.CallFrame>} */
    stackTrace: Array<Protocol.Runtime.CallFrame> | null;
    /** @type {?SDK.TracingModel.ObjectSnapshot} */
    picture: SDK.TracingModel.ObjectSnapshot | null;
    /** @type {?SDK.TracingModel.Event} */
    _initiator: SDK.TracingModel.Event | null;
    frameId: string;
    /** @type {number|undefined} */
    timeWaitingForMainThread: number | undefined;
    /**
     * @param {!SDK.TracingModel.Event} initiator
     */
    setInitiator(initiator: SDK.TracingModel.Event): void;
    /**
     * @return {?SDK.TracingModel.Event}
     */
    initiator(): SDK.TracingModel.Event | null;
    /**
     * @return {?Protocol.Runtime.CallFrame}
     */
    topFrame(): Protocol.Runtime.CallFrame | null;
    /**
     * @return {?Array<!Protocol.Runtime.CallFrame>}
     */
    stackTraceForSelfOrInitiator(): Array<Protocol.Runtime.CallFrame> | null;
}
export namespace TimelineData {
    const _symbol: symbol;
}
export type InvalidationCause = {
    reason: string;
    stackTrace: Array<Protocol.Runtime.CallFrame> | null;
};
/** @typedef {{reason: string, stackTrace: ?Array<!Protocol.Runtime.CallFrame>}} */
export let InvalidationCause: any;
export type MetadataEvents = {
    page: Array<SDK.TracingModel.Event>;
    workers: Array<SDK.TracingModel.Event>;
};
/** @typedef {!{page: !Array<!SDK.TracingModel.Event>, workers: !Array<!SDK.TracingModel.Event>}} */
export let MetadataEvents: any;
import * as SDK from "../sdk/sdk.js";
