/**
 * @param {!SDK.TracingModel.Event} event
 * @return {?string}
 */
export function eventURL(event: SDK.TracingModel.Event): string | null;
/**
 * @param {!SDK.TracingModel.Event} event
 * @return {?Protocol.Runtime.CallFrame}
 */
export function eventStackFrame(event: SDK.TracingModel.Event): Protocol.Runtime.CallFrame | null;
/**
 * @param {!SDK.TracingModel.Event} event
 * @return {string}
 */
export function _eventId(event: SDK.TracingModel.Event): string;
/**
 * @unrestricted
 */
export class Node {
    /**
     * @param {string|symbol} id
     * @param {?SDK.TracingModel.Event} event
     */
    constructor(id: string | symbol, event: SDK.TracingModel.Event | null);
    /** @type {number} */
    totalTime: number;
    /** @type {number} */
    selfTime: number;
    /** @type {string|symbol} */
    id: string | symbol;
    /** @type {?SDK.TracingModel.Event} */
    event: SDK.TracingModel.Event | null;
    /** @type {?Node} */
    parent: Node | null;
    /** @type {string} */
    _groupId: string;
    _isGroupNode: boolean;
    /**
     * @return {boolean}
     */
    isGroupNode(): boolean;
    /**
     * @return {boolean}
     */
    hasChildren(): boolean;
    /**
     * @return {!ChildrenCache}
     */
    children(): Map<string | symbol, Node>;
    /**
     * @param {function(!SDK.TracingModel.Event):boolean} matchFunction
     * @param {!Array<!Node>=} results
     * @return {!Array<!Node>}
     */
    searchTree(matchFunction: (arg0: SDK.TracingModel.Event) => boolean, results?: Array<Node> | undefined): Array<Node>;
}
export class TopDownNode extends Node {
    /**
     * @param {string|symbol} id
     * @param {?SDK.TracingModel.Event} event
     * @param {?TopDownNode} parent
     */
    constructor(id: string | symbol, event: SDK.TracingModel.Event | null, parent: TopDownNode | null);
    /** @type {?TopDownRootNode} */
    _root: TopDownRootNode | null;
    _hasChildren: boolean;
    _children: Map<string | symbol, Node> | null;
    /**
     * @return {!ChildrenCache}
     */
    _buildChildren(): Map<string | symbol, Node>;
}
export class TopDownRootNode extends TopDownNode {
    /**
     * @param {!Array<!SDK.TracingModel.Event>} events
     * @param {!Array<!TimelineModelFilter>} filters
     * @param {number} startTime
     * @param {number} endTime
     * @param {boolean=} doNotAggregate
     * @param {?function(!SDK.TracingModel.Event):string=} eventGroupIdCallback
     */
    constructor(events: Array<SDK.TracingModel.Event>, filters: Array<TimelineModelFilter>, startTime: number, endTime: number, doNotAggregate?: boolean | undefined, eventGroupIdCallback?: (((arg0: SDK.TracingModel.Event) => string) | null) | undefined);
    _events: SDK.TracingModel.Event[];
    _filter: (e: any) => boolean;
    _startTime: number;
    _endTime: number;
    _eventGroupIdCallback: ((arg0: SDK.TracingModel.Event) => string) | null | undefined;
    _doNotAggregate: boolean | undefined;
    /**
     * @return {!ChildrenCache}
     */
    _grouppedTopNodes(): Map<string | symbol, Node>;
}
export class BottomUpRootNode extends Node {
    /**
     * @param {!Array<!SDK.TracingModel.Event>} events
     * @param {!TimelineModelFilter} textFilter
     * @param {!Array<!TimelineModel.TimelineModelFilter>} filters
     * @param {number} startTime
     * @param {number} endTime
     * @param {?function(!SDK.TracingModel.Event):string} eventGroupIdCallback
     */
    constructor(events: Array<SDK.TracingModel.Event>, textFilter: TimelineModelFilter, filters: Array<any>, startTime: number, endTime: number, eventGroupIdCallback: ((arg0: SDK.TracingModel.Event) => string) | null);
    /** @type {?ChildrenCache} */
    _children: Map<string | symbol, Node> | null;
    _events: SDK.TracingModel.Event[];
    _textFilter: TimelineModelFilter;
    _filter: (e: any) => boolean;
    _startTime: number;
    _endTime: number;
    _eventGroupIdCallback: ((arg0: SDK.TracingModel.Event) => string) | null;
    /**
     * @param {!ChildrenCache} children
     * @return {!ChildrenCache}
     */
    _filterChildren(children: Map<string | symbol, Node>): Map<string | symbol, Node>;
    /**
     * @return {!ChildrenCache}
     */
    _ungrouppedTopNodes(): Map<string | symbol, Node>;
    /**
     * @return {!ChildrenCache}
     */
    _grouppedTopNodes(): Map<string | symbol, Node>;
}
export class GroupNode extends Node {
    /**
     * @param {string} id
     * @param {!BottomUpRootNode|!TopDownRootNode} parent
     * @param {!SDK.TracingModel.Event} event
     */
    constructor(id: string, parent: BottomUpRootNode | TopDownRootNode, event: SDK.TracingModel.Event);
    _children: Map<any, any>;
    /**
     * @param {!BottomUpNode} child
     * @param {number} selfTime
     * @param {number} totalTime
     */
    addChild(child: BottomUpNode, selfTime: number, totalTime: number): void;
}
export class BottomUpNode extends Node {
    /**
     * @param {!BottomUpRootNode} root
     * @param {string} id
     * @param {!SDK.TracingModel.Event} event
     * @param {boolean} hasChildren
     * @param {!Node} parent
     */
    constructor(root: BottomUpRootNode, id: string, event: SDK.TracingModel.Event, hasChildren: boolean, parent: Node);
    _root: BottomUpRootNode;
    _depth: any;
    /** @type {?ChildrenCache} */
    _cachedChildren: Map<string | symbol, Node> | null;
    _hasChildren: boolean;
    setHasChildren(): void;
}
export type ChildrenCache = Map<string | symbol, Node>;
/**
 * @typedef {Map<string|symbol, !Node>}
 */
export let ChildrenCache: any;
import * as SDK from "../sdk/sdk.js";
import { TimelineModelFilter } from "./TimelineModelFilter.js";
