/**
 * @unrestricted
 */
export class TracingLayerTree extends SDK.LayerTreeBase.LayerTreeBase {
    /**
     * @param {?SDK.SDKModel.Target} target
     */
    constructor(target: SDK.SDKModel.Target | null);
    /** @type {!Map.<string, !TracingLayerTile>} */
    _tileById: Map<string, TracingLayerTile>;
    _paintProfilerModel: any;
    /**
     * @param {?TracingLayerPayload} root
     * @param {?Array<!TracingLayerPayload>} layers
     * @param {!Array<!LayerPaintEvent>} paints
     * @return {!Promise}
     */
    setLayers(root: TracingLayerPayload | null, layers: Array<TracingLayerPayload> | null, paints: Array<LayerPaintEvent>): Promise<any>;
    /**
     * @param {!Array.<!TracingLayerTile>} tiles
     */
    setTiles(tiles: Array<TracingLayerTile>): void;
    /**
     * @param {string} tileId
     * @return {!Promise<?SDK.PaintProfiler.SnapshotWithRect>}
     */
    pictureForRasterTile(tileId: string): Promise<SDK.PaintProfiler.SnapshotWithRect | null>;
    /**
     * @param {!Array<!LayerPaintEvent>} paints
     */
    _setPaints(paints: Array<LayerPaintEvent>): void;
    /**
     * @param {!Map<(string|number), !SDK.LayerTreeBase.Layer>} oldLayersById
     * @param {!TracingLayerPayload} payload
     * @return {!TracingLayer}
     */
    _innerSetLayers(oldLayersById: Map<(string | number), SDK.LayerTreeBase.Layer>, payload: TracingLayerPayload): TracingLayer;
    /**
     * @param {!Set<number>} nodeIdsToResolve
     * @param {!Object} seenNodeIds
     * @param {!TracingLayerPayload} payload
     */
    _extractNodeIdsToResolve(nodeIdsToResolve: Set<number>, seenNodeIds: Object, payload: TracingLayerPayload): void;
}
/**
 * @implements {SDK.LayerTreeBase.Layer}
 * @unrestricted
 */
export class TracingLayer implements SDK.LayerTreeBase.Layer {
    /**
     * @param {?SDK.PaintProfiler.PaintProfilerModel} paintProfilerModel
     * @param {!TracingLayerPayload} payload
     */
    constructor(paintProfilerModel: SDK.PaintProfiler.PaintProfilerModel | null, payload: TracingLayerPayload);
    _paintProfilerModel: SDK.PaintProfiler.PaintProfilerModel | null;
    /**
     * @param {!TracingLayerPayload} payload
     */
    _reset(payload: TracingLayerPayload): void;
    /** @type {?SDK.DOMModel.DOMNode} */
    _node: SDK.DOMModel.DOMNode | null | undefined;
    _layerId: string | undefined;
    _offsetX: number | undefined;
    _offsetY: number | undefined;
    _width: number | undefined;
    _height: number | undefined;
    _children: any[] | undefined;
    _parentLayerId: any;
    _parent: any;
    _quad: number[] | undefined;
    _compositingReasonIds: any;
    _drawsContent: boolean | undefined;
    _gpuMemoryUsage: number | undefined;
    _paints: any[] | undefined;
    /**
     * @override
     * @return {string}
     */
    id(): string;
    /**
     * @override
     * @return {?string}
     */
    parentId(): string | null;
    /**
     * @override
     * @return {?SDK.LayerTreeBase.Layer}
     */
    parent(): SDK.LayerTreeBase.Layer | null;
    /**
     * @override
     * @return {boolean}
     */
    isRoot(): boolean;
    /**
     * @override
     * @return {!Array.<!SDK.LayerTreeBase.Layer>}
     */
    children(): Array<SDK.LayerTreeBase.Layer>;
    /**
     * @override
     * @param {!SDK.LayerTreeBase.Layer} childParam
     */
    addChild(childParam: SDK.LayerTreeBase.Layer): void;
    /**
     * @param {?SDK.DOMModel.DOMNode} node
     */
    _setNode(node: SDK.DOMModel.DOMNode | null): void;
    /**
     * @override
     * @return {?SDK.DOMModel.DOMNode}
     */
    node(): SDK.DOMModel.DOMNode | null;
    /**
     * @override
     * @return {?SDK.DOMModel.DOMNode}
     */
    nodeForSelfOrAncestor(): SDK.DOMModel.DOMNode | null;
    /**
     * @override
     * @return {number}
     */
    offsetX(): number;
    /**
     * @override
     * @return {number}
     */
    offsetY(): number;
    /**
     * @override
     * @return {number}
     */
    width(): number;
    /**
     * @override
     * @return {number}
     */
    height(): number;
    /**
     * @override
     * @return {?Array.<number>}
     */
    transform(): Array<number> | null;
    /**
     * @override
     * @return {!Array.<number>}
     */
    quad(): Array<number>;
    /**
     * @override
     * @return {!Array.<number>}
     */
    anchorPoint(): Array<number>;
    /**
     * @override
     * @return {boolean}
     */
    invisible(): boolean;
    /**
     * @override
     * @return {number}
     */
    paintCount(): number;
    /**
     * @override
     * @return {?Protocol.DOM.Rect}
     */
    lastPaintRect(): Protocol.DOM.Rect | null;
    /**
     * @override
     * @return {!Array.<!Protocol.LayerTree.ScrollRect>}
     */
    scrollRects(): Array<Protocol.LayerTree.ScrollRect>;
    /**
     * @override
     * @return {?SDK.LayerTreeBase.StickyPositionConstraint}
     */
    stickyPositionConstraint(): SDK.LayerTreeBase.StickyPositionConstraint | null;
    /**
     * @override
     * @return {number}
     */
    gpuMemoryUsage(): number;
    /**
     * @override
     * @return {!Array<!Promise<?SDK.PaintProfiler.SnapshotWithRect>>}
     */
    snapshots(): Array<Promise<SDK.PaintProfiler.SnapshotWithRect | null>>;
    /**
     * @param {!Array<number>} targetRect
     * @return {!Promise<?SDK.PaintProfiler.SnapshotWithRect>}
     */
    _pictureForRect(targetRect: Array<number>): Promise<SDK.PaintProfiler.SnapshotWithRect | null>;
    /**
     * @param {!Array.<number>} params
     * @param {string} type
     * @return {!Object}
     */
    _scrollRectsFromParams(params: Array<number>, type: string): Object;
    /**
     * @param {!TracingLayerPayload} payload
     */
    _createScrollRects(payload: TracingLayerPayload): void;
    _scrollRects: any[] | undefined;
    /**
     * @param {!LayerPaintEvent} paint
     */
    _addPaintEvent(paint: LayerPaintEvent): void;
    /**
     * @override
     * @return {!Promise<!Array<string>>}
     */
    requestCompositingReasonIds(): Promise<Array<string>>;
    /**
     * @override
     * @return {boolean}
     */
    drawsContent(): boolean;
}
export type TracingLayerPayload = {
    bounds: {
        height: number;
        width: number;
    };
    children: Array<TracingLayerPayload>;
    layer_id: number;
    position: Array<number>;
    scroll_offset: Array<number>;
    layer_quad: Array<number>;
    draws_content: number;
    gpu_memory_usage: number;
    transform: Array<number>;
    owner_node: number;
    compositing_reasons: Array<string>;
};
/** @typedef {!{
 bounds: {height: number, width: number},
 children: Array.<!TracingLayerPayload>,
 layer_id: number,
 position: Array.<number>,
 scroll_offset: Array.<number>,
 layer_quad: Array.<number>,
 draws_content: number,
 gpu_memory_usage: number,
 transform: Array.<number>,
 owner_node: number,
 compositing_reasons: Array.<string>
}}
*/
export let TracingLayerPayload: any;
export type TracingLayerTile = {
    id: string;
    layer_id: string;
    gpu_memory_usage: number;
    content_rect: Array<number>;
};
/** @typedef {!{
 id: string,
 layer_id: string,
 gpu_memory_usage: number,
 content_rect: !Array.<number>
}}
*/
export let TracingLayerTile: any;
import * as SDK from "../sdk/sdk.js";
import { LayerPaintEvent } from "./TimelineFrameModel.js";
