export class Context {
    /**
     * @param {{forceNew: ?boolean}} opts
     */
    static instance(opts?: {
        forceNew: boolean | null;
    }): Context;
    /** @type {!Map<!ConstructorFn, !Object>} */
    _flavors: Map<ConstructorFn, Object>;
    /** @type {!Map<!ConstructorFn, !Common.ObjectWrapper.ObjectWrapper>} */
    _eventDispatchers: Map<ConstructorFn, Common.ObjectWrapper.ObjectWrapper>;
    /**
     * @param {(function(new:T, ...*):void|function(new:T, ...?):void)} flavorType
     * @param {?T} flavorValue
     * @template T
     */
    setFlavor<T>(flavorType: new (...arg1: any[]) => T, flavorValue: T | null): void;
    /**
     * @param {(function(new:T, ...*):void|function(new:T, ...?):void)} flavorType
     * @param {?T} flavorValue
     * @template T
     */
    _dispatchFlavorChange<T_1>(flavorType: new (...arg1: any[]) => T_1, flavorValue: T_1 | null): void;
    /**
     * @param {!ConstructorFn} flavorType
     * @param {function(!Common.EventTarget.EventTargetEvent):void} listener
     * @param {!Object=} thisObject
     */
    addFlavorChangeListener(flavorType: ConstructorFn, listener: (arg0: Common.EventTarget.EventTargetEvent) => void, thisObject?: Object | undefined): void;
    /**
     * @param {!ConstructorFn} flavorType
     * @param {function(!Common.EventTarget.EventTargetEvent):void} listener
     * @param {!Object=} thisObject
     */
    removeFlavorChangeListener(flavorType: ConstructorFn, listener: (arg0: Common.EventTarget.EventTargetEvent) => void, thisObject?: Object | undefined): void;
    /**
     * @param {(function(new:T, ...*):void|function(new:T, ...?):void)} flavorType
     * @return {?T}
     * @template T
     */
    flavor<T_2>(flavorType: new (...arg1: any[]) => T_2): T_2 | null;
    /**
     * @return {!Set.<(function(new:Object, ...*):void|function(new:Object, ...?):void)>}
     */
    flavors(): Set<(new (...args: any[]) => Object)>;
    /**
     * @param {!Array.<!Root.Runtime.Extension>} extensions
     * @return {!Set.<!Root.Runtime.Extension>}
     */
    applicableExtensions(extensions: Array<Root.Runtime.Extension>): Set<Root.Runtime.Extension>;
}
type ConstructorFn = new (...arg1: any[]) => Object;
/** @typedef {(function(new:Object, ...*):void|function(new:Object, ...?):void)} */
declare let ConstructorFn: any;
import * as Common from "../common/common.js";
import * as Root from "../root/root.js";
export {};
