/**
 * @unrestricted
 */
export class Infobar {
    /**
     * @param {!Type} type
     * @param {string} text
     * @param {!Array<!InfobarAction>=} actions
     * @param {!Common.Settings.Setting<*>=} disableSetting
     * @return {?Infobar}
     */
    static create(type: Type, text: string, actions?: Array<InfobarAction> | undefined, disableSetting?: Common.Settings.Setting<any> | undefined): Infobar | null;
    /**
     * @param {!Type} type
     * @param {string} text
     * @param {!Array<!InfobarAction>=} actions
     * @param {!Common.Settings.Setting<*>=} disableSetting
     */
    constructor(type: Type, text: string, actions?: Array<InfobarAction> | undefined, disableSetting?: Common.Settings.Setting<any> | undefined);
    element: HTMLDivElement;
    _shadowRoot: DocumentFragment;
    /** @type {!HTMLDivElement} */
    _contentElement: HTMLDivElement;
    _mainRow: HTMLElement;
    _detailsRows: HTMLElement;
    _hasDetails: boolean;
    _infoContainer: HTMLElement;
    _infoMessage: HTMLElement;
    _infoText: HTMLElement;
    _actionContainer: HTMLElement;
    /** @type {?Common.Settings.Setting<*>} */
    _disableSetting: Common.Settings.Setting<any> | null;
    _closeContainer: HTMLElement;
    _toggleElement: HTMLButtonElement;
    _closeButton: HTMLElement;
    /** @type {?function():*} */
    _closeCallback: (() => any) | null;
    dispose(): void;
    /**
     * @param {string} text
     */
    setText(text: string): void;
    /**
     * @param {?function():*} callback
     */
    setCloseCallback(callback: (() => any) | null): void;
    /**
     * @param {!Widget} parentView
     */
    setParentView(parentView: Widget): void;
    _parentView: Widget | undefined;
    /**
     * @param {!InfobarAction} action
     * @returns {!function():void}
     */
    _actionCallbackFactory(action: InfobarAction): () => void;
    _onResize(): void;
    _onDisable(): void;
    _onToggleDetails(): void;
    /**
     * @param {string=} message
     * @return {!Element}
     */
    createDetailsRowMessage(message?: string | undefined): Element;
}
export type InfobarAction = {
    text: string;
    highlight: boolean;
    delegate: (() => void) | null;
    dismiss: boolean;
};
/** @typedef {{
 *        text: !string,
 *        highlight: !boolean,
 *        delegate: ?function():void,
 *        dismiss: !boolean
 * }}
 */
export let InfobarAction: any;
export type Type = string;
export namespace Type {
    const Warning: string;
    const Info: string;
    const Issue: string;
}
import * as Common from "../common/common.js";
import { Widget } from "./Widget.js";
