export class InplaceEditor {
    /**
     * @param {!Element} element
     * @param {!Config<?>=} config
     * @return {?Controller}
     */
    static startEditing(element: Element, config?: Config<unknown> | undefined): Controller | null;
    /**
     * @param {!EditingContext} editingContext
     * @return {string}
     */
    editorContent(editingContext: EditingContext): string;
    /**
     * @param {!EditingContext} editingContext
     */
    setUpEditor(editingContext: EditingContext): void;
    /** @type {!ElementFocusRestorer} */
    _focusRestorer: ElementFocusRestorer | undefined;
    /**
     * @param {!EditingContext} editingContext
     */
    closeEditor(editingContext: EditingContext): void;
    /**
     * @param {!EditingContext} editingContext
     */
    cancelEditing(editingContext: EditingContext): void;
    /**
     * @param {!EditingContext} editingContext
     * @param {*} handle
     */
    augmentEditingHandle(editingContext: EditingContext, handle: any): void;
    /**
     * @param {!Element} element
     * @param {!Config<*>=} inputConfig
     * @return {?Controller}
     */
    startEditing(element: Element, inputConfig?: Config<any> | undefined): Controller | null;
}
/**
 * @template T
 */
export class Config<T> {
    /**
     * @param {function(!Element,string,string,T,string):void} commitHandler
     * @param {function(!Element,T):void} cancelHandler
     * @param {T=} context
     * @param {function(!Element,!Event=):boolean=} blurHandler
     */
    constructor(commitHandler: (arg0: Element, arg1: string, arg2: string, arg3: T, arg4: string) => void, cancelHandler: (arg0: Element, arg1: T) => void, context?: T | undefined, blurHandler?: ((arg0: Element, arg1: Event | undefined) => boolean) | undefined);
    commitHandler: (arg0: Element, arg1: string, arg2: string, arg3: T, arg4: string) => void;
    cancelHandler: (arg0: Element, arg1: T) => void;
    context: T | undefined;
    blurHandler: ((arg0: Element, arg1?: Event | undefined) => boolean) | undefined;
    /**
     * @type {?EventHandler}
     */
    pasteHandler: EventHandler | null;
    /**
     * @type {?EventHandler}
     */
    postKeydownFinishHandler: EventHandler | null;
    /**
     * @param {!EventHandler} pasteHandler
     */
    setPasteHandler(pasteHandler: EventHandler): void;
    /**
     * @param {!EventHandler} postKeydownFinishHandler
     */
    setPostKeydownFinishHandler(postKeydownFinishHandler: EventHandler): void;
}
export type EventHandler = (arg0: Event) => string | undefined;
/**
 * @typedef {function(!Event):string|undefined}
 */
export let EventHandler: any;
export type Controller = {
    cancel: () => void;
    commit: () => void;
};
/**
 * @typedef {{cancel: function():void, commit: function():void}}
 */
export let Controller: any;
export type EditingContext = {
    element: Element;
    config: Config<any>;
    oldRole: string | null;
    oldText: string | null;
    oldTabIndex: number | null;
};
/**
 * @typedef {!{element: Element, config: !Config<*>, oldRole: ?string, oldText: ?string, oldTabIndex: ?number}}
 */
export let EditingContext: any;
import { ElementFocusRestorer } from "./UIUtils.js";
